@@ -52,12 +52,12 @@ namespace OpenRCT2::Ui::Windows
     }
     static constexpr uint16_t MapColourUnowned(uint16_t colour)
     {
-        return MapColour2((colour & 0xFF00) >> 8, PALETTE_INDEX_10);
+        return MapColour2((colour & 0xFF00) >> 8, PaletteIndex::pi10);
     }
     static int32_t getPracticalMapSize()
     {
         // Take non-square maps into account
-        return std::max(GetGameState().MapSize.x, GetGameState().MapSize.y) - 2;
+        return std::max(getGameState().mapSize.x, getGameState().mapSize.y) - 2;
     }
     static int32_t getPracticalMapSizeBig()
     {
@@ -74,12 +74,11 @@ namespace OpenRCT2::Ui::Windows
 
     static bool isEditorOrSandbox()
     {
-        return (gScreenFlags & SCREEN_FLAGS_SCENARIO_EDITOR) || GetGameState().Cheats.sandboxMode;
+        return gLegacyScene == LegacyScene::scenarioEditor || getGameState().cheats.sandboxMode;
     }
 
-    static constexpr StringId WINDOW_TITLE = STR_MAP_LABEL;
-    static constexpr int32_t WH = 259;
-    static constexpr int32_t WW = 245;
+    static constexpr StringId kWindowTitle = STR_MAP_LABEL;
+    static constexpr ScreenSize kWindowSize = { 245, 259 };
 
     static constexpr uint16_t kReservedHSpace = 4;
     static constexpr uint16_t kReservedTopSpace = 46;
@@ -131,20 +130,20 @@ namespace OpenRCT2::Ui::Windows
     };
 
     // clang-format off
-    static constexpr Widget window_map_widgets[] = {
-        WINDOW_SHIM(WINDOW_TITLE, WW, WH),
-        MakeWidget        ({  0,  43}, {245, 215}, WindowWidgetType::Resize,    WindowColour::Secondary                                                                ),
-        MakeRemapWidget   ({  3,  17}, { 31,  27}, WindowWidgetType::ColourBtn, WindowColour::Secondary, SPR_TAB,                      STR_SHOW_PEOPLE_ON_MAP_TIP      ),
-        MakeRemapWidget   ({ 34,  17}, { 31,  27}, WindowWidgetType::ColourBtn, WindowColour::Secondary, SPR_TAB,                      STR_SHOW_RIDES_STALLS_ON_MAP_TIP),
-        MakeWidget        ({  3,  46}, {239, 180}, WindowWidgetType::Scroll,    WindowColour::Secondary, SCROLL_BOTH                                                   ),
-        MakeSpinnerWidgets({102, 229}, { 50,  12}, WindowWidgetType::Spinner,   WindowColour::Secondary, STR_COMMA16                                                   ), // NB: 3 widgets
-        MakeWidget        ({153, 230}, { 20,  12}, WindowWidgetType::FlatBtn,   WindowColour::Secondary, ImageId(SPR_G2_LINK_CHAIN),   STR_MAINTAIN_SQUARE_MAP_TOOLTIP ),
-        MakeSpinnerWidgets({174, 229}, { 50,  12}, WindowWidgetType::Spinner,   WindowColour::Secondary, STR_POP16_COMMA16                                             ), // NB: 3 widgets
-        MakeWidget        ({  4,  46}, { 24,  24}, WindowWidgetType::FlatBtn,   WindowColour::Secondary, ImageId(SPR_BUY_LAND_RIGHTS), STR_SELECT_PARK_OWNED_LAND_TIP  ),
-        MakeWidget        ({  4,  70}, { 24,  24}, WindowWidgetType::FlatBtn,   WindowColour::Secondary, ImageId(SPR_G2_PEEP_SPAWN),   STR_SET_STARTING_POSITIONS_TIP  ),
-        MakeWidget        ({ 28,  94}, { 24,  24}, WindowWidgetType::FlatBtn,   WindowColour::Secondary, ImageId(SPR_PARK_ENTRANCE),   STR_BUILD_PARK_ENTRANCE_TIP     ),
-        MakeWidget        ({110, 118}, { 24,  24}, WindowWidgetType::FlatBtn,   WindowColour::Secondary, ImageId(SPR_G2_MAP_GEN_BTN),  STR_MAP_GENERATOR_TIP           ),
-    };
+    static constexpr auto window_map_widgets = makeWidgets(
+        makeWindowShim(kWindowTitle, kWindowSize),
+        makeWidget        ({  0,  43}, {245, 215}, WidgetType::resize,    WindowColour::secondary                                                                ),
+        makeRemapWidget   ({  3,  17}, { 31,  27}, WidgetType::colourBtn, WindowColour::secondary, SPR_TAB,                      STR_SHOW_PEOPLE_ON_MAP_TIP      ),
+        makeRemapWidget   ({ 34,  17}, { 31,  27}, WidgetType::colourBtn, WindowColour::secondary, SPR_TAB,                      STR_SHOW_RIDES_STALLS_ON_MAP_TIP),
+        makeWidget        ({  3,  46}, {239, 180}, WidgetType::scroll,    WindowColour::secondary, SCROLL_BOTH                                                   ),
+        makeSpinnerWidgets({102, 229}, { 50,  12}, WidgetType::spinner,   WindowColour::secondary, STR_COMMA16                                                   ), // NB: 3 widgets
+        makeWidget        ({153, 230}, { 20,  12}, WidgetType::flatBtn,   WindowColour::secondary, ImageId(SPR_G2_LINK_CHAIN),   STR_MAINTAIN_SQUARE_MAP_TOOLTIP ),
+        makeSpinnerWidgets({174, 229}, { 50,  12}, WidgetType::spinner,   WindowColour::secondary, STR_POP16_COMMA16                                             ), // NB: 3 widgets
+        makeWidget        ({  4,  46}, { 24,  24}, WidgetType::flatBtn,   WindowColour::secondary, ImageId(SPR_BUY_LAND_RIGHTS), STR_SELECT_PARK_OWNED_LAND_TIP  ),
+        makeWidget        ({  4,  70}, { 24,  24}, WidgetType::flatBtn,   WindowColour::secondary, ImageId(SPR_G2_PEEP_SPAWN),   STR_SET_STARTING_POSITIONS_TIP  ),
+        makeWidget        ({ 28,  94}, { 24,  24}, WidgetType::flatBtn,   WindowColour::secondary, ImageId(SPR_PARK_ENTRANCE),   STR_BUILD_PARK_ENTRANCE_TIP     ),
+        makeWidget        ({110, 118}, { 24,  24}, WidgetType::flatBtn,   WindowColour::secondary, ImageId(SPR_G2_MAP_GEN_BTN),  STR_MAP_GENERATOR_TIP           )
+    );
     // clang-format on
 
     // These represent a coefficient for the map size to be multiplied
@@ -163,23 +162,23 @@ namespace OpenRCT2::Ui::Windows
     };
 
     static constexpr uint16_t RideKeyColours[] = {
-        MapColour(PALETTE_INDEX_61),  // COLOUR_KEY_RIDE
-        MapColour(PALETTE_INDEX_42),  // COLOUR_KEY_FOOD
-        MapColour(PALETTE_INDEX_20),  // COLOUR_KEY_DRINK
-        MapColour(PALETTE_INDEX_209), // COLOUR_KEY_SOUVENIR
-        MapColour(PALETTE_INDEX_136), // COLOUR_KEY_KIOSK
-        MapColour(PALETTE_INDEX_102), // COLOUR_KEY_FIRST_AID
-        MapColour(PALETTE_INDEX_55),  // COLOUR_KEY_CASH_MACHINE
-        MapColour(PALETTE_INDEX_161), // COLOUR_KEY_TOILETS
+        MapColour(PaletteIndex::pi61),  // COLOUR_KEY_RIDE
+        MapColour(PaletteIndex::pi42),  // COLOUR_KEY_FOOD
+        MapColour(PaletteIndex::pi20),  // COLOUR_KEY_DRINK
+        MapColour(PaletteIndex::pi209), // COLOUR_KEY_SOUVENIR
+        MapColour(PaletteIndex::pi136), // COLOUR_KEY_KIOSK
+        MapColour(PaletteIndex::pi102), // COLOUR_KEY_FIRST_AID
+        MapColour(PaletteIndex::pi55),  // COLOUR_KEY_CASH_MACHINE
+        MapColour(PaletteIndex::pi161), // COLOUR_KEY_TOILETS
     };
 
-    static constexpr uint8_t DefaultPeepMapColour = PALETTE_INDEX_20;
-    static constexpr uint8_t GuestMapColour = PALETTE_INDEX_172;
-    static constexpr uint8_t GuestMapColourAlternate = PALETTE_INDEX_21;
-    static constexpr uint8_t StaffMapColour = PALETTE_INDEX_138;
-    static constexpr uint8_t StaffMapColourAlternate = PALETTE_INDEX_10;
+    static constexpr uint8_t DefaultPeepMapColour = PaletteIndex::pi20;
+    static constexpr uint8_t GuestMapColour = PaletteIndex::pi172;
+    static constexpr uint8_t GuestMapColourAlternate = PaletteIndex::pi21;
+    static constexpr uint8_t StaffMapColour = PaletteIndex::pi138;
+    static constexpr uint8_t StaffMapColourAlternate = PaletteIndex::pi10;
 
-    static constexpr uint16_t WaterColour = MapColour(PALETTE_INDEX_195);
+    static constexpr uint16_t WaterColour = MapColour(PaletteIndex::pi195);
 
     static constexpr uint16_t ElementTypeMaskColour[] = {
         0xFFFF, // TILE_ELEMENT_TYPE_SURFACE
@@ -193,14 +192,14 @@ namespace OpenRCT2::Ui::Windows
     };
 
     static constexpr uint16_t ElementTypeAddColour[] = {
-        MapColour(PALETTE_INDEX_0),                     // TILE_ELEMENT_TYPE_SURFACE
-        MapColour(PALETTE_INDEX_17),                    // TILE_ELEMENT_TYPE_PATH
-        MapColour2(PALETTE_INDEX_183, PALETTE_INDEX_0), // TILE_ELEMENT_TYPE_TRACK
-        MapColour2(PALETTE_INDEX_0, PALETTE_INDEX_99),  // TILE_ELEMENT_TYPE_SMALL_SCENERY
-        MapColour(PALETTE_INDEX_186),                   // TILE_ELEMENT_TYPE_ENTRANCE
-        MapColour(PALETTE_INDEX_0),                     // TILE_ELEMENT_TYPE_WALL
-        MapColour(PALETTE_INDEX_99),                    // TILE_ELEMENT_TYPE_LARGE_SCENERY
-        MapColour(PALETTE_INDEX_0),                     // TILE_ELEMENT_TYPE_BANNER
+        MapColour(PaletteIndex::pi0),                       // TILE_ELEMENT_TYPE_SURFACE
+        MapColour(PaletteIndex::pi17),                      // TILE_ELEMENT_TYPE_PATH
+        MapColour2(PaletteIndex::pi183, PaletteIndex::pi0), // TILE_ELEMENT_TYPE_TRACK
+        MapColour2(PaletteIndex::pi0, PaletteIndex::pi99),  // TILE_ELEMENT_TYPE_SMALL_SCENERY
+        MapColour(PaletteIndex::pi186),                     // TILE_ELEMENT_TYPE_ENTRANCE
+        MapColour(PaletteIndex::pi0),                       // TILE_ELEMENT_TYPE_WALL
+        MapColour(PaletteIndex::pi99),                      // TILE_ELEMENT_TYPE_LARGE_SCENERY
+        MapColour(PaletteIndex::pi0),                       // TILE_ELEMENT_TYPE_BANNER
     };
 
     namespace MapFlashingFlags
@@ -239,8 +238,6 @@ namespace OpenRCT2::Ui::Windows
                 | (1uLL << WIDX_MAP_SIZE_SPINNER_X_UP) | (1uLL << WIDX_MAP_SIZE_SPINNER_X_DOWN);
 
             flags |= WF_RESIZABLE;
-            min_width = WW;
-            min_height = WH;
 
             SetInitialWindowDimensions();
             ResetMaxWindowDimensions();
@@ -255,8 +252,8 @@ namespace OpenRCT2::Ui::Windows
             CentreMapOnViewPoint();
             FootpathSelectDefault();
 
-            auto& gameState = GetGameState();
-            _mapWidthAndHeightLinked = gameState.MapSize.x == gameState.MapSize.y;
+            auto& gameState = getGameState();
+            _mapWidthAndHeightLinked = gameState.mapSize.x == gameState.mapSize.y;
 
             // Reset land rights tool size
             _landRightsToolSize = 1;
@@ -298,7 +295,7 @@ namespace OpenRCT2::Ui::Windows
                     break;
                 }
                 case WIDX_PEOPLE_STARTING_POSITION:
-                    if (ToolSet(*this, widgetIndex, Tool::UpArrow))
+                    if (ToolSet(*this, widgetIndex, Tool::upArrow))
                         break;
 
                     ShowGridlines();
@@ -484,7 +481,7 @@ namespace OpenRCT2::Ui::Windows
 
             int32_t mapZ = tileElement->GetBaseZ();
 
-            auto gameAction = PeepSpawnPlaceAction({ mapCoords, mapZ, static_cast<Direction>(direction) });
+            auto gameAction = GameActions::PeepSpawnPlaceAction({ mapCoords, mapZ, static_cast<Direction>(direction) });
             auto result = GameActions::Execute(&gameAction);
             if (result.Error == GameActions::Status::Ok)
             {
@@ -512,13 +509,13 @@ namespace OpenRCT2::Ui::Windows
                         size = std::clamp(
                             size, static_cast<int>(kMinimumMapSizeTechnical), static_cast<int>(kMaximumMapSizeTechnical));
 
-                        TileCoordsXY newMapSize = GetGameState().MapSize;
+                        TileCoordsXY newMapSize = getGameState().mapSize;
                         if (_resizeDirection != ResizeDirection::X)
                             newMapSize.y = size;
                         if (_resizeDirection != ResizeDirection::Y)
                             newMapSize.x = size;
 
-                        auto mapChangeSizeAction = MapChangeSizeAction(newMapSize);
+                        auto mapChangeSizeAction = GameActions::MapChangeSizeAction(newMapSize);
                         GameActions::Execute(&mapChangeSizeAction);
                         Invalidate();
                     }
@@ -568,9 +565,9 @@ namespace OpenRCT2::Ui::Windows
             OnScrollMouseDown(scrollIndex, screenCoords);
         }
 
-        void OnScrollDraw(int32_t scrollIndex, DrawPixelInfo& dpi) override
+        void OnScrollDraw(int32_t scrollIndex, RenderTarget& rt) override
         {
-            GfxClear(dpi, PALETTE_INDEX_10);
+            GfxClear(rt, PaletteIndex::pi10);
 
             // Ensure small maps are centred
             auto screenOffset = ScreenCoordsXY(0, 0);
@@ -584,17 +581,17 @@ namespace OpenRCT2::Ui::Windows
             g1temp.height = getMiniMapWidth();
             GfxSetG1Element(SPR_TEMP, &g1temp);
             DrawingEngineInvalidateImage(SPR_TEMP);
-            GfxDrawSprite(dpi, ImageId(SPR_TEMP), screenOffset);
+            GfxDrawSprite(rt, ImageId(SPR_TEMP), screenOffset);
 
             if (selected_tab == PAGE_PEEPS)
             {
-                PaintPeepOverlay(dpi, screenOffset);
+                PaintPeepOverlay(rt, screenOffset);
             }
             else
             {
-                PaintTrainOverlay(dpi, screenOffset);
+                PaintTrainOverlay(rt, screenOffset);
             }
-            PaintHudRectangle(dpi, screenOffset);
+            PaintHudRectangle(rt, screenOffset);
         }
 
         void OnPrepareDraw() override
@@ -616,11 +613,10 @@ namespace OpenRCT2::Ui::Windows
                 pressed_widgets |= (1uLL << WIDX_MAP_GENERATOR);
 
             // Set disabled widgets
-            auto& gameState = GetGameState();
-            SetWidgetDisabled(WIDX_MAP_SIZE_LINK, gameState.MapSize.x != gameState.MapSize.y);
+            auto& gameState = getGameState();
+            SetWidgetDisabled(WIDX_MAP_SIZE_LINK, gameState.mapSize.x != gameState.mapSize.y);
 
             // Resize widgets to window size
-            ResizeFrameWithPage();
             ResizeMiniMap();
 
             widgets[WIDX_MAP_SIZE_SPINNER_Y].top = height - 15;
@@ -650,7 +646,7 @@ namespace OpenRCT2::Ui::Windows
             // Disable all scenario editor related widgets
             for (int32_t i = WIDX_MAP_SIZE_SPINNER_Y; i <= WIDX_MAP_GENERATOR; i++)
             {
-                widgets[i].type = WindowWidgetType::Empty;
+                widgets[i].type = WidgetType::empty;
             }
 
             if (isEditorOrSandbox())
@@ -659,15 +655,15 @@ namespace OpenRCT2::Ui::Windows
             }
             if (_recalculateScrollbars)
             {
-                WidgetScrollUpdateThumbs(*this, WIDX_MAP);
+                widgetScrollUpdateThumbs(*this, WIDX_MAP);
                 _recalculateScrollbars = false;
             }
         }
 
-        void OnDraw(DrawPixelInfo& dpi) override
+        void OnDraw(RenderTarget& rt) override
         {
-            DrawWidgets(dpi);
-            DrawTabImages(dpi);
+            DrawWidgets(rt);
+            DrawTabImages(rt);
 
             if (!isEditorOrSandbox())
             {
@@ -681,9 +677,9 @@ namespace OpenRCT2::Ui::Windows
                     for (uint32_t i = 0; i < std::size(RideKeyColours); i++)
                     {
                         GfxFillRect(
-                            dpi, { screenCoords + ScreenCoordsXY{ 0, 2 }, screenCoords + ScreenCoordsXY{ 6, 8 } },
+                            rt, { screenCoords + ScreenCoordsXY{ 0, 2 }, screenCoords + ScreenCoordsXY{ 6, 8 } },
                             RideKeyColours[i]);
-                        DrawTextBasic(dpi, screenCoords + ScreenCoordsXY{ kListRowHeight, 0 }, MapLabels[i], {});
+                        DrawTextBasic(rt, screenCoords + ScreenCoordsXY{ kListRowHeight, 0 }, MapLabels[i], {});
                         screenCoords.y += kListRowHeight;
                         if (i == 3)
                         {
@@ -695,7 +691,7 @@ namespace OpenRCT2::Ui::Windows
             else if (!isToolActive(*this, WIDX_SET_LAND_RIGHTS))
             {
                 DrawTextBasic(
-                    dpi, windowPos + ScreenCoordsXY{ 4, widgets[WIDX_MAP_SIZE_SPINNER_Y].top + 1 }, STR_MAP_SIZE, {},
+                    rt, windowPos + ScreenCoordsXY{ 4, widgets[WIDX_MAP_SIZE_SPINNER_Y].top + 1 }, STR_MAP_SIZE, {},
                     { colours[1] });
             }
         }
@@ -715,75 +711,71 @@ namespace OpenRCT2::Ui::Windows
         void InitMap()
         {
             _mapImageData.resize(getMiniMapWidth() * getMiniMapWidth());
-            std::fill(_mapImageData.begin(), _mapImageData.end(), PALETTE_INDEX_10);
+            std::fill(_mapImageData.begin(), _mapImageData.end(), PaletteIndex::pi10);
             _currentLine = 0;
         }
 
         void CentreMapOnViewPoint()
         {
             WindowBase* mainWindow = WindowGetMain();
-            int16_t ax, bx, cx, dx;
-            int16_t bp, di;
-
-            if (mainWindow == nullptr || mainWindow->viewport == nullptr)
+            if (mainWindow == nullptr)
                 return;
 
-            auto offset = MiniMapOffsetFactors[GetCurrentRotation()];
+            Viewport* vp = mainWindow->viewport;
+            if (vp == nullptr)
+                return;
 
             // calculate centre view point of viewport and transform it to minimap coordinates
+            auto centreX = ((vp->ViewWidth() / 2) + vp->viewPos.x) / kCoordsXYStep;
+            auto centreY = ((vp->ViewHeight() / 2) + vp->viewPos.y) / kCoordsXYHalfTile;
 
-            cx = ((mainWindow->viewport->ViewWidth() / 2) + mainWindow->viewport->viewPos.x) / kCoordsXYStep;
-            dx = ((mainWindow->viewport->ViewHeight() / 2) + mainWindow->viewport->viewPos.y) / kCoordsXYHalfTile;
-            cx += offset.x * getPracticalMapSize();
-            dx += offset.y * getPracticalMapSize();
+            auto& offset = MiniMapOffsetFactors[GetCurrentRotation()];
+            centreX += offset.x * getPracticalMapSize();
+            centreY += offset.y * getPracticalMapSize();
 
             // calculate width and height of minimap
+            auto& widget = widgets[WIDX_MAP];
+            auto mapWidth = widget.width() - kScrollBarWidth - 1;
+            auto mapHeight = widget.height() - kScrollBarWidth - 1;
 
-            ax = widgets[WIDX_MAP].width() - 11;
-            bx = widgets[WIDX_MAP].height() - 11;
-            bp = ax;
-            di = bx;
+            centreX = std::max(centreX - (mapWidth >> 1), 0);
+            centreY = std::max(centreY - (mapHeight >> 1), 0);
 
-            ax >>= 1;
-            bx >>= 1;
-            cx = std::max(cx - ax, 0);
-            dx = std::max(dx - bx, 0);
+            mapWidth = scrolls[0].contentWidth - mapWidth;
+            mapHeight = scrolls[0].contentHeight - mapHeight;
 
-            bp = scrolls[0].contentWidth - bp;
-            di = scrolls[0].contentHeight - di;
+            if (mapWidth < 0 && (mapWidth - centreX) < 0)
+                centreX = 0;
 
-            if (bp < 0 && (bp - cx) < 0)
-                cx = 0;
+            if (mapHeight < 0 && (mapHeight - centreY) < 0)
+                centreY = 0;
 
-            if (di < 0 && (di - dx) < 0)
-                dx = 0;
-
-            scrolls[0].contentOffsetX = cx;
-            scrolls[0].contentOffsetY = dx;
-            WidgetScrollUpdateThumbs(*this, WIDX_MAP);
+            scrolls[0].contentOffsetX = centreX;
+            scrolls[0].contentOffsetY = centreY;
+            widgetScrollUpdateThumbs(*this, WIDX_MAP);
         }
 
         void IncreaseMapSize()
         {
-            auto newMapSize = GetGameState().MapSize;
+            auto newMapSize = getGameState().mapSize;
             if (IsWidgetPressed(WIDX_MAP_SIZE_LINK) || _resizeDirection == ResizeDirection::Y)
                 newMapSize.y++;
             if (IsWidgetPressed(WIDX_MAP_SIZE_LINK) || _resizeDirection == ResizeDirection::X)
                 newMapSize.x++;
 
-            auto increaseMapSizeAction = MapChangeSizeAction(newMapSize);
+            auto increaseMapSizeAction = GameActions::MapChangeSizeAction(newMapSize);
             GameActions::Execute(&increaseMapSizeAction);
         }
 
         void DecreaseMapSize()
         {
-            auto newMapSize = GetGameState().MapSize;
+            auto newMapSize = getGameState().mapSize;
             if (IsWidgetPressed(WIDX_MAP_SIZE_LINK) || _resizeDirection == ResizeDirection::Y)
                 newMapSize.y--;
             if (IsWidgetPressed(WIDX_MAP_SIZE_LINK) || _resizeDirection == ResizeDirection::X)
                 newMapSize.x--;
 
-            auto decreaseMapSizeAction = MapChangeSizeAction(newMapSize);
+            auto decreaseMapSizeAction = GameActions::MapChangeSizeAction(newMapSize);
             GameActions::Execute(&decreaseMapSizeAction);
         }
 
@@ -857,7 +849,7 @@ namespace OpenRCT2::Ui::Windows
             if (surfaceElement == nullptr)
                 return 0;
 
-            uint16_t colour = MapColour(PALETTE_INDEX_0);
+            uint16_t colour = MapColour(PaletteIndex::pi0);
             const auto* surfaceObject = surfaceElement->GetSurfaceObject();
             if (surfaceObject != nullptr)
                 colour = MapColour2(surfaceObject->MapColours[0], surfaceObject->MapColours[1]);
@@ -874,7 +866,7 @@ namespace OpenRCT2::Ui::Windows
             {
                 if (tileElement->IsGhost())
                 {
-                    colour = MapColour(PALETTE_INDEX_21);
+                    colour = MapColour(PaletteIndex::pi21);
                     break;
                 }
 
@@ -892,8 +884,8 @@ namespace OpenRCT2::Ui::Windows
 
         uint16_t GetPixelColourRide(const CoordsXY& c)
         {
-            uint16_t colourA = 0;                           // highlight colour
-            uint16_t colourB = MapColour(PALETTE_INDEX_13); // surface colour (dark grey)
+            uint16_t colourA = 0;                             // highlight colour
+            uint16_t colourB = MapColour(PaletteIndex::pi13); // surface colour (dark grey)
 
             // as an improvement we could use first_element to show underground stuff?
             TileElement* tileElement = reinterpret_cast<TileElement*>(MapGetSurfaceElementAt(c));
@@ -904,7 +896,7 @@ namespace OpenRCT2::Ui::Windows
 
                 if (tileElement->IsGhost())
                 {
-                    colourA = MapColour(PALETTE_INDEX_21);
+                    colourA = MapColour(PaletteIndex::pi21);
                     break;
                 }
 
@@ -913,12 +905,12 @@ namespace OpenRCT2::Ui::Windows
                     case TileElementType::Surface:
                         if (tileElement->AsSurface()->GetWaterHeight() > 0)
                             // Why is this a different water colour as above (195)?
-                            colourB = MapColour(PALETTE_INDEX_194);
+                            colourB = MapColour(PaletteIndex::pi194);
                         if (!(tileElement->AsSurface()->GetOwnership() & OWNERSHIP_OWNED))
                             colourB = MapColourUnowned(colourB);
                         break;
                     case TileElementType::Path:
-                        colourA = MapColour(PALETTE_INDEX_14); // lighter grey
+                        colourA = MapColour(PaletteIndex::pi14); // lighter grey
                         break;
                     case TileElementType::Entrance:
                     {
@@ -927,7 +919,7 @@ namespace OpenRCT2::Ui::Windows
                         Ride* targetRide = GetRide(tileElement->AsEntrance()->GetRideIndex());
                         if (targetRide != nullptr)
                         {
-                            const auto& colourKey = targetRide->GetRideTypeDescriptor().ColourKey;
+                            const auto& colourKey = targetRide->getRideTypeDescriptor().ColourKey;
                             colourA = RideKeyColours[EnumValue(colourKey)];
                         }
                         break;
@@ -937,7 +929,7 @@ namespace OpenRCT2::Ui::Windows
                         Ride* targetRide = GetRide(tileElement->AsTrack()->GetRideIndex());
                         if (targetRide != nullptr)
                         {
-                            const auto& colourKey = targetRide->GetRideTypeDescriptor().ColourKey;
+                            const auto& colourKey = targetRide->getRideTypeDescriptor().ColourKey;
                             colourA = RideKeyColours[EnumValue(colourKey)];
                         }
 
@@ -954,21 +946,21 @@ namespace OpenRCT2::Ui::Windows
             return colourB;
         }
 
-        void PaintPeepOverlay(DrawPixelInfo& dpi, const ScreenCoordsXY& offset)
+        void PaintPeepOverlay(RenderTarget& rt, const ScreenCoordsXY& offset)
         {
             auto flashColour = GetGuestFlashColour();
             for (auto guest : EntityList<Guest>())
             {
-                DrawMapPeepPixel(guest, flashColour, dpi, offset);
+                DrawMapPeepPixel(guest, flashColour, rt, offset);
             }
             flashColour = GetStaffFlashColour();
             for (auto staff : EntityList<Staff>())
             {
-                DrawMapPeepPixel(staff, flashColour, dpi, offset);
+                DrawMapPeepPixel(staff, flashColour, rt, offset);
             }
         }
 
-        void DrawMapPeepPixel(Peep* peep, const uint8_t flashColour, DrawPixelInfo& dpi, const ScreenCoordsXY& offset)
+        void DrawMapPeepPixel(Peep* peep, const uint8_t flashColour, RenderTarget& rt, const ScreenCoordsXY& offset)
         {
             if (peep->x == kLocationNull)
                 return;
@@ -987,7 +979,7 @@ namespace OpenRCT2::Ui::Windows
                 }
             }
 
-            GfxFillRect(dpi, { leftTop, rightBottom }, colour);
+            GfxFillRect(rt, { leftTop, rightBottom }, colour);
         }
 
         uint8_t GetGuestFlashColour() const
@@ -1014,7 +1006,7 @@ namespace OpenRCT2::Ui::Windows
             return colour;
         }
 
-        void PaintTrainOverlay(DrawPixelInfo& dpi, const ScreenCoordsXY& offset)
+        void PaintTrainOverlay(RenderTarget& rt, const ScreenCoordsXY& offset)
         {
             for (auto train : TrainManager::View())
             {
@@ -1026,7 +1018,7 @@ namespace OpenRCT2::Ui::Windows
                     auto mapCoord = TransformToMapCoords({ vehicle->x, vehicle->y });
                     auto pixelCoord = ScreenCoordsXY{ mapCoord.x, mapCoord.y } + offset;
 
-                    GfxFillRect(dpi, { pixelCoord, pixelCoord }, PALETTE_INDEX_171);
+                    GfxFillRect(rt, { pixelCoord, pixelCoord }, PaletteIndex::pi171);
                 }
             }
         }
@@ -1035,7 +1027,7 @@ namespace OpenRCT2::Ui::Windows
          * The call to GfxFillRect was originally wrapped in Sub68DABD which made sure that arguments were ordered correctly,
          * but it doesn't look like it's ever necessary here so the call was removed.
          */
-        void PaintHudRectangle(DrawPixelInfo& dpi, const ScreenCoordsXY& widgetOffset)
+        void PaintHudRectangle(RenderTarget& rt, const ScreenCoordsXY& widgetOffset)
         {
             WindowBase* mainWindow = WindowGetMain();
             if (mainWindow == nullptr)
@@ -1057,23 +1049,23 @@ namespace OpenRCT2::Ui::Windows
             auto leftBottom = ScreenCoordsXY{ leftTop.x, rightBottom.y };
 
             // top horizontal lines
-            GfxFillRect(dpi, { leftTop, leftTop + ScreenCoordsXY{ 3, 0 } }, PALETTE_INDEX_56);
-            GfxFillRect(dpi, { rightTop - ScreenCoordsXY{ 3, 0 }, rightTop }, PALETTE_INDEX_56);
+            GfxFillRect(rt, { leftTop, leftTop + ScreenCoordsXY{ 3, 0 } }, PaletteIndex::pi56);
+            GfxFillRect(rt, { rightTop - ScreenCoordsXY{ 3, 0 }, rightTop }, PaletteIndex::pi56);
 
             // left vertical lines
-            GfxFillRect(dpi, { leftTop, leftTop + ScreenCoordsXY{ 0, 3 } }, PALETTE_INDEX_56);
-            GfxFillRect(dpi, { leftBottom - ScreenCoordsXY{ 0, 3 }, leftBottom }, PALETTE_INDEX_56);
+            GfxFillRect(rt, { leftTop, leftTop + ScreenCoordsXY{ 0, 3 } }, PaletteIndex::pi56);
+            GfxFillRect(rt, { leftBottom - ScreenCoordsXY{ 0, 3 }, leftBottom }, PaletteIndex::pi56);
 
             // bottom horizontal lines
-            GfxFillRect(dpi, { leftBottom, leftBottom + ScreenCoordsXY{ 3, 0 } }, PALETTE_INDEX_56);
-            GfxFillRect(dpi, { rightBottom - ScreenCoordsXY{ 3, 0 }, rightBottom }, PALETTE_INDEX_56);
+            GfxFillRect(rt, { leftBottom, leftBottom + ScreenCoordsXY{ 3, 0 } }, PaletteIndex::pi56);
+            GfxFillRect(rt, { rightBottom - ScreenCoordsXY{ 3, 0 }, rightBottom }, PaletteIndex::pi56);
 
             // right vertical lines
-            GfxFillRect(dpi, { rightTop, rightTop + ScreenCoordsXY{ 0, 3 } }, PALETTE_INDEX_56);
-            GfxFillRect(dpi, { rightBottom - ScreenCoordsXY{ 0, 3 }, rightBottom }, PALETTE_INDEX_56);
+            GfxFillRect(rt, { rightTop, rightTop + ScreenCoordsXY{ 0, 3 } }, PaletteIndex::pi56);
+            GfxFillRect(rt, { rightBottom - ScreenCoordsXY{ 0, 3 }, rightBottom }, PaletteIndex::pi56);
         }
 
-        void DrawTabImages(DrawPixelInfo& dpi)
+        void DrawTabImages(RenderTarget& rt)
         {
             // Guest tab image (animated)
             uint32_t guestTabImage = SPR_TAB_GUESTS_0;
@@ -1081,7 +1073,7 @@ namespace OpenRCT2::Ui::Windows
                 guestTabImage += list_information_type / 4;
 
             GfxDrawSprite(
-                dpi, ImageId(guestTabImage),
+                rt, ImageId(guestTabImage),
                 windowPos + ScreenCoordsXY{ widgets[WIDX_PEOPLE_TAB].left, widgets[WIDX_PEOPLE_TAB].top });
 
             // Ride/stall tab image (animated)
@@ -1090,33 +1082,33 @@ namespace OpenRCT2::Ui::Windows
                 rideTabImage += list_information_type / 4;
 
             GfxDrawSprite(
-                dpi, ImageId(rideTabImage),
+                rt, ImageId(rideTabImage),
                 windowPos + ScreenCoordsXY{ widgets[WIDX_RIDES_TAB].left, widgets[WIDX_RIDES_TAB].top });
         }
 
         void ShowDefaultScenarioEditorButtons()
         {
-            widgets[WIDX_SET_LAND_RIGHTS].type = WindowWidgetType::FlatBtn;
-            widgets[WIDX_BUILD_PARK_ENTRANCE].type = WindowWidgetType::FlatBtn;
-            widgets[WIDX_PEOPLE_STARTING_POSITION].type = WindowWidgetType::FlatBtn;
+            widgets[WIDX_SET_LAND_RIGHTS].type = WidgetType::flatBtn;
+            widgets[WIDX_BUILD_PARK_ENTRANCE].type = WidgetType::flatBtn;
+            widgets[WIDX_PEOPLE_STARTING_POSITION].type = WidgetType::flatBtn;
 
             // Only show this in the scenario editor, even when in sandbox mode.
-            if (gScreenFlags & SCREEN_FLAGS_SCENARIO_EDITOR)
-                widgets[WIDX_MAP_GENERATOR].type = WindowWidgetType::FlatBtn;
+            if (gLegacyScene == LegacyScene::scenarioEditor)
+                widgets[WIDX_MAP_GENERATOR].type = WidgetType::flatBtn;
 
-            widgets[WIDX_MAP_SIZE_SPINNER_Y].type = WindowWidgetType::Spinner;
-            widgets[WIDX_MAP_SIZE_SPINNER_Y_UP].type = WindowWidgetType::Button;
-            widgets[WIDX_MAP_SIZE_SPINNER_Y_DOWN].type = WindowWidgetType::Button;
-            widgets[WIDX_MAP_SIZE_LINK].type = WindowWidgetType::FlatBtn;
-            widgets[WIDX_MAP_SIZE_SPINNER_X].type = WindowWidgetType::Spinner;
-            widgets[WIDX_MAP_SIZE_SPINNER_X_UP].type = WindowWidgetType::Button;
-            widgets[WIDX_MAP_SIZE_SPINNER_X_DOWN].type = WindowWidgetType::Button;
+            widgets[WIDX_MAP_SIZE_SPINNER_Y].type = WidgetType::spinner;
+            widgets[WIDX_MAP_SIZE_SPINNER_Y_UP].type = WidgetType::button;
+            widgets[WIDX_MAP_SIZE_SPINNER_Y_DOWN].type = WidgetType::button;
+            widgets[WIDX_MAP_SIZE_LINK].type = WidgetType::flatBtn;
+            widgets[WIDX_MAP_SIZE_SPINNER_X].type = WidgetType::spinner;
+            widgets[WIDX_MAP_SIZE_SPINNER_X_UP].type = WidgetType::button;
+            widgets[WIDX_MAP_SIZE_SPINNER_X_DOWN].type = WidgetType::button;
 
             // Push width (Y) and height (X) to the common formatter arguments for the map size spinners to use
-            auto& gameState = GetGameState();
+            auto& gameState = getGameState();
             auto ft = Formatter::Common();
-            ft.Add<uint16_t>(gameState.MapSize.y - 2);
-            ft.Add<uint16_t>(gameState.MapSize.x - 2);
+            ft.Add<uint16_t>(gameState.mapSize.y - 2);
+            ft.Add<uint16_t>(gameState.mapSize.x - 2);
         }
 
         void InputMapSize(WidgetIndex callingWidget)
@@ -1193,30 +1185,35 @@ namespace OpenRCT2::Ui::Windows
         void SetInitialWindowDimensions()
         {
             // The initial mini map size should be able to show a reasonably sized map
-            auto initSize = std::clamp(getPracticalMapSize(), 100, 254) * 2;
-            width = initSize + GetReservedRightSpace();
-            height = initSize + kReservedTopSpace + GetReservedBottomSpace();
+            auto initWidth = std::clamp(getPracticalMapSize(), 100, 254) * 2;
+            width = initWidth + GetReservedRightSpace();
 
-            auto scrollbarSize = getPracticalMapSize() > 254 ? kScrollBarWidth : 2;
-            width += scrollbarSize;
-            height += scrollbarSize;
+            auto initHeight = std::clamp(getMiniMapWidth(), 100, 254) * 2;
+            height = initHeight + kReservedTopSpace + GetReservedBottomSpace();
+
+            width += getPracticalMapSize() > initWidth ? kScrollBarWidth : 2;
+            height += getMiniMapWidth() > initHeight ? kScrollBarWidth : 2;
 
             auto maxWindowHeight = ContextGetHeight() - 68;
             width = std::min<int16_t>(width, ContextGetWidth());
             height = std::min<int16_t>(height, maxWindowHeight);
 
             _adjustedForSandboxMode = isEditorOrSandbox();
+
+            ResizeFrame();
         }
 
         void ResetMaxWindowDimensions()
         {
-            max_width = std::clamp(getMiniMapWidth() + GetReservedRightSpace(), WW, ContextGetWidth());
-            max_height = std::clamp(
-                getMiniMapWidth() + kReservedTopSpace + GetReservedBottomSpace(), WH, ContextGetHeight() - 68);
+            auto newMaxWidth = std::clamp(getMiniMapWidth() + GetReservedRightSpace(), kWindowSize.width, ContextGetWidth());
+            auto newMaxHeight = std::clamp(
+                getMiniMapWidth() + kReservedTopSpace + GetReservedBottomSpace(), kWindowSize.height, ContextGetHeight() - 68);
 
             auto scrollbarSize = getMiniMapWidth() + GetReservedRightSpace() > ContextGetWidth() ? kScrollBarWidth : 2;
-            max_width += scrollbarSize;
-            max_height += scrollbarSize;
+            newMaxWidth += scrollbarSize;
+            newMaxHeight += scrollbarSize;
+
+            WindowSetResize(*this, kWindowSize, { newMaxWidth, newMaxHeight });
         }
 
         void ResizeMiniMap()
@@ -1236,7 +1233,7 @@ namespace OpenRCT2::Ui::Windows
             }
 
             textOffset += _firstColumnWidth + 4;
-            min_width = WW;
+            min_width = kWindowSize.width;
             for (uint32_t i = 4; i < std::size(MapLabels); i++)
             {
                 const auto* labelStr = LanguageGetString(MapLabels[i]);
@@ -1253,7 +1250,7 @@ namespace OpenRCT2::Ui::Windows
         try
         {
             auto* windowMgr = GetWindowManager();
-            auto* w = windowMgr->FocusOrCreate<MapWindow>(WindowClass::Map, 245, 259, WF_10);
+            auto* w = windowMgr->FocusOrCreate<MapWindow>(WindowClass::Map, kWindowSize, WF_10);
             w->selected_tab = 0;
             w->list_information_type = 0;
             return w;
