@@ -61,49 +61,49 @@ namespace OpenRCT2::Ui::Windows
         WIDX_KNOWN_KEYS_ONLY_CHECKBOX,
     };
 
+    static constexpr ScreenSize kWindowSize = { 340, 240 };
     // clang-format off
 
-    #define MAIN_MULTIPLAYER_WIDGETS \
-        MakeWidget({  0,  0}, {340, 240}, WindowWidgetType::Frame,    WindowColour::Primary                                        ), /* panel / background */ \
-        MakeWidget({  1,  1}, {338,  14}, WindowWidgetType::Caption,  WindowColour::Primary,  kStringIdNone,    STR_WINDOW_TITLE_TIP    ), /* title bar */ \
-        MakeWidget({327,  2}, { 11,  12}, WindowWidgetType::CloseBox, WindowColour::Primary,  STR_CLOSE_X, STR_CLOSE_WINDOW_TIP    ), /* close x button */ \
-        MakeWidget({  0, 43}, {340, 197}, WindowWidgetType::Resize,   WindowColour::Secondary                                      ), /* content panel */ \
-        MakeTab   ({  3, 17},                                                                STR_SHOW_SERVER_INFO_TIP), /* tab */ \
-        MakeTab   ({ 34, 17},                                                                STR_PLAYERS_TIP         ), /* tab */ \
-        MakeTab   ({ 65, 17},                                                                STR_GROUPS_TIP          ), /* tab */ \
-        MakeTab   ({ 96, 17},                                                                STR_OPTIONS_TIP         )  /* tab */
+    static constexpr auto kMainMultiplayerWidgets = makeWidgets(
+        makeWindowShim(kStringIdNone, kWindowSize),
+        makeWidget({  0, 43}, {340, 197}, WidgetType::resize, WindowColour::secondary                          ),
+        makeTab   ({  3, 17},                                                          STR_SHOW_SERVER_INFO_TIP),
+        makeTab   ({ 34, 17},                                                          STR_PLAYERS_TIP         ),
+        makeTab   ({ 65, 17},                                                          STR_GROUPS_TIP          ),
+        makeTab   ({ 96, 17},                                                          STR_OPTIONS_TIP         )
+    );
 
-    static constexpr Widget window_multiplayer_information_widgets[] = {
-        MAIN_MULTIPLAYER_WIDGETS,
-    };
+    static constexpr auto window_multiplayer_information_widgets = makeWidgets(
+        kMainMultiplayerWidgets
+    );
 
-    static constexpr Widget window_multiplayer_players_widgets[] = {
-        MAIN_MULTIPLAYER_WIDGETS,
-        MakeWidget({  3, 46}, {173,  15}, WindowWidgetType::TableHeader, WindowColour::Primary  , STR_PLAYER     ), // Player name
-        MakeWidget({176, 46}, { 83,  15}, WindowWidgetType::TableHeader, WindowColour::Primary  , STR_GROUP      ), // Player name
-        MakeWidget({259, 46}, {100,  15}, WindowWidgetType::TableHeader, WindowColour::Primary  , STR_LAST_ACTION), // Player name
-        MakeWidget({359, 46}, { 42,  15}, WindowWidgetType::TableHeader, WindowColour::Primary  , STR_PING       ), // Player name
-        MakeWidget({  3, 60}, {334, 177}, WindowWidgetType::Scroll,       WindowColour::Secondary, SCROLL_VERTICAL), // list
-    };
+    static constexpr auto window_multiplayer_players_widgets = makeWidgets(
+        kMainMultiplayerWidgets,
+        makeWidget({  3, 46}, {173,  15}, WidgetType::tableHeader, WindowColour::primary  , STR_PLAYER     ), // Player name
+        makeWidget({176, 46}, { 83,  15}, WidgetType::tableHeader, WindowColour::primary  , STR_GROUP      ), // Player name
+        makeWidget({259, 46}, {100,  15}, WidgetType::tableHeader, WindowColour::primary  , STR_LAST_ACTION), // Player name
+        makeWidget({359, 46}, { 42,  15}, WidgetType::tableHeader, WindowColour::primary  , STR_PING       ), // Player name
+        makeWidget({  3, 60}, {334, 177}, WidgetType::scroll,      WindowColour::secondary, SCROLL_VERTICAL) // list
+    );
 
-    static constexpr Widget window_multiplayer_groups_widgets[] = {
-        MAIN_MULTIPLAYER_WIDGETS,
-        MakeWidget({141, 46}, {175,  12}, WindowWidgetType::DropdownMenu, WindowColour::Secondary                    ), // default group
-        MakeWidget({305, 47}, { 11,  10}, WindowWidgetType::Button,   WindowColour::Secondary, STR_DROPDOWN_GLYPH),
-        MakeWidget({ 11, 65}, { 92,  12}, WindowWidgetType::Button,   WindowColour::Secondary, STR_ADD_GROUP     ), // add group button
-        MakeWidget({113, 65}, { 92,  12}, WindowWidgetType::Button,   WindowColour::Secondary, STR_REMOVE_GROUP  ), // remove group button
-        MakeWidget({215, 65}, { 92,  12}, WindowWidgetType::Button,   WindowColour::Secondary, STR_RENAME_GROUP  ), // rename group button
-        MakeWidget({ 72, 80}, {175,  12}, WindowWidgetType::DropdownMenu, WindowColour::Secondary                    ), // selected group
-        MakeWidget({236, 81}, { 11,  10}, WindowWidgetType::Button,   WindowColour::Secondary, STR_DROPDOWN_GLYPH),
-        MakeWidget({  3, 94}, {314, 207}, WindowWidgetType::Scroll,   WindowColour::Secondary, SCROLL_VERTICAL   ), // permissions list
-    };
+    static constexpr auto window_multiplayer_groups_widgets = makeWidgets(
+        kMainMultiplayerWidgets,
+        makeWidget({141, 46}, {175,  12}, WidgetType::dropdownMenu, WindowColour::secondary                    ), // default group
+        makeWidget({305, 47}, { 11,  10}, WidgetType::button,       WindowColour::secondary, STR_DROPDOWN_GLYPH),
+        makeWidget({ 11, 65}, { 92,  12}, WidgetType::button,       WindowColour::secondary, STR_ADD_GROUP     ), // add group button
+        makeWidget({113, 65}, { 92,  12}, WidgetType::button,       WindowColour::secondary, STR_REMOVE_GROUP  ), // remove group button
+        makeWidget({215, 65}, { 92,  12}, WidgetType::button,       WindowColour::secondary, STR_RENAME_GROUP  ), // rename group button
+        makeWidget({ 72, 80}, {175,  12}, WidgetType::dropdownMenu, WindowColour::secondary                    ), // selected group
+        makeWidget({236, 81}, { 11,  10}, WidgetType::button,       WindowColour::secondary, STR_DROPDOWN_GLYPH),
+        makeWidget({  3, 94}, {314, 207}, WidgetType::scroll,       WindowColour::secondary, SCROLL_VERTICAL   ) // permissions list
+    );
 
-    static constexpr Widget window_multiplayer_options_widgets[] = {
-        MAIN_MULTIPLAYER_WIDGETS,
-        MakeWidget({3, 50}, {295, 12}, WindowWidgetType::Checkbox, WindowColour::Secondary, STR_LOG_CHAT,              STR_LOG_CHAT_TIP             ),
-        MakeWidget({3, 64}, {295, 12}, WindowWidgetType::Checkbox, WindowColour::Secondary, STR_LOG_SERVER_ACTIONS,    STR_LOG_SERVER_ACTIONS_TIP   ),
-        MakeWidget({3, 78}, {295, 12}, WindowWidgetType::Checkbox, WindowColour::Secondary, STR_ALLOW_KNOWN_KEYS_ONLY, STR_ALLOW_KNOWN_KEYS_ONLY_TIP),
-    };
+    static constexpr auto window_multiplayer_options_widgets = makeWidgets(
+        kMainMultiplayerWidgets,
+        makeWidget({3, 50}, {295, 12}, WidgetType::checkbox, WindowColour::secondary, STR_LOG_CHAT,              STR_LOG_CHAT_TIP             ),
+        makeWidget({3, 64}, {295, 12}, WidgetType::checkbox, WindowColour::secondary, STR_LOG_SERVER_ACTIONS,    STR_LOG_SERVER_ACTIONS_TIP   ),
+        makeWidget({3, 78}, {295, 12}, WidgetType::checkbox, WindowColour::secondary, STR_ALLOW_KNOWN_KEYS_ONLY, STR_ALLOW_KNOWN_KEYS_ONLY_TIP)
+    );
 
     static std::span<const Widget> window_multiplayer_page_widgets[] = {
         window_multiplayer_information_widgets,
@@ -142,24 +142,24 @@ namespace OpenRCT2::Ui::Windows
     class MultiplayerWindow final : public Window
     {
     private:
-        std::optional<ScreenCoordsXY> _windowInformationSize;
+        std::optional<ScreenSize> _windowInformationSize;
         uint8_t _selectedGroup{ 0 };
 
     private:
         void ResetPressedWidgets();
 
-        void InformationPaint(DrawPixelInfo& dpi);
-        void PlayersPaint(DrawPixelInfo& dpi);
-        void GroupsPaint(DrawPixelInfo& dpi);
+        void InformationPaint(RenderTarget& rt);
+        void PlayersPaint(RenderTarget& rt);
+        void GroupsPaint(RenderTarget& rt);
 
-        void DrawTabImage(DrawPixelInfo& dpi, int32_t page_number, int32_t spriteIndex);
-        void DrawTabImages(DrawPixelInfo& dpi);
+        void DrawTabImage(RenderTarget& rt, int32_t page_number, int32_t spriteIndex);
+        void DrawTabImages(RenderTarget& rt);
 
-        void PlayersScrollPaint(int32_t scrollIndex, DrawPixelInfo& dpi) const;
-        void GroupsScrollPaint(int32_t scrollIndex, DrawPixelInfo& dpi) const;
+        void PlayersScrollPaint(int32_t scrollIndex, RenderTarget& rt) const;
+        void GroupsScrollPaint(int32_t scrollIndex, RenderTarget& rt) const;
 
         void ShowGroupDropdown(WidgetIndex widgetIndex);
-        ScreenCoordsXY InformationGetSize();
+        ScreenSize InformationGetSize();
 
     public:
         void OnOpen() override;
@@ -170,7 +170,7 @@ namespace OpenRCT2::Ui::Windows
         void OnResize() override;
         void OnUpdate() override;
         void OnPrepareDraw() override;
-        void OnDraw(DrawPixelInfo& dpi) override;
+        void OnDraw(RenderTarget& rt) override;
 
         void OnDropdown(WidgetIndex widgetIndex, int32_t selectedIndex) override;
         void OnTextInput(WidgetIndex widgetIndex, std::string_view text) override;
@@ -179,7 +179,7 @@ namespace OpenRCT2::Ui::Windows
         ScreenSize OnScrollGetSize(int32_t scrollIndex) override;
         void OnScrollMouseDown(int32_t scrollIndex, const ScreenCoordsXY& screenCoords) override;
         void OnScrollMouseOver(int32_t scrollIndex, const ScreenCoordsXY& screenCoords) override;
-        void OnScrollDraw(int32_t scrollIndex, DrawPixelInfo& dpi) override;
+        void OnScrollDraw(int32_t scrollIndex, RenderTarget& rt) override;
     };
 
     WindowBase* MultiplayerOpen()
@@ -190,7 +190,7 @@ namespace OpenRCT2::Ui::Windows
         if (window == nullptr)
         {
             window = windowMgr->Create<MultiplayerWindow>(
-                WindowClass::Multiplayer, 320, 144, WF_10 | WF_RESIZABLE | WF_AUTO_POSITION);
+                WindowClass::Multiplayer, { 320, 144 }, WF_10 | WF_RESIZABLE | WF_AUTO_POSITION);
         }
 
         return window;
@@ -203,6 +203,10 @@ namespace OpenRCT2::Ui::Windows
 
     void MultiplayerWindow::SetPage(int32_t page_number)
     {
+        // Skip setting page if we're already on this page, unless we're initialising the window
+        if (page == page_number && !widgets.empty())
+            return;
+
         _windowInformationSize.reset();
 
         page = page_number;
@@ -246,13 +250,14 @@ namespace OpenRCT2::Ui::Windows
                 {
                     case WIDX_ADD_GROUP:
                     {
-                        auto networkModifyGroup = NetworkModifyGroupAction(ModifyGroupType::AddGroup);
+                        auto networkModifyGroup = GameActions::NetworkModifyGroupAction(GameActions::ModifyGroupType::AddGroup);
                         GameActions::Execute(&networkModifyGroup);
                         break;
                     }
                     case WIDX_REMOVE_GROUP:
                     {
-                        auto networkModifyGroup = NetworkModifyGroupAction(ModifyGroupType::RemoveGroup, _selectedGroup);
+                        auto networkModifyGroup = GameActions::NetworkModifyGroupAction(
+                            GameActions::ModifyGroupType::RemoveGroup, _selectedGroup);
                         GameActions::Execute(&networkModifyGroup);
                         break;
                     }
@@ -289,7 +294,7 @@ namespace OpenRCT2::Ui::Windows
         }
     }
 
-    ScreenCoordsXY MultiplayerWindow::InformationGetSize()
+    ScreenSize MultiplayerWindow::InformationGetSize()
     {
         assert(!_windowInformationSize.has_value());
 
@@ -342,12 +347,12 @@ namespace OpenRCT2::Ui::Windows
             case WINDOW_MULTIPLAYER_PAGE_INFORMATION:
             {
                 auto size = _windowInformationSize ? _windowInformationSize.value() : InformationGetSize();
-                WindowSetResize(*this, size.x, size.y, size.x, size.y);
+                WindowSetResize(*this, size, size);
                 break;
             }
             case WINDOW_MULTIPLAYER_PAGE_PLAYERS:
             {
-                WindowSetResize(*this, 420, 124, 500, 450);
+                WindowSetResize(*this, { 420, 124 }, { 500, 450 });
 
                 no_list_items = (IsServerPlayerInvisible() ? NetworkGetNumVisiblePlayers() : NetworkGetNumPlayers());
 
@@ -359,7 +364,7 @@ namespace OpenRCT2::Ui::Windows
             }
             case WINDOW_MULTIPLAYER_PAGE_GROUPS:
             {
-                WindowSetResize(*this, 320, 200, 320, 500);
+                WindowSetResize(*this, { 320, 200 }, { 320, 500 });
 
                 no_list_items = NetworkGetNumActions();
 
@@ -369,7 +374,7 @@ namespace OpenRCT2::Ui::Windows
             }
             case WINDOW_MULTIPLAYER_PAGE_OPTIONS:
             {
-                WindowSetResize(*this, 300, 100, 300, 100);
+                WindowSetResize(*this, { 300, 100 }, { 300, 100 });
                 break;
             }
         }
@@ -393,7 +398,6 @@ namespace OpenRCT2::Ui::Windows
     {
         ResetPressedWidgets();
         SetWidgetPressed(WIDX_TAB1 + page, true);
-        ResizeFrameWithPage();
         switch (page)
         {
             case WINDOW_MULTIPLAYER_PAGE_INFORMATION:
@@ -427,7 +431,7 @@ namespace OpenRCT2::Ui::Windows
 
                 if (NetworkGetMode() == NETWORK_MODE_CLIENT)
                 {
-                    widgets[WIDX_KNOWN_KEYS_ONLY_CHECKBOX].type = WindowWidgetType::Empty;
+                    widgets[WIDX_KNOWN_KEYS_ONLY_CHECKBOX].type = WidgetType::empty;
                 }
 
                 SetCheckboxValue(WIDX_LOG_CHAT_CHECKBOX, Config::Get().network.LogChat);
@@ -438,25 +442,25 @@ namespace OpenRCT2::Ui::Windows
         }
     }
 
-    void MultiplayerWindow::OnDraw(DrawPixelInfo& dpi)
+    void MultiplayerWindow::OnDraw(RenderTarget& rt)
     {
-        DrawWidgets(dpi);
-        DrawTabImages(dpi);
+        DrawWidgets(rt);
+        DrawTabImages(rt);
         switch (page)
         {
             case WINDOW_MULTIPLAYER_PAGE_INFORMATION:
             {
-                InformationPaint(dpi);
+                InformationPaint(rt);
                 break;
             }
             case WINDOW_MULTIPLAYER_PAGE_PLAYERS:
             {
-                PlayersPaint(dpi);
+                PlayersPaint(rt);
                 break;
             }
             case WINDOW_MULTIPLAYER_PAGE_GROUPS:
             {
-                GroupsPaint(dpi);
+                GroupsPaint(rt);
                 break;
             }
         }
@@ -477,8 +481,8 @@ namespace OpenRCT2::Ui::Windows
                 {
                     case WIDX_DEFAULT_GROUP_DROPDOWN:
                     {
-                        auto networkModifyGroup = NetworkModifyGroupAction(
-                            ModifyGroupType::SetDefault, NetworkGetGroupID(selectedIndex));
+                        auto networkModifyGroup = GameActions::NetworkModifyGroupAction(
+                            GameActions::ModifyGroupType::SetDefault, NetworkGetGroupID(selectedIndex));
                         GameActions::Execute(&networkModifyGroup);
                         break;
                     }
@@ -506,7 +510,8 @@ namespace OpenRCT2::Ui::Windows
                 if (text.empty())
                     return;
 
-                auto networkModifyGroup = NetworkModifyGroupAction(ModifyGroupType::SetName, _selectedGroup, std::string(text));
+                auto networkModifyGroup = GameActions::NetworkModifyGroupAction(
+                    GameActions::ModifyGroupType::SetName, _selectedGroup, std::string(text));
                 GameActions::Execute(&networkModifyGroup);
                 break;
             }
@@ -525,16 +530,15 @@ namespace OpenRCT2::Ui::Windows
 
         for (auto i = 0; i < NetworkGetNumGroups(); i++)
         {
-            gDropdownItems[i].Format = STR_OPTIONS_DROPDOWN_ITEM;
-            gDropdownItems[i].Args = reinterpret_cast<uintptr_t>(NetworkGetGroupName(i));
+            gDropdown.items[i] = Dropdown::MenuLabel(NetworkGetGroupName(i));
         }
         if (widget == &widgets[WIDX_DEFAULT_GROUP_DROPDOWN])
         {
-            Dropdown::SetChecked(NetworkGetGroupIndex(NetworkGetDefaultGroup()), true);
+            gDropdown.items[NetworkGetGroupIndex(NetworkGetDefaultGroup())].setChecked(true);
         }
         else if (widget == &widgets[WIDX_SELECTED_GROUP_DROPDOWN])
         {
-            Dropdown::SetChecked(NetworkGetGroupIndex(_selectedGroup), true);
+            gDropdown.items[NetworkGetGroupIndex(_selectedGroup)].setChecked(true);
         }
     }
 
@@ -631,8 +635,9 @@ namespace OpenRCT2::Ui::Windows
                 selected_list_item = index;
                 Invalidate();
 
-                auto networkModifyGroup = NetworkModifyGroupAction(
-                    ModifyGroupType::SetPermissions, _selectedGroup, "", index, PermissionState::Toggle);
+                auto networkModifyGroup = GameActions::NetworkModifyGroupAction(
+                    GameActions::ModifyGroupType::SetPermissions, _selectedGroup, "", index,
+                    GameActions::PermissionState::Toggle);
                 GameActions::Execute(&networkModifyGroup);
                 break;
             }
@@ -657,26 +662,26 @@ namespace OpenRCT2::Ui::Windows
         }
     }
 
-    void MultiplayerWindow::OnScrollDraw(int32_t scrollIndex, DrawPixelInfo& dpi)
+    void MultiplayerWindow::OnScrollDraw(int32_t scrollIndex, RenderTarget& rt)
     {
         switch (page)
         {
             case WINDOW_MULTIPLAYER_PAGE_PLAYERS:
-                PlayersScrollPaint(scrollIndex, dpi);
+                PlayersScrollPaint(scrollIndex, rt);
                 break;
 
             case WINDOW_MULTIPLAYER_PAGE_GROUPS:
-                GroupsScrollPaint(scrollIndex, dpi);
+                GroupsScrollPaint(scrollIndex, rt);
                 break;
         }
     }
 
-    void MultiplayerWindow::InformationPaint(DrawPixelInfo& dpi)
+    void MultiplayerWindow::InformationPaint(RenderTarget& rt)
     {
-        DrawPixelInfo clippedDPI;
-        if (ClipDrawPixelInfo(clippedDPI, dpi, windowPos, width, height))
+        RenderTarget clippedDPI;
+        if (ClipDrawPixelInfo(clippedDPI, rt, windowPos, width, height))
         {
-            auto screenCoords = ScreenCoordsXY{ 3, 50 };
+            auto screenCoords = ScreenCoordsXY{ 3, widgets[WIDX_CONTENT_PANEL].top + 7 };
             int32_t newWidth = width - 6;
 
             const auto& name = NetworkGetServerName();
@@ -724,17 +729,17 @@ namespace OpenRCT2::Ui::Windows
         }
     }
 
-    void MultiplayerWindow::PlayersPaint(DrawPixelInfo& dpi)
+    void MultiplayerWindow::PlayersPaint(RenderTarget& rt)
     {
         // Number of players
         StringId stringId = no_list_items == 1 ? STR_MULTIPLAYER_PLAYER_COUNT : STR_MULTIPLAYER_PLAYER_COUNT_PLURAL;
         auto screenCoords = windowPos + ScreenCoordsXY{ 4, widgets[WIDX_LIST].bottom + 2 };
         auto ft = Formatter();
         ft.Add<uint16_t>(no_list_items);
-        DrawTextBasic(dpi, screenCoords, stringId, ft, { colours[2] });
+        DrawTextBasic(rt, screenCoords, stringId, ft, { colours[2] });
     }
 
-    void MultiplayerWindow::PlayersScrollPaint(int32_t scrollIndex, DrawPixelInfo& dpi) const
+    void MultiplayerWindow::PlayersScrollPaint(int32_t scrollIndex, RenderTarget& rt) const
     {
         ScreenCoordsXY screenCoords;
         screenCoords.y = 0;
@@ -744,12 +749,12 @@ namespace OpenRCT2::Ui::Windows
 
         for (int32_t player = firstPlayerInList; player < NetworkGetNumPlayers(); player++)
         {
-            if (screenCoords.y > dpi.y + dpi.height)
+            if (screenCoords.y > rt.y + rt.height)
             {
                 break;
             }
 
-            if (screenCoords.y + kScrollableRowHeight + 1 >= dpi.y)
+            if (screenCoords.y + kScrollableRowHeight + 1 >= rt.y)
             {
                 thread_local std::string _buffer;
                 _buffer.reserve(512);
@@ -760,7 +765,7 @@ namespace OpenRCT2::Ui::Windows
                 if (listPosition == selected_list_item)
                 {
                     GfxFilterRect(
-                        dpi, { 0, screenCoords.y, 800, screenCoords.y + kScrollableRowHeight - 1 },
+                        rt, { 0, screenCoords.y, 800, screenCoords.y + kScrollableRowHeight - 1 },
                         FilterPaletteID::PaletteDarken1);
                     _buffer += NetworkGetPlayerName(player);
                     colour = colours[2];
@@ -779,7 +784,7 @@ namespace OpenRCT2::Ui::Windows
                 }
                 screenCoords.x = 0;
                 GfxClipString(_buffer.data(), 230, FontStyle::Medium);
-                DrawText(dpi, screenCoords, { colour }, _buffer.c_str());
+                DrawText(rt, screenCoords, { colour }, _buffer.c_str());
 
                 // Draw group name
                 _buffer.resize(0);
@@ -790,7 +795,7 @@ namespace OpenRCT2::Ui::Windows
                     screenCoords.x = 173;
                     _buffer += NetworkGetGroupName(group);
                     GfxClipString(_buffer.data(), 80, FontStyle::Medium);
-                    DrawText(dpi, screenCoords, { colour }, _buffer.c_str());
+                    DrawText(rt, screenCoords, { colour }, _buffer.c_str());
                 }
 
                 // Draw last action
@@ -804,7 +809,7 @@ namespace OpenRCT2::Ui::Windows
                 {
                     ft.Add<StringId>(STR_ACTION_NA);
                 }
-                DrawTextEllipsised(dpi, { 256, screenCoords.y }, 100, STR_BLACK_STRING, ft);
+                DrawTextEllipsised(rt, { 256, screenCoords.y }, 100, STR_BLACK_STRING, ft);
 
                 // Draw ping
                 _buffer.resize(0);
@@ -827,14 +832,14 @@ namespace OpenRCT2::Ui::Windows
                 _buffer += pingBuffer;
 
                 screenCoords.x = 356;
-                DrawText(dpi, screenCoords, { colour }, _buffer.c_str());
+                DrawText(rt, screenCoords, { colour }, _buffer.c_str());
             }
             screenCoords.y += kScrollableRowHeight;
             listPosition++;
         }
     }
 
-    void MultiplayerWindow::GroupsPaint(DrawPixelInfo& dpi)
+    void MultiplayerWindow::GroupsPaint(RenderTarget& rt)
     {
         thread_local std::string _buffer;
 
@@ -848,19 +853,19 @@ namespace OpenRCT2::Ui::Windows
             auto ft = Formatter();
             ft.Add<const char*>(_buffer.c_str());
             DrawTextEllipsised(
-                dpi, windowPos + ScreenCoordsXY{ widget->midX() - 5, widget->top }, widget->width() - 8, STR_STRING, ft,
+                rt, windowPos + ScreenCoordsXY{ widget->midX() - 5, widget->top }, widget->width() - 8, STR_STRING, ft,
                 { TextAlignment::CENTRE });
         }
 
         auto screenPos = windowPos
             + ScreenCoordsXY{ widgets[WIDX_CONTENT_PANEL].left + 4, widgets[WIDX_CONTENT_PANEL].top + 4 };
 
-        DrawTextBasic(dpi, screenPos, STR_DEFAULT_GROUP, {}, { colours[2] });
+        DrawTextBasic(rt, screenPos, STR_DEFAULT_GROUP, {}, { colours[2] });
 
         screenPos.y += 20;
 
         GfxFillRectInset(
-            dpi, { screenPos - ScreenCoordsXY{ 0, 6 }, screenPos + ScreenCoordsXY{ 310, -5 } }, colours[1],
+            rt, { screenPos - ScreenCoordsXY{ 0, 6 }, screenPos + ScreenCoordsXY{ 310, -5 } }, colours[1],
             INSET_RECT_FLAG_BORDER_INSET);
 
         widget = &widgets[WIDX_SELECTED_GROUP];
@@ -872,18 +877,18 @@ namespace OpenRCT2::Ui::Windows
             auto ft = Formatter();
             ft.Add<const char*>(_buffer.c_str());
             DrawTextEllipsised(
-                dpi, windowPos + ScreenCoordsXY{ widget->midX() - 5, widget->top }, widget->width() - 8, STR_STRING, ft,
+                rt, windowPos + ScreenCoordsXY{ widget->midX() - 5, widget->top }, widget->width() - 8, STR_STRING, ft,
                 { TextAlignment::CENTRE });
         }
     }
 
-    void MultiplayerWindow::GroupsScrollPaint(int32_t scrollIndex, DrawPixelInfo& dpi) const
+    void MultiplayerWindow::GroupsScrollPaint(int32_t scrollIndex, RenderTarget& rt) const
     {
         auto screenCoords = ScreenCoordsXY{ 0, 0 };
 
-        auto dpiCoords = ScreenCoordsXY{ dpi.x, dpi.y };
+        auto rtCoords = ScreenCoordsXY{ rt.x, rt.y };
         GfxFillRect(
-            dpi, { dpiCoords, dpiCoords + ScreenCoordsXY{ dpi.width - 1, dpi.height - 1 } },
+            rt, { rtCoords, rtCoords + ScreenCoordsXY{ rt.width - 1, rt.height - 1 } },
             ColourMapA[colours[1].colour].mid_light);
 
         for (int32_t i = 0; i < NetworkGetNumActions(); i++)
@@ -891,15 +896,14 @@ namespace OpenRCT2::Ui::Windows
             if (i == selected_list_item)
             {
                 GfxFilterRect(
-                    dpi, { 0, screenCoords.y, 800, screenCoords.y + kScrollableRowHeight - 1 },
-                    FilterPaletteID::PaletteDarken1);
+                    rt, { 0, screenCoords.y, 800, screenCoords.y + kScrollableRowHeight - 1 }, FilterPaletteID::PaletteDarken1);
             }
-            if (screenCoords.y > dpi.y + dpi.height)
+            if (screenCoords.y > rt.y + rt.height)
             {
                 break;
             }
 
-            if (screenCoords.y + kScrollableRowHeight + 1 >= dpi.y)
+            if (screenCoords.y + kScrollableRowHeight + 1 >= rt.y)
             {
                 int32_t groupindex = NetworkGetGroupIndex(_selectedGroup);
                 if (groupindex != -1)
@@ -907,20 +911,20 @@ namespace OpenRCT2::Ui::Windows
                     if (NetworkCanPerformAction(groupindex, static_cast<NetworkPermission>(i)))
                     {
                         screenCoords.x = 0;
-                        DrawText(dpi, screenCoords, {}, u8"{WINDOW_COLOUR_2}✓");
+                        DrawText(rt, screenCoords, {}, u8"{WINDOW_COLOUR_2}✓");
                     }
                 }
 
                 // Draw action name
                 auto ft = Formatter();
                 ft.Add<uint16_t>(NetworkGetActionNameStringID(i));
-                DrawTextBasic(dpi, { 10, screenCoords.y }, STR_WINDOW_COLOUR_2_STRINGID, ft);
+                DrawTextBasic(rt, { 10, screenCoords.y }, STR_WINDOW_COLOUR_2_STRINGID, ft);
             }
             screenCoords.y += kScrollableRowHeight;
         }
     }
 
-    void MultiplayerWindow::DrawTabImage(DrawPixelInfo& dpi, int32_t page_number, int32_t spriteIndex)
+    void MultiplayerWindow::DrawTabImage(RenderTarget& rt, int32_t page_number, int32_t spriteIndex)
     {
         WidgetIndex widgetIndex = WIDX_TAB1 + page_number;
 
@@ -937,15 +941,15 @@ namespace OpenRCT2::Ui::Windows
             }
 
             GfxDrawSprite(
-                dpi, ImageId(spriteIndex), windowPos + ScreenCoordsXY{ widgets[widgetIndex].left, widgets[widgetIndex].top });
+                rt, ImageId(spriteIndex), windowPos + ScreenCoordsXY{ widgets[widgetIndex].left, widgets[widgetIndex].top });
         }
     }
 
-    void MultiplayerWindow::DrawTabImages(DrawPixelInfo& dpi)
+    void MultiplayerWindow::DrawTabImages(RenderTarget& rt)
     {
-        DrawTabImage(dpi, WINDOW_MULTIPLAYER_PAGE_INFORMATION, SPR_TAB_KIOSKS_AND_FACILITIES_0);
-        DrawTabImage(dpi, WINDOW_MULTIPLAYER_PAGE_PLAYERS, SPR_TAB_GUESTS_0);
-        DrawTabImage(dpi, WINDOW_MULTIPLAYER_PAGE_GROUPS, SPR_TAB_STAFF_OPTIONS_0);
-        DrawTabImage(dpi, WINDOW_MULTIPLAYER_PAGE_OPTIONS, SPR_TAB_GEARS_0);
+        DrawTabImage(rt, WINDOW_MULTIPLAYER_PAGE_INFORMATION, SPR_TAB_KIOSKS_AND_FACILITIES_0);
+        DrawTabImage(rt, WINDOW_MULTIPLAYER_PAGE_PLAYERS, SPR_TAB_GUESTS_0);
+        DrawTabImage(rt, WINDOW_MULTIPLAYER_PAGE_GROUPS, SPR_TAB_STAFF_OPTIONS_0);
+        DrawTabImage(rt, WINDOW_MULTIPLAYER_PAGE_OPTIONS, SPR_TAB_GEARS_0);
     }
 } // namespace OpenRCT2::Ui::Windows
