@@ -13,17 +13,23 @@
 #include <openrct2-ui/interface/Widget.h>
 #include <openrct2-ui/windows/Windows.h>
 #include <openrct2/Context.h>
+#include <openrct2/Diagnostic.h>
+#include <openrct2/FileClassifier.h>
+#include <openrct2/ParkImporter.h>
 #include <openrct2/SpriteIds.h>
 #include <openrct2/audio/Audio.h>
 #include <openrct2/config/Config.h>
-#include <openrct2/core/String.hpp>
+#include <openrct2/core/FileStream.h>
 #include <openrct2/drawing/Drawing.h>
 #include <openrct2/localisation/Formatter.h>
 #include <openrct2/localisation/Formatting.h>
-#include <openrct2/localisation/Localisation.Date.h>
 #include <openrct2/localisation/LocalisationService.h>
+#include <openrct2/object/ObjectManager.h>
+#include <openrct2/object/ScenarioMetaObject.h>
+#include <openrct2/park/ParkPreview.h>
 #include <openrct2/ride/RideData.h>
 #include <openrct2/scenario/Scenario.h>
+#include <openrct2/scenario/ScenarioCategory.h>
 #include <openrct2/scenario/ScenarioRepository.h>
 #include <openrct2/scenario/ScenarioSources.h>
 #include <openrct2/ui/WindowManager.h>
@@ -31,17 +37,18 @@
 
 namespace OpenRCT2::Ui::Windows
 {
-    static constexpr StringId kWindowTitle = STR_SELECT_SCENARIO;
-    static constexpr int32_t kWindowWidth = 734;
-    static constexpr int32_t kWindowHeight = 384;
-    static constexpr int32_t kSidebarWidth = 180;
-    static constexpr int32_t kTabWidth = 92;
+    static constexpr int32_t kInitialNumUnlockedScenarios = 5;
+    static constexpr uint8_t kNumTabs = 10;
+    static constexpr uint8_t kPadding = 5;
+    static constexpr int32_t kPreviewPaneWidthRegular = 180;
+    static constexpr int32_t kPreviewPaneWidthScreenshots = 254;
     static constexpr int32_t kTabHeight = 34;
-    static constexpr int32_t kTrueFontSize = 24;
     static constexpr int32_t kWidgetsStart = 17;
     static constexpr int32_t kTabsStart = kWidgetsStart;
-    static constexpr int32_t kInitialNumUnlockedScenarios = 5;
-    constexpr uint8_t kNumTabs = 10;
+    static constexpr int32_t kTabWidth = 92;
+    static constexpr int32_t kTrueFontSize = 24;
+    static constexpr ScreenSize kWindowSize = { 734, 384 };
+    static constexpr StringId kWindowTitle = STR_SELECT_SCENARIO;
 
     enum class ListItemType : uint8_t
     {
@@ -93,21 +100,21 @@ namespace OpenRCT2::Ui::Windows
     };
 
     // clang-format off
-    static constexpr Widget _scenarioSelectWidgets[] = {
-        WINDOW_SHIM(kWindowTitle, kWindowWidth, kWindowHeight),
-        MakeWidget({ kTabWidth + 1, kWidgetsStart }, { kWindowWidth, 284 }, WindowWidgetType::Resize, WindowColour::Secondary), // tab content panel
-        MakeRemapWidget({ 3, kTabsStart + (kTabHeight * 0) }, { kTabWidth, kTabHeight}, WindowWidgetType::Tab, WindowColour::Secondary, SPR_G2_SIDEWAYS_TAB), // tab 01
-        MakeRemapWidget({ 3, kTabsStart + (kTabHeight * 1) }, { kTabWidth, kTabHeight}, WindowWidgetType::Tab, WindowColour::Secondary, SPR_G2_SIDEWAYS_TAB), // tab 02
-        MakeRemapWidget({ 3, kTabsStart + (kTabHeight * 2) }, { kTabWidth, kTabHeight}, WindowWidgetType::Tab, WindowColour::Secondary, SPR_G2_SIDEWAYS_TAB), // tab 03
-        MakeRemapWidget({ 3, kTabsStart + (kTabHeight * 3) }, { kTabWidth, kTabHeight}, WindowWidgetType::Tab, WindowColour::Secondary, SPR_G2_SIDEWAYS_TAB), // tab 04
-        MakeRemapWidget({ 3, kTabsStart + (kTabHeight * 4) }, { kTabWidth, kTabHeight}, WindowWidgetType::Tab, WindowColour::Secondary, SPR_G2_SIDEWAYS_TAB), // tab 05
-        MakeRemapWidget({ 3, kTabsStart + (kTabHeight * 5) }, { kTabWidth, kTabHeight}, WindowWidgetType::Tab, WindowColour::Secondary, SPR_G2_SIDEWAYS_TAB), // tab 06
-        MakeRemapWidget({ 3, kTabsStart + (kTabHeight * 6) }, { kTabWidth, kTabHeight}, WindowWidgetType::Tab, WindowColour::Secondary, SPR_G2_SIDEWAYS_TAB), // tab 07
-        MakeRemapWidget({ 3, kTabsStart + (kTabHeight * 7) }, { kTabWidth, kTabHeight}, WindowWidgetType::Tab, WindowColour::Secondary, SPR_G2_SIDEWAYS_TAB), // tab 08
-        MakeRemapWidget({ 3, kTabsStart + (kTabHeight * 8) }, { kTabWidth, kTabHeight}, WindowWidgetType::Tab, WindowColour::Secondary, SPR_G2_SIDEWAYS_TAB), // tab 09
-        MakeRemapWidget({ 3, kTabsStart + (kTabHeight * 8) }, { kTabWidth, kTabHeight}, WindowWidgetType::Tab, WindowColour::Secondary, SPR_G2_SIDEWAYS_TAB), // tab 10
-        MakeWidget({ kTabWidth + 3, kWidgetsStart + 1 }, { kWindowWidth - kSidebarWidth, 362 }, WindowWidgetType::Scroll, WindowColour::Secondary, SCROLL_VERTICAL), // level list
-    };
+    static constexpr auto _scenarioSelectWidgets = makeWidgets(
+        makeWindowShim(kWindowTitle, kWindowSize),
+        makeWidget({ kTabWidth + 1, kWidgetsStart }, { kWindowSize.width, 284 },         WidgetType::resize, WindowColour::secondary                     ), // tab content panel
+        makeRemapWidget({ 3, kTabsStart + (kTabHeight * 0) }, { kTabWidth, kTabHeight }, WidgetType::tab,    WindowColour::secondary, SPR_G2_SIDEWAYS_TAB), // tab 01
+        makeRemapWidget({ 3, kTabsStart + (kTabHeight * 1) }, { kTabWidth, kTabHeight }, WidgetType::tab,    WindowColour::secondary, SPR_G2_SIDEWAYS_TAB), // tab 02
+        makeRemapWidget({ 3, kTabsStart + (kTabHeight * 2) }, { kTabWidth, kTabHeight }, WidgetType::tab,    WindowColour::secondary, SPR_G2_SIDEWAYS_TAB), // tab 03
+        makeRemapWidget({ 3, kTabsStart + (kTabHeight * 3) }, { kTabWidth, kTabHeight }, WidgetType::tab,    WindowColour::secondary, SPR_G2_SIDEWAYS_TAB), // tab 04
+        makeRemapWidget({ 3, kTabsStart + (kTabHeight * 4) }, { kTabWidth, kTabHeight }, WidgetType::tab,    WindowColour::secondary, SPR_G2_SIDEWAYS_TAB), // tab 05
+        makeRemapWidget({ 3, kTabsStart + (kTabHeight * 5) }, { kTabWidth, kTabHeight }, WidgetType::tab,    WindowColour::secondary, SPR_G2_SIDEWAYS_TAB), // tab 06
+        makeRemapWidget({ 3, kTabsStart + (kTabHeight * 6) }, { kTabWidth, kTabHeight }, WidgetType::tab,    WindowColour::secondary, SPR_G2_SIDEWAYS_TAB), // tab 07
+        makeRemapWidget({ 3, kTabsStart + (kTabHeight * 7) }, { kTabWidth, kTabHeight }, WidgetType::tab,    WindowColour::secondary, SPR_G2_SIDEWAYS_TAB), // tab 08
+        makeRemapWidget({ 3, kTabsStart + (kTabHeight * 8) }, { kTabWidth, kTabHeight }, WidgetType::tab,    WindowColour::secondary, SPR_G2_SIDEWAYS_TAB), // tab 09
+        makeRemapWidget({ 3, kTabsStart + (kTabHeight * 8) }, { kTabWidth, kTabHeight }, WidgetType::tab,    WindowColour::secondary, SPR_G2_SIDEWAYS_TAB), // tab 10
+        makeWidget({ kTabWidth + 3, kWidgetsStart + 1 }, { kWindowSize.width - kPreviewPaneWidthRegular, 362 }, WidgetType::scroll, WindowColour::secondary, SCROLL_VERTICAL    ) // level list
+    );
     // clang-format on
 
     class ScenarioSelectWindow final : public Window
@@ -117,6 +124,8 @@ namespace OpenRCT2::Ui::Windows
         std::function<void(std::string_view)> _callback;
         std::vector<ScenarioListItem> _listItems;
         const ScenarioIndexEntry* _highlightedScenario = nullptr;
+        ParkPreview _preview;
+        BackgroundWorker::Job _previewLoadJob;
 
     public:
         ScenarioSelectWindow(std::function<void(std::string_view)> callback)
@@ -137,6 +146,13 @@ namespace OpenRCT2::Ui::Windows
             InitScrollWidgets();
         }
 
+        void OnLanguageChange() override
+        {
+            _listItems.clear();
+            ScenarioRepositoryScan();
+            InitialiseListItems();
+        }
+
         void OnMouseUp(WidgetIndex widgetIndex) override
         {
             if (widgetIndex == WIDX_CLOSE)
@@ -150,9 +166,12 @@ namespace OpenRCT2::Ui::Windows
             if (widgetIndex >= WIDX_TAB1 && widgetIndex <= WIDX_TAB10)
             {
                 selected_tab = widgetIndex - 4;
-                _highlightedScenario = nullptr;
-                Config::Get().interface.ScenarioselectLastTab = selected_tab;
+                Config::Get().interface.scenarioSelectLastTab = selected_tab;
                 Config::Save();
+
+                _highlightedScenario = nullptr;
+                _preview = {};
+
                 InitialiseListItems();
                 Invalidate();
                 OnResize();
@@ -162,11 +181,124 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void OnDraw(DrawPixelInfo& dpi) override
+        int32_t GetPreviewPaneWidth() const
         {
-            const ScenarioIndexEntry* scenario;
+            if (Config::Get().interface.scenarioPreviewScreenshots)
+                return kPreviewPaneWidthScreenshots;
+            else
+                return kPreviewPaneWidthRegular;
+        }
 
-            DrawWidgets(dpi);
+        void LoadPreview()
+        {
+            _preview = {};
+
+            if (_highlightedScenario == nullptr)
+                return;
+
+            if (_previewLoadJob.isValid())
+                _previewLoadJob.cancel();
+
+            auto& bgWorker = GetContext()->GetBackgroundWorker();
+            auto& path = _highlightedScenario->Path;
+            auto& name = _highlightedScenario->InternalName;
+
+            ClassifiedFileInfo info;
+            bool isClassified = TryClassifyFile(path, &info);
+
+            if (isClassified && info.Type == FileType::park)
+            {
+                _previewLoadJob = bgWorker.addJob(
+                    [path, name]() {
+                        try
+                        {
+                            auto fs = FileStream(path, FileMode::open);
+                            auto& objectRepository = GetContext()->GetObjectRepository();
+                            auto parkImporter = ParkImporter::CreateParkFile(objectRepository);
+                            parkImporter->LoadFromStream(&fs, false, true, path.c_str());
+                            return parkImporter->GetParkPreview();
+                        }
+                        catch (const std::exception& e)
+                        {
+                            LOG_ERROR("Could not get preview for \"%s\" due to %s", path.c_str(), e.what());
+                            return ParkPreview{};
+                        }
+                    },
+                    [](const ParkPreview preview) {
+                        auto* windowMgr = GetWindowManager();
+                        auto* wnd = windowMgr->FindByClass(WindowClass::ScenarioSelect);
+                        if (wnd == nullptr)
+                        {
+                            return;
+                        }
+                        auto* scenarioSelectWnd = static_cast<ScenarioSelectWindow*>(wnd);
+                        scenarioSelectWnd->UpdateParkPreview(preview);
+                    });
+            }
+            else
+            {
+                SourceDescriptor source{};
+                if (!ScenarioSources::TryGetByName(name, &source))
+                    return;
+
+                auto& objManager = GetContext()->GetObjectManager();
+                if (auto obj = objManager.LoadTempObject(source.textObjectId); obj != nullptr)
+                {
+                    auto& scenarioMetaObj = reinterpret_cast<ScenarioMetaObject&>(*obj);
+                    scenarioMetaObj.Load();
+
+                    ParkPreview preview{};
+                    preview.images.push_back(scenarioMetaObj.GetMiniMapImage());
+                    preview.images.push_back(scenarioMetaObj.GetPreviewImage());
+                    _preview = preview;
+
+                    scenarioMetaObj.Unload();
+                }
+            }
+        }
+
+        void UpdateParkPreview(const ParkPreview& preview)
+        {
+            _preview = preview;
+            Invalidate();
+        }
+
+        ScreenCoordsXY DrawPreview(RenderTarget& rt, ScreenCoordsXY screenPos)
+        {
+            auto targetImageType = PreviewImageType::miniMap;
+            if (Config::Get().interface.scenarioPreviewScreenshots)
+                targetImageType = PreviewImageType::screenshot;
+
+            // Find minimap image to draw, if available
+            PreviewImage* image = nullptr;
+            for (auto& candidate : _preview.images)
+            {
+                if (candidate.type == targetImageType)
+                {
+                    image = &candidate;
+                    break;
+                }
+            }
+
+            if (image == nullptr)
+                return screenPos;
+
+            // Draw frame
+            auto startFrameX = width - (GetPreviewPaneWidth() / 2) - (image->width / 2) - kPadding;
+            auto frameStartPos = ScreenCoordsXY(windowPos.x + startFrameX, screenPos.y + 15);
+            auto frameEndPos = frameStartPos + ScreenCoordsXY(image->width + 1, image->height + 1);
+            GfxFillRectInset(rt, { frameStartPos, frameEndPos }, colours[1], INSET_RECT_F_60 | INSET_RECT_FLAG_FILL_MID_LIGHT);
+
+            // Draw image, if available
+            auto imagePos = frameStartPos + ScreenCoordsXY(1, 1);
+            drawPreviewImage(*image, rt, imagePos);
+
+            return frameEndPos;
+        }
+
+        void OnDraw(RenderTarget& rt) override
+        {
+            DrawWidgets(rt);
 
             StringId format = STR_WINDOW_COLOUR_2_STRINGID;
             FontStyle fontStyle = FontStyle::Medium;
@@ -181,25 +313,20 @@ namespace OpenRCT2::Ui::Windows
             for (uint32_t i = 0; i < std::size(kScenarioOriginStringIds); i++)
             {
                 const Widget& widget = widgets[WIDX_TAB1 + i];
-                if (widget.type == WindowWidgetType::Empty)
+                if (widget.type == WidgetType::empty)
                     continue;
 
                 auto ft = Formatter();
-                if (Config::Get().general.ScenarioSelectMode == SCENARIO_SELECT_MODE_ORIGIN)
-                {
-                    ft.Add<StringId>(kScenarioOriginStringIds[i]);
-                }
-                else
-                { // old-style
-                    ft.Add<StringId>(kScenarioCategoryStringIds[i]);
-                }
+                ft.Add<StringId>(kScenarioOriginStringIds[i]);
 
                 auto stringCoords = windowPos + ScreenCoordsXY{ widget.midX(), widget.midY() - 3 };
-                DrawTextWrapped(dpi, stringCoords, 87, format, ft, { COLOUR_AQUAMARINE, fontStyle, TextAlignment::CENTRE });
+                DrawTextWrapped(rt, stringCoords, 87, format, ft, { COLOUR_AQUAMARINE, fontStyle, TextAlignment::CENTRE });
             }
 
+            auto previewPaneWidth = GetPreviewPaneWidth();
+
             // Return if no scenario highlighted
-            scenario = _highlightedScenario;
+            auto* scenario = _highlightedScenario;
             if (scenario == nullptr)
             {
                 if (_showLockedInformation)
@@ -208,9 +335,10 @@ namespace OpenRCT2::Ui::Windows
                     auto screenPos = windowPos
                         + ScreenCoordsXY{ widgets[WIDX_SCENARIOLIST].right + 4, widgets[WIDX_TABCONTENT].top + 5 };
                     DrawTextEllipsised(
-                        dpi, screenPos + ScreenCoordsXY{ 85, 0 }, 170, STR_SCENARIO_LOCKED, {}, { TextAlignment::CENTRE });
+                        rt, screenPos + ScreenCoordsXY{ previewPaneWidth / 2, 0 }, previewPaneWidth, STR_SCENARIO_LOCKED, {},
+                        { TextAlignment::CENTRE });
 
-                    DrawTextWrapped(dpi, screenPos + ScreenCoordsXY{ 0, 15 }, 170, STR_SCENARIO_LOCKED_DESC);
+                    DrawTextWrapped(rt, screenPos + ScreenCoordsXY{ 0, 15 }, previewPaneWidth, STR_SCENARIO_LOCKED_DESC);
                 }
                 else
                 {
@@ -218,7 +346,7 @@ namespace OpenRCT2::Ui::Windows
                     auto screenPos = windowPos
                         + ScreenCoordsXY{ widgets[WIDX_SCENARIOLIST].right + 4, widgets[WIDX_TABCONTENT].top + 5 };
 
-                    DrawTextWrapped(dpi, screenPos + ScreenCoordsXY{ 0, 15 }, 170, STR_SCENARIO_HOVER_HINT);
+                    DrawTextWrapped(rt, screenPos + ScreenCoordsXY{ 0, 15 }, previewPaneWidth, STR_SCENARIO_HOVER_HINT);
                 }
                 return;
             }
@@ -230,8 +358,7 @@ namespace OpenRCT2::Ui::Windows
 
                 auto ft = Formatter();
                 ft.Add<utf8*>(shortPath.c_str());
-                DrawTextBasic(
-                    dpi, windowPos + ScreenCoordsXY{ kTabWidth + 3, height - 3 - 11 }, STR_STRING, ft, { colours[1] });
+                DrawTextBasic(rt, windowPos + ScreenCoordsXY{ kTabWidth + 3, height - 3 - 11 }, STR_STRING, ft, { colours[1] });
             }
 
             // Scenario name
@@ -241,25 +368,40 @@ namespace OpenRCT2::Ui::Windows
             ft.Add<StringId>(STR_STRING);
             ft.Add<const char*>(scenario->Name.c_str());
             DrawTextEllipsised(
-                dpi, screenPos + ScreenCoordsXY{ 85, 0 }, 170, STR_WINDOW_COLOUR_2_STRINGID, ft, { TextAlignment::CENTRE });
-            screenPos.y += 15;
+                rt, screenPos + ScreenCoordsXY{ previewPaneWidth / 2, 0 }, previewPaneWidth, STR_WINDOW_COLOUR_2_STRINGID, ft,
+                { TextAlignment::CENTRE });
+
+            // Still loading the preview?
+            if (_previewLoadJob.isValid())
+            {
+                ft = Formatter();
+                ft.Add<StringId>(STR_LOADING_GENERIC);
+                DrawTextBasic(
+                    rt, screenPos + ScreenCoordsXY{ previewPaneWidth / 2, 15 }, STR_BLACK_STRING, ft,
+                    { TextAlignment::CENTRE });
+                return;
+            }
+
+            // Draw preview
+            auto previewEnd = DrawPreview(rt, screenPos);
+            screenPos.y = previewEnd.y + 15;
 
             // Scenario details
             ft = Formatter();
             ft.Add<StringId>(STR_STRING);
             ft.Add<const char*>(scenario->Details.c_str());
-            screenPos.y += DrawTextWrapped(dpi, screenPos, 170, STR_BLACK_STRING, ft) + 5;
+            screenPos.y += DrawTextWrapped(rt, screenPos, previewPaneWidth, STR_BLACK_STRING, ft) + 5;
 
             // Scenario objective
-            Objective objective = { .Type = scenario->ObjectiveType,
-                                    .Year = scenario->ObjectiveArg1,
-                                    .NumGuests = static_cast<uint16_t>(scenario->ObjectiveArg3),
-                                    .Currency = scenario->ObjectiveArg2 };
+            Scenario::Objective objective = { .Type = scenario->ObjectiveType,
+                                              .Year = scenario->ObjectiveArg1,
+                                              .NumGuests = static_cast<uint16_t>(scenario->ObjectiveArg3),
+                                              .Currency = scenario->ObjectiveArg2 };
 
             ft = Formatter();
-            ft.Add<StringId>(kObjectiveNames[scenario->ObjectiveType]);
+            ft.Add<StringId>(kObjectiveNames[EnumValue(scenario->ObjectiveType)]);
             formatObjective(ft, objective);
-            screenPos.y += DrawTextWrapped(dpi, screenPos, 170, STR_OBJECTIVE, ft) + 5;
+            screenPos.y += DrawTextWrapped(rt, screenPos, previewPaneWidth, STR_OBJECTIVE, ft) + 5;
 
             // Scenario score
             if (scenario->Highscore != nullptr)
@@ -274,7 +416,7 @@ namespace OpenRCT2::Ui::Windows
                 ft.Add<StringId>(STR_STRING);
                 ft.Add<const char*>(completedByName.c_str());
                 ft.Add<money64>(scenario->Highscore->company_value);
-                screenPos.y += DrawTextWrapped(dpi, screenPos, 170, STR_COMPLETED_BY_WITH_COMPANY_VALUE, ft);
+                screenPos.y += DrawTextWrapped(rt, screenPos, previewPaneWidth, STR_COMPLETED_BY_WITH_COMPANY_VALUE, ft);
             }
         }
 
@@ -287,9 +429,8 @@ namespace OpenRCT2::Ui::Windows
 
             pressed_widgets |= 1LL << (selected_tab + WIDX_TAB1);
 
-            ResizeFrameWithPage();
             const int32_t bottomMargin = Config::Get().general.DebuggingTools ? 17 : 5;
-            widgets[WIDX_SCENARIOLIST].right = width - 179;
+            widgets[WIDX_SCENARIOLIST].right = width - GetPreviewPaneWidth() - 2 * kPadding;
             widgets[WIDX_SCENARIOLIST].bottom = height - bottomMargin;
         }
 
@@ -311,7 +452,7 @@ namespace OpenRCT2::Ui::Windows
                 }
             }
 
-            return { kWindowWidth, y };
+            return { kWindowSize.width, y };
         }
 
         void OnScrollMouseOver(int32_t scrollIndex, const ScreenCoordsXY& screenCoords) override
@@ -353,6 +494,7 @@ namespace OpenRCT2::Ui::Windows
             if (_highlightedScenario != selected)
             {
                 _highlightedScenario = selected;
+                LoadPreview();
                 Invalidate();
             }
             else if (_showLockedInformation != originalShowLockedInformation)
@@ -392,10 +534,10 @@ namespace OpenRCT2::Ui::Windows
             }
         }
 
-        void OnScrollDraw(int32_t scrollIndex, DrawPixelInfo& dpi) override
+        void OnScrollDraw(int32_t scrollIndex, RenderTarget& rt) override
         {
             uint8_t paletteIndex = ColourMapA[colours[1].colour].mid_light;
-            GfxClear(dpi, paletteIndex);
+            GfxClear(rt, paletteIndex);
 
             StringId highlighted_format = STR_WINDOW_COLOUR_2_STRINGID;
             StringId unhighlighted_format = STR_BLACK_STRING;
@@ -416,7 +558,7 @@ namespace OpenRCT2::Ui::Windows
             int32_t y = 0;
             for (const auto& listItem : _listItems)
             {
-                if (y > dpi.y + dpi.height)
+                if (y > rt.y + rt.height)
                 {
                     continue;
                 }
@@ -427,7 +569,7 @@ namespace OpenRCT2::Ui::Windows
                     {
                         const int32_t horizontalRuleMargin = 4;
                         DrawCategoryHeading(
-                            dpi, horizontalRuleMargin, listWidth - horizontalRuleMargin, y + 2, listItem.heading.string_id);
+                            rt, horizontalRuleMargin, listWidth - horizontalRuleMargin, y + 2, listItem.heading.string_id);
                         y += 18;
                         break;
                     }
@@ -438,7 +580,7 @@ namespace OpenRCT2::Ui::Windows
                         bool isHighlighted = _highlightedScenario == scenario;
                         if (isHighlighted)
                         {
-                            GfxFilterRect(dpi, { 0, y, width, y + scenarioItemHeight - 1 }, FilterPaletteID::PaletteDarken1);
+                            GfxFilterRect(rt, { 0, y, width, y + scenarioItemHeight - 1 }, FilterPaletteID::PaletteDarken1);
                         }
 
                         bool isCompleted = scenario->Highscore != nullptr;
@@ -456,14 +598,14 @@ namespace OpenRCT2::Ui::Windows
                         const auto scrollCentre = widgets[WIDX_SCENARIOLIST].width() / 2;
 
                         DrawTextBasic(
-                            dpi, { scrollCentre, y + 1 }, format, ft,
+                            rt, { scrollCentre, y + 1 }, format, ft,
                             { colour, FontStyle::Medium, TextAlignment::CENTRE, darkness });
 
                         // Check if scenario is completed
                         if (isCompleted)
                         {
                             // Draw completion tick
-                            GfxDrawSprite(dpi, ImageId(SPR_MENU_CHECKMARK), { widgets[WIDX_SCENARIOLIST].width() - 45, y + 1 });
+                            GfxDrawSprite(rt, ImageId(SPR_MENU_CHECKMARK), { widgets[WIDX_SCENARIOLIST].width() - 45, y + 1 });
 
                             // Draw completion score
                             u8string completedByName = "???";
@@ -476,7 +618,7 @@ namespace OpenRCT2::Ui::Windows
                             ft.Add<StringId>(STR_STRING);
                             ft.Add<const char*>(completedByName.c_str());
                             DrawTextBasic(
-                                dpi, { scrollCentre, y + scenarioTitleHeight + 1 }, format, ft,
+                                rt, { scrollCentre, y + scenarioTitleHeight + 1 }, format, ft,
                                 { FontStyle::Small, TextAlignment::CENTRE });
                         }
 
@@ -488,7 +630,7 @@ namespace OpenRCT2::Ui::Windows
         }
 
     private:
-        void DrawCategoryHeading(DrawPixelInfo& dpi, int32_t left, int32_t right, int32_t y, StringId stringId) const
+        void DrawCategoryHeading(RenderTarget& rt, int32_t left, int32_t right, int32_t y, StringId stringId) const
         {
             auto baseColour = colours[1];
             colour_t lightColour = ColourMapA[baseColour.colour].lighter;
@@ -496,7 +638,7 @@ namespace OpenRCT2::Ui::Windows
 
             // Draw string
             int32_t centreX = (left + right) / 2;
-            DrawTextBasic(dpi, { centreX, y }, stringId, {}, { baseColour, TextAlignment::CENTRE });
+            DrawTextBasic(rt, { centreX, y }, stringId, {}, { baseColour, TextAlignment::CENTRE });
 
             // Get string dimensions
             utf8 buffer[512];
@@ -510,21 +652,21 @@ namespace OpenRCT2::Ui::Windows
             int32_t lineY = y + 4;
             auto lightLineLeftTop1 = ScreenCoordsXY{ left, lineY };
             auto lightLineRightBottom1 = ScreenCoordsXY{ strLeft, lineY };
-            GfxDrawLine(dpi, { lightLineLeftTop1, lightLineRightBottom1 }, lightColour);
+            GfxDrawLine(rt, { lightLineLeftTop1, lightLineRightBottom1 }, lightColour);
 
             auto lightLineLeftTop2 = ScreenCoordsXY{ strRight, lineY };
             auto lightLineRightBottom2 = ScreenCoordsXY{ right, lineY };
-            GfxDrawLine(dpi, { lightLineLeftTop2, lightLineRightBottom2 }, lightColour);
+            GfxDrawLine(rt, { lightLineLeftTop2, lightLineRightBottom2 }, lightColour);
 
             // Draw dark horizontal rule
             lineY++;
             auto darkLineLeftTop1 = ScreenCoordsXY{ left, lineY };
             auto darkLineRightBottom1 = ScreenCoordsXY{ strLeft, lineY };
-            GfxDrawLine(dpi, { darkLineLeftTop1, darkLineRightBottom1 }, darkColour);
+            GfxDrawLine(rt, { darkLineLeftTop1, darkLineRightBottom1 }, darkColour);
 
             auto darkLineLeftTop2 = ScreenCoordsXY{ strRight, lineY };
             auto darkLineRightBottom2 = ScreenCoordsXY{ right, lineY };
-            GfxDrawLine(dpi, { darkLineLeftTop2, darkLineRightBottom2 }, darkColour);
+            GfxDrawLine(rt, { darkLineLeftTop2, darkLineRightBottom2 }, darkColour);
         }
 
         void InitialiseListItems()
@@ -538,7 +680,12 @@ namespace OpenRCT2::Ui::Windows
             std::optional<size_t> megaParkListItemIndex = std::nullopt;
 
             int32_t numUnlocks = kInitialNumUnlockedScenarios;
-            uint8_t currentHeading = UINT8_MAX;
+            union
+            {
+                uint8_t raw = UINT8_MAX;
+                Scenario::Category category;
+                ScenarioSource source;
+            } currentHeading{};
             for (size_t i = 0; i < numScenarios; i++)
             {
                 const ScenarioIndexEntry* scenario = ScenarioRepositoryGetByIndex(i);
@@ -548,37 +695,10 @@ namespace OpenRCT2::Ui::Windows
 
                 // Category heading
                 StringId headingStringId = kStringIdNone;
-                if (Config::Get().general.ScenarioSelectMode == SCENARIO_SELECT_MODE_ORIGIN)
+                if (selected_tab != EnumValue(ScenarioSource::Real) && currentHeading.category != scenario->Category)
                 {
-                    if (selected_tab != static_cast<uint8_t>(ScenarioSource::Real) && currentHeading != scenario->Category)
-                    {
-                        currentHeading = scenario->Category;
-                        headingStringId = kScenarioCategoryStringIds[currentHeading];
-                    }
-                }
-                else
-                {
-                    if (selected_tab <= SCENARIO_CATEGORY_EXPERT)
-                    {
-                        if (currentHeading != static_cast<uint8_t>(scenario->SourceGame))
-                        {
-                            currentHeading = static_cast<uint8_t>(scenario->SourceGame);
-                            headingStringId = kScenarioOriginStringIds[currentHeading];
-                        }
-                    }
-                    else if (selected_tab == SCENARIO_CATEGORY_OTHER)
-                    {
-                        int32_t category = scenario->Category;
-                        if (category <= SCENARIO_CATEGORY_REAL)
-                        {
-                            category = SCENARIO_CATEGORY_OTHER;
-                        }
-                        if (currentHeading != category)
-                        {
-                            currentHeading = category;
-                            headingStringId = kScenarioCategoryStringIds[category];
-                        }
-                    }
+                    currentHeading.category = scenario->Category;
+                    headingStringId = Scenario::kScenarioCategoryStringIds[currentHeading.raw];
                 }
 
                 if (headingStringId != kStringIdNone)
@@ -654,32 +774,16 @@ namespace OpenRCT2::Ui::Windows
 
         bool IsScenarioVisible(const ScenarioIndexEntry& scenario) const
         {
-            if (Config::Get().general.ScenarioSelectMode == SCENARIO_SELECT_MODE_ORIGIN)
+            if (static_cast<uint8_t>(scenario.SourceGame) != selected_tab)
             {
-                if (static_cast<uint8_t>(scenario.SourceGame) != selected_tab)
-                {
-                    return false;
-                }
-            }
-            else
-            {
-                int32_t category = scenario.Category;
-                if (category > SCENARIO_CATEGORY_OTHER)
-                {
-                    category = SCENARIO_CATEGORY_OTHER;
-                }
-                if (category != selected_tab)
-                {
-                    return false;
-                }
+                return false;
             }
+
             return true;
         }
 
         bool IsLockingEnabled() const
         {
-            if (Config::Get().general.ScenarioSelectMode != SCENARIO_SELECT_MODE_ORIGIN)
-                return false;
             if (!Config::Get().general.ScenarioUnlockingEnabled)
                 return false;
             if (selected_tab >= 6)
@@ -695,24 +799,12 @@ namespace OpenRCT2::Ui::Windows
             for (size_t i = 0; i < numScenarios; i++)
             {
                 const ScenarioIndexEntry* scenario = ScenarioRepositoryGetByIndex(i);
-                if (Config::Get().general.ScenarioSelectMode == SCENARIO_SELECT_MODE_ORIGIN)
-                {
-                    showPages |= 1 << static_cast<uint8_t>(scenario->SourceGame);
-                }
-                else
-                {
-                    int32_t category = scenario->Category;
-                    if (category > SCENARIO_CATEGORY_OTHER)
-                    {
-                        category = SCENARIO_CATEGORY_OTHER;
-                    }
-                    showPages |= 1 << category;
-                }
+                showPages |= 1 << static_cast<uint8_t>(scenario->SourceGame);
             }
 
-            if (showPages & (1 << Config::Get().interface.ScenarioselectLastTab))
+            if (showPages & (1 << Config::Get().interface.scenarioSelectLastTab))
             {
-                selected_tab = Config::Get().interface.ScenarioselectLastTab;
+                selected_tab = Config::Get().interface.scenarioSelectLastTab;
             }
             else
             {
@@ -723,17 +815,17 @@ namespace OpenRCT2::Ui::Windows
                 }
             }
 
-            int32_t y = kTabsStart;
+            int32_t y = widgets[WIDX_TAB1].top;
             for (int32_t i = 0; i < kNumTabs; i++)
             {
                 auto& widget = widgets[i + WIDX_TAB1];
                 if (!(showPages & (1 << i)))
                 {
-                    widget.type = WindowWidgetType::Empty;
+                    widget.type = WidgetType::empty;
                     continue;
                 }
 
-                widget.type = WindowWidgetType::Tab;
+                widget.type = WidgetType::tab;
                 widget.top = y;
                 widget.bottom = y + (kTabHeight - 1);
                 y += kTabHeight;
@@ -774,12 +866,8 @@ namespace OpenRCT2::Ui::Windows
             return window;
         }
 
-        int32_t screenWidth = ContextGetWidth();
-        int32_t screenHeight = ContextGetHeight();
-        ScreenCoordsXY screenPos = { (screenWidth - kWindowWidth) / 2,
-                                     std::max(kTopToolbarHeight + 1, (screenHeight - kWindowHeight) / 2) };
         window = windowMgr->Create<ScenarioSelectWindow>(
-            WindowClass::ScenarioSelect, screenPos, kWindowWidth, kWindowHeight, 0, callback);
+            WindowClass::ScenarioSelect, {}, kWindowSize, WF_AUTO_POSITION | WF_CENTRE_SCREEN, callback);
         return window;
     }
 } // namespace OpenRCT2::Ui::Windows
