@@ -44,7 +44,7 @@
 #include "../world/tile_element/WallElement.h"
 #include "Colour.h"
 #include "Window.h"
-#include "Window_internal.h"
+#include "WindowBase.h"
 
 #include <cstring>
 #include <list>
@@ -79,8 +79,8 @@ namespace OpenRCT2
     {
     }
 
-    static void ViewportPaintWeatherGloom(DrawPixelInfo& dpi);
-    static void ViewportPaint(const Viewport* viewport, DrawPixelInfo& dpi);
+    static void ViewportPaintWeatherGloom(RenderTarget& rt);
+    static void ViewportPaint(const Viewport* viewport, RenderTarget& rt);
     static void ViewportUpdateFollowSprite(WindowBase* window);
     static void ViewportUpdateSmartFollowEntity(WindowBase* window);
     static void ViewportUpdateSmartFollowStaff(WindowBase* window, const Staff& peep);
@@ -102,7 +102,7 @@ namespace OpenRCT2
         WindowInitAll();
 
         // ?
-        InputResetFlags();
+        gInputFlags.clearAll();
         InputSetState(InputState::Reset);
         gPressedWidget.window_classification = WindowClass::Null;
         gPickupPeepImage = ImageId();
@@ -203,6 +203,7 @@ namespace OpenRCT2
         if (Config::Get().general.AlwaysShowGridlines)
             viewport->flags |= VIEWPORT_FLAG_GRIDLINES;
         w->viewport = viewport;
+        viewport->isVisible = w->isVisible;
 
         CoordsXYZ centrePos = focus.GetPos();
         w->viewport_target_sprite = std::visit(
@@ -246,33 +247,23 @@ namespace OpenRCT2
         return mainWindow->viewport;
     }
 
-    void ViewportsInvalidate(int32_t x, int32_t y, int32_t z0, int32_t z1, ZoomLevel maxZoom)
+    void ViewportsInvalidate(const int32_t x, const int32_t y, const int32_t z0, const int32_t z1, const ZoomLevel maxZoom)
     {
-        for (auto& vp : _viewports)
+        for (const auto& viewport : _viewports)
         {
-            if (maxZoom == ZoomLevel{ -1 } || vp.zoom <= ZoomLevel{ maxZoom })
+            if (viewport.isVisible)
             {
-                int32_t x1, y1, x2, y2;
-
-                x += 16;
-                y += 16;
-                auto screenCoord = Translate3DTo2DWithZ(vp.rotation, CoordsXYZ{ x, y, 0 });
-
-                x1 = screenCoord.x - 32;
-                y1 = screenCoord.y - 32 - z1;
-                x2 = screenCoord.x + 32;
-                y2 = screenCoord.y + 32 - z0;
-
-                ViewportInvalidate(&vp, ScreenRect{ { x1, y1 }, { x2, y2 } });
+                viewport.Invalidate(x, y, z0, z1, maxZoom);
             }
         }
     }
 
-    void ViewportsInvalidate(const CoordsXYZ& pos, int32_t width, int32_t minHeight, int32_t maxHeight, ZoomLevel maxZoom)
+    void ViewportsInvalidate(
+        const CoordsXYZ& pos, const int32_t width, const int32_t minHeight, const int32_t maxHeight, const ZoomLevel maxZoom)
     {
         for (auto& vp : _viewports)
         {
-            if (maxZoom == ZoomLevel{ -1 } || vp.zoom <= ZoomLevel{ maxZoom })
+            if (vp.isVisible && (maxZoom == ZoomLevel{ -1 } || vp.zoom <= ZoomLevel{ maxZoom }))
             {
                 auto screenCoords = Translate3DTo2DWithZ(vp.rotation, pos);
                 auto screenPos = ScreenRect(
@@ -283,11 +274,11 @@ namespace OpenRCT2
         }
     }
 
-    void ViewportsInvalidate(const ScreenRect& screenRect, ZoomLevel maxZoom)
+    void ViewportsInvalidate(const ScreenRect& screenRect, const ZoomLevel maxZoom)
     {
         for (auto& vp : _viewports)
         {
-            if (maxZoom == ZoomLevel{ -1 } || vp.zoom <= ZoomLevel{ maxZoom })
+            if (vp.isVisible && (maxZoom == ZoomLevel{ -1 } || vp.zoom <= ZoomLevel{ maxZoom }))
             {
                 ViewportInvalidate(&vp, screenRect);
             }
@@ -333,7 +324,7 @@ namespace OpenRCT2
      *  rct2: 0x006E7FF3
      */
     static void ViewportRedrawAfterShift(
-        DrawPixelInfo& dpi, WindowBase* window, const WindowBase* originalWindow, const ScreenCoordsXY shift,
+        RenderTarget& rt, WindowBase* window, const WindowBase* originalWindow, const ScreenCoordsXY shift,
         const ScreenRect& drawRect)
     {
         // sub-divide by intersecting windows
@@ -345,43 +336,51 @@ namespace OpenRCT2
                 || drawRect.GetTop() >= window->windowPos.y + window->height)
             {
                 auto itWindowPos = WindowGetIterator(window);
-                auto itNextWindow = itWindowPos != g_window_list.end() ? std::next(itWindowPos) : g_window_list.end();
+                // Get next valid window after.
+                auto itNextWindow = [&]() {
+                    auto itNext = std::next(itWindowPos);
+                    while (itNext != g_window_list.end() && (itNext->get()->flags & WF_DEAD))
+                    {
+                        ++itNext;
+                    }
+                    return itNext;
+                }();
                 ViewportRedrawAfterShift(
-                    dpi, itNextWindow == g_window_list.end() ? nullptr : itNextWindow->get(), originalWindow, shift, drawRect);
+                    rt, itNextWindow == g_window_list.end() ? nullptr : itNextWindow->get(), originalWindow, shift, drawRect);
                 return;
             }
 
             if (drawRect.GetLeft() < window->windowPos.x)
             {
                 ScreenRect leftRect = { drawRect.Point1, { window->windowPos.x, drawRect.GetBottom() } };
-                ViewportRedrawAfterShift(dpi, window, originalWindow, shift, leftRect);
+                ViewportRedrawAfterShift(rt, window, originalWindow, shift, leftRect);
 
                 ScreenRect rightRect = { { window->windowPos.x, drawRect.GetTop() }, drawRect.Point2 };
-                ViewportRedrawAfterShift(dpi, window, originalWindow, shift, rightRect);
+                ViewportRedrawAfterShift(rt, window, originalWindow, shift, rightRect);
             }
             else if (drawRect.GetRight() > window->windowPos.x + window->width)
             {
                 ScreenRect leftRect = { drawRect.Point1, { window->windowPos.x + window->width, drawRect.GetBottom() } };
-                ViewportRedrawAfterShift(dpi, window, originalWindow, shift, leftRect);
+                ViewportRedrawAfterShift(rt, window, originalWindow, shift, leftRect);
 
                 ScreenRect rightRect = { { window->windowPos.x + window->width, drawRect.GetTop() }, drawRect.Point2 };
-                ViewportRedrawAfterShift(dpi, window, originalWindow, shift, rightRect);
+                ViewportRedrawAfterShift(rt, window, originalWindow, shift, rightRect);
             }
             else if (drawRect.GetTop() < window->windowPos.y)
             {
                 ScreenRect topRect = { drawRect.Point1, { drawRect.GetRight(), window->windowPos.y } };
-                ViewportRedrawAfterShift(dpi, window, originalWindow, shift, topRect);
+                ViewportRedrawAfterShift(rt, window, originalWindow, shift, topRect);
 
                 ScreenRect bottomRect = { { drawRect.GetLeft(), window->windowPos.y }, drawRect.Point2 };
-                ViewportRedrawAfterShift(dpi, window, originalWindow, shift, bottomRect);
+                ViewportRedrawAfterShift(rt, window, originalWindow, shift, bottomRect);
             }
             else if (drawRect.GetBottom() > window->windowPos.y + window->height)
             {
                 ScreenRect topRect = { drawRect.Point1, { drawRect.GetRight(), window->windowPos.y + window->height } };
-                ViewportRedrawAfterShift(dpi, window, originalWindow, shift, topRect);
+                ViewportRedrawAfterShift(rt, window, originalWindow, shift, topRect);
 
                 ScreenRect bottomRect = { { drawRect.GetLeft(), window->windowPos.y + window->height }, drawRect.Point2 };
-                ViewportRedrawAfterShift(dpi, window, originalWindow, shift, bottomRect);
+                ViewportRedrawAfterShift(rt, window, originalWindow, shift, bottomRect);
             }
         }
         else
@@ -402,14 +401,14 @@ namespace OpenRCT2
                 {
                     // draw left
                     auto _right = left + shift.x;
-                    WindowDrawAll(dpi, left, top, _right, bottom);
+                    WindowDrawAll(rt, left, top, _right, bottom);
                     left += shift.x;
                 }
                 else if (shift.x < 0)
                 {
                     // draw right
                     auto _left = right + shift.x;
-                    WindowDrawAll(dpi, _left, top, right, bottom);
+                    WindowDrawAll(rt, _left, top, right, bottom);
                     right += shift.x;
                 }
 
@@ -417,77 +416,62 @@ namespace OpenRCT2
                 {
                     // draw top
                     bottom = top + shift.y;
-                    WindowDrawAll(dpi, left, top, right, bottom);
+                    WindowDrawAll(rt, left, top, right, bottom);
                 }
                 else if (shift.y < 0)
                 {
                     // draw bottom
                     top = bottom + shift.y;
-                    WindowDrawAll(dpi, left, top, right, bottom);
+                    WindowDrawAll(rt, left, top, right, bottom);
                 }
             }
             else
             {
                 // redraw whole draw rectangle
-                WindowDrawAll(dpi, left, top, right, bottom);
+                WindowDrawAll(rt, left, top, right, bottom);
             }
         }
     }
 
-    static void ViewportShiftPixels(DrawPixelInfo& dpi, WindowBase* window, Viewport* viewport, int32_t x_diff, int32_t y_diff)
+    static void ViewportShiftPixels(
+        RenderTarget& rt, WindowBase* window, const ScreenRect& drawRect, const ScreenCoordsXY& shift)
     {
         // This loop redraws all parts covered by transparent windows.
         auto it = WindowGetIterator(window);
         for (; it != g_window_list.end(); it++)
         {
             auto w = it->get();
-            if (!(w->flags & WF_TRANSPARENT))
+            if (!(w->flags & WF_TRANSPARENT) || (w->flags & WF_DEAD))
                 continue;
-            if (w->viewport == viewport)
+            if (w->viewport == window->viewport)
                 continue;
 
-            if (viewport->pos.x + viewport->width <= w->windowPos.x)
+            if (drawRect.GetRight() <= w->windowPos.x)
                 continue;
-            if (w->windowPos.x + w->width <= viewport->pos.x)
+            if (w->windowPos.x + w->width <= drawRect.GetLeft())
                 continue;
 
-            if (viewport->pos.y + viewport->height <= w->windowPos.y)
+            if (drawRect.GetBottom() <= w->windowPos.y)
                 continue;
-            if (w->windowPos.y + w->height <= viewport->pos.y)
+            if (w->windowPos.y + w->height <= drawRect.GetTop())
                 continue;
 
-            auto left = w->windowPos.x;
-            auto right = w->windowPos.x + w->width;
-            auto top = w->windowPos.y;
-            auto bottom = w->windowPos.y + w->height;
+            const int32_t left = std::max(w->windowPos.x, drawRect.GetLeft());
+            const int32_t right = std::min(w->windowPos.x + w->width, drawRect.GetRight());
+            const int32_t top = std::max(w->windowPos.y, drawRect.GetTop());
+            const int32_t bottom = std::min(w->windowPos.y + w->height, drawRect.GetBottom());
 
-            if (left < viewport->pos.x)
-                left = viewport->pos.x;
-            if (right > viewport->pos.x + viewport->width)
-                right = viewport->pos.x + viewport->width;
-
-            if (top < viewport->pos.y)
-                top = viewport->pos.y;
-            if (bottom > viewport->pos.y + viewport->height)
-                bottom = viewport->pos.y + viewport->height;
-
-            if (left >= right)
-                continue;
-            if (top >= bottom)
+            if (left >= right || top >= bottom)
                 continue;
 
-            WindowDrawAll(dpi, left, top, right, bottom);
+            WindowDrawAll(rt, left, top, right, bottom);
         }
 
-        ViewportRedrawAfterShift(
-            dpi, window, window, { x_diff, y_diff },
-            { viewport->pos, { viewport->pos.x + viewport->width, viewport->pos.y + viewport->height } });
+        ViewportRedrawAfterShift(rt, window, window, shift, drawRect);
     }
 
     static void ViewportMove(const ScreenCoordsXY& coords, WindowBase* w, Viewport* viewport)
     {
-        auto zoom = viewport->zoom;
-
         // Note: do not do the subtraction and then divide!
         // Note: Due to arithmetic shift != /zoom a shift will have to be used
         // hopefully when 0x006E7FF3 is finished this can be converted to /zoom.
@@ -514,65 +498,39 @@ namespace OpenRCT2
 
             if (DrawingEngineHasDirtyOptimisations())
             {
-                DrawPixelInfo& dpi = DrawingEngineGetDpi();
-                WindowDrawAll(dpi, left, top, right, bottom);
+                RenderTarget& rt = DrawingEngineGetDpi();
+                WindowDrawAll(rt, left, top, right, bottom);
                 return;
             }
+            else
+            {
+                GfxInvalidateScreen();
+            }
         }
 
-        Viewport view_copy = *viewport;
+        const int32_t left = std::max(viewport->pos.x, 0);
+        const int32_t top = std::max(viewport->pos.y, 0);
+        const int32_t right = std::min(left + viewport->width + std::min(viewport->pos.x, 0), ContextGetWidth());
+        const int32_t bottom = std::min(top + viewport->height + std::min(viewport->pos.y, 0), ContextGetHeight());
 
-        if (viewport->pos.x < 0)
-        {
-            viewport->width += viewport->pos.x;
-            viewport->viewPos.x -= zoom.ApplyTo(viewport->pos.x);
-            viewport->pos.x = 0;
-        }
-
-        int32_t eax = viewport->pos.x + viewport->width - ContextGetWidth();
-        if (eax > 0)
-        {
-            viewport->width -= eax;
-        }
-
-        if (viewport->width <= 0)
-        {
-            *viewport = view_copy;
+        if (left >= right || top >= bottom)
             return;
-        }
-
-        if (viewport->pos.y < 0)
-        {
-            viewport->height += viewport->pos.y;
-            viewport->viewPos.y -= zoom.ApplyTo(viewport->pos.y);
-            viewport->pos.y = 0;
-        }
-
-        eax = viewport->pos.y + viewport->height - ContextGetHeight();
-        if (eax > 0)
-        {
-            viewport->height -= eax;
-        }
-
-        if (viewport->height <= 0)
-        {
-            *viewport = view_copy;
-            return;
-        }
 
         if (DrawingEngineHasDirtyOptimisations())
         {
-            DrawPixelInfo& dpi = DrawingEngineGetDpi();
-            ViewportShiftPixels(dpi, w, viewport, x_diff, y_diff);
+            RenderTarget& rt = DrawingEngineGetDpi();
+            ViewportShiftPixels(rt, w, { left, top, right, bottom }, { x_diff, y_diff });
+        }
+        else
+        {
+            GfxInvalidateScreen();
         }
-
-        *viewport = view_copy;
     }
 
     // rct2: 0x006E7A15
     static void ViewportSetUndergroundFlag(int32_t underground, WindowBase* window, Viewport* viewport)
     {
-        if (window->classification != WindowClass::MainWindow
+        if ((window->classification != WindowClass::MainWindow && window->classification != WindowClass::Viewport)
             || (window->classification == WindowClass::MainWindow && !window->viewport_smart_follow_sprite.IsNull()))
         {
             if (!underground)
@@ -599,7 +557,9 @@ namespace OpenRCT2
      */
     void ViewportUpdatePosition(WindowBase* window)
     {
-        window->OnResize();
+        // Guard against any code attempting to call this at the wrong time.
+        Guard::Assert(
+            GetContext()->GetDrawingEngine()->GetDrawingContext() != nullptr, "We must be in a valid drawing context.");
 
         Viewport* viewport = window->viewport;
         if (viewport == nullptr)
@@ -708,9 +668,9 @@ namespace OpenRCT2
                 return;
             }
 
-            if (!(gScreenFlags & SCREEN_FLAGS_TITLE_DEMO))
+            if (gLegacyScene != LegacyScene::titleSequence)
             {
-                int32_t height = (TileElementHeight({ sprite->x, sprite->y }))-16;
+                int32_t height = TileElementHeight({ sprite->x, sprite->y }) - 16;
                 int32_t underground = sprite->z < height;
                 ViewportSetUndergroundFlag(underground, window, window->viewport);
             }
@@ -785,7 +745,7 @@ namespace OpenRCT2
             || (peep.State == PeepState::LeavingRide && peep.x == kLocationNull))
         {
             auto ride = GetRide(peep.CurrentRide);
-            if (ride != nullptr && (ride->lifecycle_flags & RIDE_LIFECYCLE_ON_TRACK))
+            if (ride != nullptr && (ride->lifecycleFlags & RIDE_LIFECYCLE_ON_TRACK))
             {
                 auto train = GetEntity<Vehicle>(ride->vehicles[peep.CurrentTrain]);
                 if (train != nullptr)
@@ -806,7 +766,7 @@ namespace OpenRCT2
             auto ride = GetRide(peep.CurrentRide);
             if (ride != nullptr)
             {
-                auto xy = ride->overall_view.ToTileCentre();
+                auto xy = ride->overallView.ToTileCentre();
                 CoordsXYZ coordFocus;
                 coordFocus.x = xy.x;
                 coordFocus.y = xy.y;
@@ -892,7 +852,7 @@ namespace OpenRCT2
             auto* viewport = w->viewport;
             if (viewport == nullptr)
                 return;
-            if (viewport->flags & VIEWPORT_FLAG_INDEPEDENT_ROTATION)
+            if (viewport->flags & VIEWPORT_FLAG_INDEPENDENT_ROTATION)
                 return;
             ViewportRotateSingleInternal(*w, direction);
         });
@@ -908,21 +868,21 @@ namespace OpenRCT2
      *  edi: dpi
      *  ebp: bottom
      */
-    void ViewportRender(DrawPixelInfo& dpi, const Viewport* viewport)
+    void ViewportRender(RenderTarget& rt, const Viewport* viewport)
     {
         if (viewport->flags & VIEWPORT_FLAG_RENDERING_INHIBITED)
             return;
 
-        if (dpi.x + dpi.width <= viewport->pos.x)
+        if (rt.x + rt.width <= viewport->pos.x)
             return;
-        if (dpi.y + dpi.height <= viewport->pos.y)
+        if (rt.y + rt.height <= viewport->pos.y)
             return;
-        if (dpi.x >= viewport->pos.x + viewport->width)
+        if (rt.x >= viewport->pos.x + viewport->width)
             return;
-        if (dpi.y >= viewport->pos.y + viewport->height)
+        if (rt.y >= viewport->pos.y + viewport->height)
             return;
 
-        ViewportPaint(viewport, dpi);
+        ViewportPaint(viewport, rt);
     }
 
     static void ViewportFillColumn(PaintSession& session)
@@ -974,27 +934,26 @@ namespace OpenRCT2
      *  edi: dpi
      *  ebp: bottom
      */
-    static void ViewportPaint(const Viewport* viewport, DrawPixelInfo& dpi)
+    static void ViewportPaint(const Viewport* viewport, RenderTarget& rt)
     {
         PROFILED_FUNCTION();
 
-        const int32_t offsetX = dpi.x - viewport->pos.x;
-        const int32_t offsetY = dpi.y - viewport->pos.y;
+        const int32_t offsetX = rt.x - viewport->pos.x;
+        const int32_t offsetY = rt.y - viewport->pos.y;
         const int32_t worldX = viewport->zoom.ApplyInversedTo(viewport->viewPos.x) + std::max(0, offsetX);
         const int32_t worldY = viewport->zoom.ApplyInversedTo(viewport->viewPos.y) + std::max(0, offsetY);
-        const int32_t width = std::min(viewport->pos.x + viewport->width, dpi.x + dpi.width) - std::max(viewport->pos.x, dpi.x);
-        const int32_t height = std::min(viewport->pos.y + viewport->height, dpi.y + dpi.height)
-            - std::max(viewport->pos.y, dpi.y);
+        const int32_t width = std::min(viewport->pos.x + viewport->width, rt.x + rt.width) - std::max(viewport->pos.x, rt.x);
+        const int32_t height = std::min(viewport->pos.y + viewport->height, rt.y + rt.height) - std::max(viewport->pos.y, rt.y);
 
-        DrawPixelInfo worldDpi;
-        worldDpi.DrawingEngine = dpi.DrawingEngine;
-        worldDpi.bits = dpi.bits + std::max(0, -offsetX) + std::max(0, -offsetY) * dpi.LineStride();
-        worldDpi.x = worldX;
-        worldDpi.y = worldY;
-        worldDpi.width = width;
-        worldDpi.height = height;
-        worldDpi.pitch = dpi.LineStride() - worldDpi.width;
-        worldDpi.zoom_level = viewport->zoom;
+        RenderTarget worldRT;
+        worldRT.DrawingEngine = rt.DrawingEngine;
+        worldRT.bits = rt.bits + std::max(0, -offsetX) + std::max(0, -offsetY) * rt.LineStride();
+        worldRT.x = worldX;
+        worldRT.y = worldY;
+        worldRT.width = width;
+        worldRT.height = height;
+        worldRT.pitch = rt.LineStride() - worldRT.width;
+        worldRT.zoom_level = viewport->zoom;
 
         _paintColumns.clear();
 
@@ -1009,39 +968,48 @@ namespace OpenRCT2
         }
 
         bool useParallelDrawing = false;
-        if (useMultithreading && (dpi.DrawingEngine->GetFlags() & DEF_PARALLEL_DRAWING))
+        if (useMultithreading && rt.DrawingEngine->GetFlags().has(DrawingEngineFlag::parallelDrawing))
         {
             useParallelDrawing = true;
         }
 
-        const int32_t columnWidth = worldDpi.zoom_level.ApplyInversedTo(kCoordsXYStep);
-        const int32_t rightBorder = worldDpi.x + worldDpi.width;
-        const int32_t alignedX = floor2(worldDpi.x, columnWidth);
+        const int32_t columnWidth = worldRT.zoom_level.ApplyInversedTo(kCoordsXYStep);
+        const int32_t rightBorder = worldRT.x + worldRT.width;
+        const int32_t alignedX = floor2(worldRT.x, columnWidth);
 
         // Generate and sort columns.
         for (int32_t x = alignedX; x < rightBorder; x += columnWidth)
         {
-            PaintSession* session = PaintSessionAlloc(worldDpi, viewport->flags, viewport->rotation);
+            PaintSession* session = PaintSessionAlloc(worldRT, viewport->flags, viewport->rotation);
             _paintColumns.push_back(session);
 
-            DrawPixelInfo& columnDpi = session->DPI;
-            if (x >= columnDpi.x)
+            RenderTarget& columnRT = session->DPI;
+            if (x >= columnRT.x)
             {
-                const int32_t leftPitch = x - columnDpi.x;
-                columnDpi.width = columnDpi.width - leftPitch;
-                columnDpi.bits += leftPitch;
-                columnDpi.pitch += leftPitch;
-                columnDpi.x = x;
+                const int32_t leftPitch = x - columnRT.x;
+                columnRT.width = columnRT.width - leftPitch;
+                columnRT.bits += leftPitch;
+                columnRT.pitch += leftPitch;
+                columnRT.x = x;
             }
 
-            int32_t paintRight = columnDpi.x + columnDpi.width;
+            int32_t paintRight = columnRT.x + columnRT.width;
             if (paintRight >= x + columnWidth)
             {
                 const int32_t rightPitch = paintRight - x - columnWidth;
                 paintRight -= rightPitch;
-                columnDpi.pitch += rightPitch;
+                columnRT.pitch += rightPitch;
             }
-            columnDpi.width = paintRight - columnDpi.x;
+            columnRT.width = paintRight - columnRT.x;
+
+            // culling sprites outside the clipped column causes sorting differences between invalidation blocks
+            // not culling sprites outside the full column width also causes a different kind of glitching
+            constexpr int32_t cullingY = ZoomLevel::max().ApplyInversedTo(std::numeric_limits<int32_t>::max()) / 2;
+
+            columnRT.cullingX = floor2(columnRT.x, columnWidth);
+            columnRT.cullingY = -cullingY;
+            columnRT.cullingWidth = columnWidth;
+            columnRT.cullingHeight = cullingY * 2;
 
             if (useMultithreading)
             {
@@ -1082,16 +1050,16 @@ namespace OpenRCT2
         }
     }
 
-    static void ViewportPaintWeatherGloom(DrawPixelInfo& dpi)
+    static void ViewportPaintWeatherGloom(RenderTarget& rt)
     {
-        auto paletteId = ClimateGetWeatherGloomPaletteId(GetGameState().WeatherCurrent);
+        auto paletteId = ClimateGetWeatherGloomPaletteId(getGameState().weatherCurrent);
         if (paletteId != FilterPaletteID::PaletteNull)
         {
-            auto x = dpi.x;
-            auto y = dpi.y;
-            auto w = dpi.width;
-            auto h = dpi.height;
-            GfxFilterRect(dpi, ScreenRect(x, y, x + w, y + h), paletteId);
+            auto x = rt.x;
+            auto y = rt.y;
+            auto w = rt.width;
+            auto h = rt.height;
+            GfxFilterRect(rt, ScreenRect(x, y, x + w, y + h), paletteId);
         }
     }
 
@@ -1145,6 +1113,17 @@ namespace OpenRCT2
         return { mapCoords->ToTileStart() };
     }
 
+    [[nodiscard]] bool Viewport::ContainsTile(const TileCoordsXY coords) const noexcept
+    {
+        const auto centreCoords = coords.ToCoordsXY() + CoordsXY(kCoordsXYHalfTile, kCoordsXYHalfTile);
+        const auto screenPos = Translate3DTo2DWithZ(rotation, CoordsXYZ{ centreCoords, 0 });
+        const auto left = screenPos.x - kScreenCoordsTileWidthHalf;
+        const auto top = screenPos.y - (kMaxTileElementHeight * kCoordsZStep) - kScreenCoordsTileHeightHalf;
+        const auto right = screenPos.x + kScreenCoordsTileWidthHalf;
+        const auto bottom = screenPos.y + kScreenCoordsTileHeightHalf;
+        return !(left > viewPos.x + ViewWidth() || top > viewPos.y + ViewHeight() || right < viewPos.x || bottom < viewPos.y);
+    }
+
     [[nodiscard]] ScreenCoordsXY Viewport::ScreenToViewportCoord(const ScreenCoordsXY& screenCoords) const
     {
         ScreenCoordsXY ret;
@@ -1158,6 +1137,21 @@ namespace OpenRCT2
         ViewportInvalidate(this, { viewPos, viewPos + ScreenCoordsXY{ ViewWidth(), ViewHeight() } });
     }
 
+    void Viewport::Invalidate(
+        const int32_t x, const int32_t y, const int32_t z0, const int32_t z1, const ZoomLevel maxZoom) const
+    {
+        if ((maxZoom == ZoomLevel{ -1 } || zoom <= ZoomLevel{ maxZoom }))
+        {
+            const auto screenCoord = Translate3DTo2DWithZ(
+                rotation, CoordsXYZ{ x + kCoordsXYHalfTile, y + kCoordsXYHalfTile, 0 });
+
+            const auto topLeft = screenCoord - ScreenCoordsXY(kScreenCoordsTileWidthHalf, kScreenCoordsTileHeight + z1);
+            const auto bottomRight = screenCoord + ScreenCoordsXY(kScreenCoordsTileWidthHalf, kScreenCoordsTileHeight - z0);
+
+            ViewportInvalidate(this, ScreenRect{ topLeft, bottomRight });
+        }
+    }
+
     CoordsXY ViewportPosToMapPos(const ScreenCoordsXY& coords, int32_t z, uint8_t rotation)
     {
         // Reverse of Translate3DTo2DWithZ
@@ -1438,7 +1432,7 @@ namespace OpenRCT2
                                     break;
 
                                 auto ride = vehicle->GetRide();
-                                if (ride != nullptr && !ride->GetRideTypeDescriptor().HasFlag(RtdFlag::hasTrack))
+                                if (ride != nullptr && !ride->getRideTypeDescriptor().HasFlag(RtdFlag::hasTrack))
                                 {
                                     return (viewFlags & VIEWPORT_FLAG_INVISIBLE_RIDES) ? VisibilityKind::Hidden
                                                                                        : VisibilityKind::Partial;
@@ -1599,8 +1593,7 @@ namespace OpenRCT2
      * rct2: 0x00679074
      */
     static bool IsSpriteInteractedWithPaletteSet(
-        DrawPixelInfo& dpi, ImageId imageId, const ScreenCoordsXY& coords, const PaletteMap& paletteMap,
-        const uint8_t imageType)
+        RenderTarget& rt, ImageId imageId, const ScreenCoordsXY& coords, const PaletteMap& paletteMap, const uint8_t imageType)
     {
         PROFILED_FUNCTION();
 
@@ -1610,11 +1603,11 @@ namespace OpenRCT2
             return false;
         }
 
-        ZoomLevel zoomLevel = dpi.zoom_level;
-        ScreenCoordsXY interactionPoint{ dpi.WorldX(), dpi.WorldY() };
+        ZoomLevel zoomLevel = rt.zoom_level;
+        ScreenCoordsXY interactionPoint{ rt.WorldX(), rt.WorldY() };
         ScreenCoordsXY origin = coords;
 
-        if (dpi.zoom_level > ZoomLevel{ 0 })
+        if (rt.zoom_level > ZoomLevel{ 0 })
         {
             if (g1->flags & G1_FLAG_NO_ZOOM_DRAW)
             {
@@ -1666,7 +1659,7 @@ namespace OpenRCT2
      *  rct2: 0x00679023
      */
 
-    static bool IsSpriteInteractedWith(DrawPixelInfo& dpi, ImageId imageId, const ScreenCoordsXY& coords)
+    static bool IsSpriteInteractedWith(RenderTarget& rt, ImageId imageId, const ScreenCoordsXY& coords)
     {
         PROFILED_FUNCTION();
 
@@ -1693,7 +1686,12 @@ namespace OpenRCT2
         {
             imageType = IMAGE_TYPE_DEFAULT;
         }
-        return IsSpriteInteractedWithPaletteSet(dpi, imageId, coords, paletteMap, imageType);
+        return IsSpriteInteractedWithPaletteSet(rt, imageId, coords, paletteMap, imageType);
+    }
+
+    const std::list<Viewport>& GetAllViewports()
+    {
+        return _viewports;
     }
 
     /**
@@ -1786,14 +1784,19 @@ namespace OpenRCT2
                 viewLoc.x &= viewport->zoom.ApplyTo(0xFFFFFFFF) & 0xFFFFFFFF;
                 viewLoc.y &= viewport->zoom.ApplyTo(0xFFFFFFFF) & 0xFFFFFFFF;
             }
-            DrawPixelInfo dpi;
-            dpi.zoom_level = viewport->zoom;
-            dpi.x = viewport->zoom.ApplyInversedTo(viewLoc.x);
-            dpi.y = viewport->zoom.ApplyInversedTo(viewLoc.y);
-            dpi.height = 1;
-            dpi.width = 1;
+            RenderTarget rt;
+            rt.zoom_level = viewport->zoom;
+            rt.x = viewport->zoom.ApplyInversedTo(viewLoc.x);
+            rt.y = viewport->zoom.ApplyInversedTo(viewLoc.y);
+            rt.height = 1;
+            rt.width = 1;
 
-            PaintSession* session = PaintSessionAlloc(dpi, viewport->flags, viewport->rotation);
+            rt.cullingX = rt.x;
+            rt.cullingY = rt.y;
+            rt.cullingWidth = rt.width;
+            rt.cullingHeight = rt.height;
+
+            PaintSession* session = PaintSessionAlloc(rt, viewport->flags, viewport->rotation);
             PaintSessionGenerate(*session);
             PaintSessionArrange(*session);
             info = SetInteractionInfoFromPaintSession(session, viewport->flags, flags & 0xFFFF);
@@ -1809,24 +1812,6 @@ namespace OpenRCT2
     {
         PROFILED_FUNCTION();
 
-        // if unknown viewport visibility, use the containing window to discover the status
-        if (viewport->visibility == VisibilityCache::Unknown)
-        {
-            auto windowManager = Ui::GetWindowManager();
-            auto owner = windowManager->GetOwner(viewport);
-            if (owner != nullptr && owner->classification != WindowClass::MainWindow)
-            {
-                // note, window_is_visible will update viewport->visibility, so this should have a low hit count
-                if (!WindowIsVisible(*owner))
-                {
-                    return;
-                }
-            }
-        }
-
-        if (viewport->visibility == VisibilityCache::Covered)
-            return;
-
         auto zoom = viewport->zoom;
         auto viewPos = viewport->viewPos;
         auto viewportScreenPos = viewport->pos;
@@ -1846,7 +1831,7 @@ namespace OpenRCT2
         GfxSetDirtyBlocks(invalidRect);
     }
 
-    static Viewport* ViewportFindFromPoint(const ScreenCoordsXY& screenCoords)
+    Viewport* ViewportFindFromPoint(const ScreenCoordsXY& screenCoords)
     {
         auto* windowMgr = Ui::GetWindowManager();
         WindowBase* w = windowMgr->FindFromPoint(screenCoords);
@@ -2044,14 +2029,27 @@ namespace OpenRCT2
         if (w != nullptr)
         {
             Viewport* viewport = w->viewport;
-            auto& gameState = GetGameState();
+            auto& gameState = getGameState();
 
-            gameState.SavedView = ScreenCoordsXY{ viewport->ViewWidth() / 2, viewport->ViewHeight() / 2 } + viewport->viewPos;
+            gameState.savedView = ScreenCoordsXY{ viewport->ViewWidth() / 2, viewport->ViewHeight() / 2 } + viewport->viewPos;
 
-            gameState.SavedViewZoom = viewport->zoom;
-            gameState.SavedViewRotation = viewport->rotation;
+            gameState.savedViewZoom = viewport->zoom;
+            gameState.savedViewRotation = viewport->rotation;
         }
     }
+
+    ViewportList GetVisibleViewports() noexcept
+    {
+        ViewportList viewports;
+        for (auto& viewport : _viewports)
+        {
+            if (viewport.isVisible)
+            {
+                viewports.push_back(&viewport);
+            }
+        };
+        return viewports;
+    }
 } // namespace OpenRCT2
 
 ZoomLevel ZoomLevel::min()
