@@ -15,6 +15,7 @@
 #include "../PlatformEnvironment.h"
 #include "../audio/Audio.h"
 #include "../core/Console.hpp"
+#include "../core/EnumMap.hpp"
 #include "../core/File.h"
 #include "../core/FileStream.h"
 #include "../core/Json.hpp"
@@ -23,9 +24,10 @@
 #include "../core/Path.hpp"
 #include "../core/String.hpp"
 #include "../core/Zip.h"
-#include "../rct12/SawyerChunkReader.h"
+#include "../sawyer_coding/SawyerChunkReader.h"
 #include "AudioObject.h"
 #include "BannerObject.h"
+#include "ClimateObject.h"
 #include "EntranceObject.h"
 #include "FootpathObject.h"
 #include "FootpathRailingsObject.h"
@@ -39,7 +41,7 @@
 #include "PeepAnimationsObject.h"
 #include "PeepNamesObject.h"
 #include "RideObject.h"
-#include "ScenarioTextObject.h"
+#include "ScenarioMetaObject.h"
 #include "SceneryGroupObject.h"
 #include "SmallSceneryObject.h"
 #include "StationObject.h"
@@ -51,170 +53,173 @@
 #include <memory>
 #include <unordered_map>
 
-using namespace OpenRCT2;
-
-struct IFileDataRetriever
+namespace OpenRCT2
 {
-    virtual ~IFileDataRetriever() = default;
-    virtual std::vector<uint8_t> GetData(std::string_view path) const = 0;
-    virtual ObjectAsset GetAsset(std::string_view path) const = 0;
-};
+    using namespace OpenRCT2::SawyerCoding;
 
-class FileSystemDataRetriever : public IFileDataRetriever
-{
-private:
-    std::string _basePath;
-
-public:
-    FileSystemDataRetriever(std::string_view basePath)
-        : _basePath(basePath)
+    struct IFileDataRetriever
     {
-    }
+        virtual ~IFileDataRetriever() = default;
+        virtual std::vector<uint8_t> GetData(std::string_view path) const = 0;
+        virtual ObjectAsset GetAsset(std::string_view path) const = 0;
+    };
 
-    std::vector<uint8_t> GetData(std::string_view path) const override
+    class FileSystemDataRetriever : public IFileDataRetriever
     {
-        auto absolutePath = Path::Combine(_basePath, path);
-        return File::ReadAllBytes(absolutePath);
-    }
+    private:
+        std::string _basePath;
 
-    ObjectAsset GetAsset(std::string_view path) const override
-    {
-        if (Path::IsAbsolute(path))
+    public:
+        FileSystemDataRetriever(std::string_view basePath)
+            : _basePath(basePath)
         {
-            return ObjectAsset(path);
         }
-        else
+
+        std::vector<uint8_t> GetData(std::string_view path) const override
         {
             auto absolutePath = Path::Combine(_basePath, path);
-            return ObjectAsset(absolutePath);
+            return File::ReadAllBytes(absolutePath);
         }
-    }
-};
 
-class ZipDataRetriever : public IFileDataRetriever
-{
-private:
-    const std::string _path;
-    const IZipArchive& _zipArchive;
-
-public:
-    ZipDataRetriever(std::string_view path, const IZipArchive& zipArchive)
-        : _path(path)
-        , _zipArchive(zipArchive)
-    {
-    }
-
-    std::vector<uint8_t> GetData(std::string_view path) const override
-    {
-        return _zipArchive.GetFileData(path);
-    }
-
-    ObjectAsset GetAsset(std::string_view path) const override
-    {
-        return ObjectAsset(_path, path);
-    }
-};
-
-class ReadObjectContext : public IReadObjectContext
-{
-private:
-    IObjectRepository& _objectRepository;
-    const IFileDataRetriever* _fileDataRetriever;
-
-    std::string _identifier;
-    bool _loadImages;
-    std::string _basePath;
-    bool _wasVerbose = false;
-    bool _wasWarning = false;
-    bool _wasError = false;
-
-public:
-    bool WasVerbose() const
-    {
-        return _wasVerbose;
-    }
-    bool WasWarning() const
-    {
-        return _wasWarning;
-    }
-    bool WasError() const
-    {
-        return _wasError;
-    }
-
-    ReadObjectContext(
-        IObjectRepository& objectRepository, const std::string& identifier, bool loadImages,
-        const IFileDataRetriever* fileDataRetriever)
-        : _objectRepository(objectRepository)
-        , _fileDataRetriever(fileDataRetriever)
-        , _identifier(identifier)
-        , _loadImages(loadImages)
-    {
-    }
-
-    std::string_view GetObjectIdentifier() override
-    {
-        return _identifier;
-    }
-
-    IObjectRepository& GetObjectRepository() override
-    {
-        return _objectRepository;
-    }
-
-    bool ShouldLoadImages() override
-    {
-        return _loadImages;
-    }
-
-    std::vector<uint8_t> GetData(std::string_view path) override
-    {
-        if (_fileDataRetriever != nullptr)
+        ObjectAsset GetAsset(std::string_view path) const override
         {
-            return _fileDataRetriever->GetData(path);
+            if (Path::IsAbsolute(path))
+            {
+                return ObjectAsset(path);
+            }
+            else
+            {
+                auto absolutePath = Path::Combine(_basePath, path);
+                return ObjectAsset(absolutePath);
+            }
         }
-        return {};
-    }
+    };
 
-    ObjectAsset GetAsset(std::string_view path) override
+    class ZipDataRetriever : public IFileDataRetriever
     {
-        if (_fileDataRetriever != nullptr)
-        {
-            return _fileDataRetriever->GetAsset(path);
-        }
-        return {};
-    }
+    private:
+        const std::string _path;
+        const IZipArchive& _zipArchive;
 
-    void LogVerbose(ObjectError code, const utf8* text) override
+    public:
+        ZipDataRetriever(std::string_view path, const IZipArchive& zipArchive)
+            : _path(path)
+            , _zipArchive(zipArchive)
+        {
+        }
+
+        std::vector<uint8_t> GetData(std::string_view path) const override
+        {
+            return _zipArchive.GetFileData(path);
+        }
+
+        ObjectAsset GetAsset(std::string_view path) const override
+        {
+            return ObjectAsset(_path, path);
+        }
+    };
+
+    class ReadObjectContext : public IReadObjectContext
     {
-        _wasVerbose = true;
+    private:
+        IObjectRepository& _objectRepository;
+        const IFileDataRetriever* _fileDataRetriever;
 
-        if (!String::isNullOrEmpty(text))
+        std::string _identifier;
+        bool _loadImages;
+        std::string _basePath;
+        bool _wasVerbose = false;
+        bool _wasWarning = false;
+        bool _wasError = false;
+
+    public:
+        bool WasVerbose() const
         {
-            LOG_VERBOSE("[%s] Info (%d): %s", _identifier.c_str(), code, text);
+            return _wasVerbose;
         }
-    }
-
-    void LogWarning(ObjectError code, const utf8* text) override
-    {
-        _wasWarning = true;
-
-        if (!String::isNullOrEmpty(text))
+        bool WasWarning() const
         {
-            Console::Error::WriteLine("[%s] Warning (%d): %s", _identifier.c_str(), code, text);
+            return _wasWarning;
         }
-    }
-
-    void LogError(ObjectError code, const utf8* text) override
-    {
-        _wasError = true;
-
-        if (!String::isNullOrEmpty(text))
+        bool WasError() const
         {
-            Console::Error::WriteLine("[%s] Error (%d): %s", _identifier.c_str(), code, text);
+            return _wasError;
         }
-    }
-};
+
+        ReadObjectContext(
+            IObjectRepository& objectRepository, const std::string& identifier, bool loadImages,
+            const IFileDataRetriever* fileDataRetriever)
+            : _objectRepository(objectRepository)
+            , _fileDataRetriever(fileDataRetriever)
+            , _identifier(identifier)
+            , _loadImages(loadImages)
+        {
+        }
+
+        std::string_view GetObjectIdentifier() override
+        {
+            return _identifier;
+        }
+
+        IObjectRepository& GetObjectRepository() override
+        {
+            return _objectRepository;
+        }
+
+        bool ShouldLoadImages() override
+        {
+            return _loadImages;
+        }
+
+        std::vector<uint8_t> GetData(std::string_view path) override
+        {
+            if (_fileDataRetriever != nullptr)
+            {
+                return _fileDataRetriever->GetData(path);
+            }
+            return {};
+        }
+
+        ObjectAsset GetAsset(std::string_view path) override
+        {
+            if (_fileDataRetriever != nullptr)
+            {
+                return _fileDataRetriever->GetAsset(path);
+            }
+            return {};
+        }
+
+        void LogVerbose(ObjectError code, const utf8* text) override
+        {
+            _wasVerbose = true;
+
+            if (!String::isNullOrEmpty(text))
+            {
+                LOG_VERBOSE("[%s] Info (%d): %s", _identifier.c_str(), code, text);
+            }
+        }
+
+        void LogWarning(ObjectError code, const utf8* text) override
+        {
+            _wasWarning = true;
+
+            if (!String::isNullOrEmpty(text))
+            {
+                Console::Error::WriteLine("[%s] Warning (%d): %s", _identifier.c_str(), code, text);
+            }
+        }
+
+        void LogError(ObjectError code, const utf8* text) override
+        {
+            _wasError = true;
+
+            if (!String::isNullOrEmpty(text))
+            {
+                Console::Error::WriteLine("[%s] Error (%d): %s", _identifier.c_str(), code, text);
+            }
+        }
+    };
+} // namespace OpenRCT2
 
 namespace OpenRCT2::ObjectFactory
 {
@@ -223,11 +228,12 @@ namespace OpenRCT2::ObjectFactory
      * @note jRoot is deliberately left non-const: json_t behaviour changes when const
      */
     static std::unique_ptr<Object> CreateObjectFromJson(
-        IObjectRepository& objectRepository, json_t& jRoot, const IFileDataRetriever* fileRetriever, bool loadImageTable);
+        IObjectRepository& objectRepository, json_t& jRoot, const IFileDataRetriever* fileRetriever, bool loadImageTable,
+        const std::string_view path);
 
-    static ObjectSourceGame ParseSourceGame(const std::string& s)
+    static ObjectSourceGame ParseSourceGame(const std::string_view s)
     {
-        static const std::unordered_map<std::string, ObjectSourceGame> LookupTable{
+        static const std::unordered_map<std::string_view, ObjectSourceGame> LookupTable{
             { "rct1", ObjectSourceGame::RCT1 },
             { "rct1aa", ObjectSourceGame::AddedAttractions },
             { "rct1ll", ObjectSourceGame::LoopyLandscapes },
@@ -265,15 +271,16 @@ namespace OpenRCT2::ObjectFactory
         std::unique_ptr<Object> result;
         try
         {
-            auto fs = OpenRCT2::FileStream(path, OpenRCT2::FILE_MODE_OPEN);
+            auto fs = OpenRCT2::FileStream(path, OpenRCT2::FileMode::open);
             auto chunkReader = SawyerChunkReader(&fs);
 
             RCTObjectEntry entry = fs.ReadValue<RCTObjectEntry>();
 
-            if (entry.GetType() != ObjectType::scenarioText)
+            if (entry.GetType() != ObjectType::scenarioMeta)
             {
                 result = CreateObject(entry.GetType());
                 result->SetDescriptor(ObjectEntryDescriptor(entry));
+                result->SetFileName(OpenRCT2::Path::GetFileNameWithoutExtension(path));
 
                 utf8 objectName[kDatNameLength + 1] = { 0 };
                 ObjectEntryGetNameFixed(objectName, sizeof(objectName), &entry);
@@ -364,8 +371,8 @@ namespace OpenRCT2::ObjectFactory
             case ObjectType::water:
                 result = std::make_unique<WaterObject>();
                 break;
-            case ObjectType::scenarioText:
-                result = std::make_unique<ScenarioTextObject>();
+            case ObjectType::scenarioMeta:
+                result = std::make_unique<ScenarioMetaObject>();
                 break;
             case ObjectType::terrainSurface:
                 result = std::make_unique<TerrainSurfaceObject>();
@@ -394,60 +401,44 @@ namespace OpenRCT2::ObjectFactory
             case ObjectType::peepAnimations:
                 result = std::make_unique<PeepAnimationsObject>();
                 break;
+            case ObjectType::climate:
+                result = std::make_unique<ClimateObject>();
+                break;
             default:
                 throw std::runtime_error("Invalid object type");
         }
         return result;
     }
 
-    static ObjectType ParseObjectType(const std::string& s)
-    {
-        if (s == "ride")
-            return ObjectType::ride;
-        if (s == "footpath_banner")
-            return ObjectType::banners;
-        if (s == "footpath_item")
-            return ObjectType::pathAdditions;
-        if (s == "scenery_small")
-            return ObjectType::smallScenery;
-        if (s == "scenery_large")
-            return ObjectType::largeScenery;
-        if (s == "scenery_wall")
-            return ObjectType::walls;
-        if (s == "scenery_group")
-            return ObjectType::sceneryGroup;
-        if (s == "park_entrance")
-            return ObjectType::parkEntrance;
-        if (s == "water")
-            return ObjectType::water;
-        if (s == "scenario_text")
-            return ObjectType::scenarioText;
-        if (s == "terrain_surface")
-            return ObjectType::terrainSurface;
-        if (s == "terrain_edge")
-            return ObjectType::terrainEdge;
-        if (s == "station")
-            return ObjectType::station;
-        if (s == "music")
-            return ObjectType::music;
-        if (s == "footpath_surface")
-            return ObjectType::footpathSurface;
-        if (s == "footpath_railings")
-            return ObjectType::footpathRailings;
-        if (s == "audio")
-            return ObjectType::audio;
-        if (s == "peep_names")
-            return ObjectType::peepNames;
-        if (s == "peep_animations")
-            return ObjectType::peepAnimations;
-        return ObjectType::none;
-    }
+    static const EnumMap<ObjectType> kObjectTypeMap = {
+        { "ride", ObjectType::ride },
+        { "scenery_small", ObjectType::smallScenery },
+        { "scenery_large", ObjectType::largeScenery },
+        { "scenery_wall", ObjectType::walls },
+        { "footpath_banner", ObjectType::banners },
+        { "footpath_legacy", ObjectType::paths },
+        { "footpath_item", ObjectType::pathAdditions },
+        { "scenery_group", ObjectType::sceneryGroup },
+        { "park_entrance", ObjectType::parkEntrance },
+        { "water", ObjectType::water },
+        { "scenario_meta", ObjectType::scenarioMeta },
+        { "terrain_surface", ObjectType::terrainSurface },
+        { "terrain_edge", ObjectType::terrainEdge },
+        { "station", ObjectType::station },
+        { "music", ObjectType::music },
+        { "footpath_surface", ObjectType::footpathSurface },
+        { "footpath_railings", ObjectType::footpathRailings },
+        { "audio", ObjectType::audio },
+        { "peep_names", ObjectType::peepNames },
+        { "peep_animations", ObjectType::peepAnimations },
+        { "climate", ObjectType::climate },
+    };
 
     std::unique_ptr<Object> CreateObjectFromZipFile(IObjectRepository& objectRepository, std::string_view path, bool loadImages)
     {
         try
         {
-            auto archive = Zip::Open(path, ZIP_ACCESS::READ);
+            auto archive = Zip::Open(path, ZipAccess::read);
             auto jsonBytes = archive->GetFileData("object.json");
             if (jsonBytes.empty())
             {
@@ -459,7 +450,7 @@ namespace OpenRCT2::ObjectFactory
             if (jRoot.is_object())
             {
                 auto fileDataRetriever = ZipDataRetriever(path, *archive);
-                return CreateObjectFromJson(objectRepository, jRoot, &fileDataRetriever, loadImages);
+                return CreateObjectFromJson(objectRepository, jRoot, &fileDataRetriever, loadImages, path);
             }
         }
         catch (const std::exception& e)
@@ -478,7 +469,7 @@ namespace OpenRCT2::ObjectFactory
         {
             json_t jRoot = Json::ReadFromFile(path.c_str());
             auto fileDataRetriever = FileSystemDataRetriever(Path::GetDirectory(path));
-            return CreateObjectFromJson(objectRepository, jRoot, &fileDataRetriever, loadImages);
+            return CreateObjectFromJson(objectRepository, jRoot, &fileDataRetriever, loadImages, path);
         }
         catch (const std::runtime_error& err)
         {
@@ -522,12 +513,13 @@ namespace OpenRCT2::ObjectFactory
 
     static bool isUsingClassic()
     {
-        auto env = OpenRCT2::GetContext()->GetPlatformEnvironment();
-        return env->IsUsingClassic();
+        auto& env = OpenRCT2::GetContext()->GetPlatformEnvironment();
+        return env.IsUsingClassic();
     }
 
     std::unique_ptr<Object> CreateObjectFromJson(
-        IObjectRepository& objectRepository, json_t& jRoot, const IFileDataRetriever* fileRetriever, bool loadImageTable)
+        IObjectRepository& objectRepository, json_t& jRoot, const IFileDataRetriever* fileRetriever, bool loadImageTable,
+        const std::string_view path)
     {
         if (!jRoot.is_object())
         {
@@ -538,9 +530,10 @@ namespace OpenRCT2::ObjectFactory
 
         std::unique_ptr<Object> result;
 
-        auto objectType = ParseObjectType(Json::GetString(jRoot["objectType"]));
-        if (objectType != ObjectType::none)
+        auto lookup = kObjectTypeMap.find(Json::GetString(jRoot["objectType"]));
+        if (lookup != kObjectTypeMap.end())
         {
+            auto objectType = lookup->second;
             auto id = Json::GetString(jRoot["id"]);
 
             // Base audio files are renamed to a common, virtual name so asset packs can override it correctly.
@@ -585,6 +578,7 @@ namespace OpenRCT2::ObjectFactory
             result->SetVersion(version);
             result->SetIdentifier(id);
             result->SetDescriptor(descriptor);
+            result->SetFileName(OpenRCT2::Path::GetFileNameWithoutExtension(path));
             result->MarkAsJsonObject();
             auto readContext = ReadObjectContext(objectRepository, id, loadImageTable, fileRetriever);
             result->ReadJson(&readContext, jRoot);
