@@ -190,7 +190,7 @@ const CarEntry kCableLiftVehicle = {
     .spinning_friction = 255,
     .friction_sound_id = Audio::SoundId::LiftClassic,
     .ReversedCarIndex = 0,
-    .sound_range = 0,
+    .soundRange = SoundRange::screamsMisc,
     .double_sound_frequency = 0,
     .powered_acceleration = 0,
     .powered_max_speed = 0,
@@ -256,108 +256,108 @@ const StringId kRideModeNames[] = {
 // clang-format on
 
 constexpr RideTypeDescriptor kRideTypeDescriptors[RIDE_TYPE_COUNT] = {
-    /* RIDE_TYPE_SPIRAL_ROLLER_COASTER              */ SpiralRollerCoasterRTD,
-    /* RIDE_TYPE_STAND_UP_ROLLER_COASTER            */ StandUpRollerCoasterRTD,
-    /* RIDE_TYPE_SUSPENDED_SWINGING_COASTER         */ SuspendedSwingingCoasterRTD,
-    /* RIDE_TYPE_INVERTED_ROLLER_COASTER            */ InvertedRollerCoasterRTD,
-    /* RIDE_TYPE_JUNIOR_ROLLER_COASTER              */ JuniorRollerCoasterRTD,
-    /* RIDE_TYPE_MINIATURE_RAILWAY                  */ MiniatureRailwayRTD,
-    /* RIDE_TYPE_MONORAIL                           */ MonorailRTD,
-    /* RIDE_TYPE_MINI_SUSPENDED_COASTER             */ MiniSuspendedCoasterRTD,
-    /* RIDE_TYPE_BOAT_HIRE                          */ BoatHireRTD,
-    /* RIDE_TYPE_WOODEN_WILD_MOUSE                  */ WoodenWildMouseRTD,
-    /* RIDE_TYPE_STEEPLECHASE                       */ SteeplechaseRTD,
-    /* RIDE_TYPE_CAR_RIDE                           */ CarRideRTD,
-    /* RIDE_TYPE_LAUNCHED_FREEFALL                  */ LaunchedFreefallRTD,
-    /* RIDE_TYPE_BOBSLEIGH_COASTER                  */ BobsleighCoasterRTD,
-    /* RIDE_TYPE_OBSERVATION_TOWER                  */ ObservationTowerRTD,
-    /* RIDE_TYPE_LOOPING_ROLLER_COASTER             */ LoopingRollerCoasterRTD,
-    /* RIDE_TYPE_DINGHY_SLIDE                       */ DinghySlideRTD,
-    /* RIDE_TYPE_MINE_TRAIN_COASTER                 */ MineTrainCoasterRTD,
-    /* RIDE_TYPE_CHAIRLIFT                          */ ChairliftRTD,
-    /* RIDE_TYPE_CORKSCREW_ROLLER_COASTER           */ CorkscrewRollerCoasterRTD,
-    /* RIDE_TYPE_MAZE                               */ MazeRTD,
-    /* RIDE_TYPE_SPIRAL_SLIDE                       */ SpiralSlideRTD,
-    /* RIDE_TYPE_GO_KARTS                           */ GoKartsRTD,
-    /* RIDE_TYPE_LOG_FLUME                          */ LogFlumeRTD,
-    /* RIDE_TYPE_RIVER_RAPIDS                       */ RiverRapidsRTD,
-    /* RIDE_TYPE_DODGEMS                            */ DodgemsRTD,
-    /* RIDE_TYPE_SWINGING_SHIP                      */ SwingingShipRTD,
-    /* RIDE_TYPE_SWINGING_INVERTER_SHIP             */ SwingingInverterShipRTD,
-    /* RIDE_TYPE_FOOD_STALL                         */ FoodStallRTD,
+    /* RIDE_TYPE_SPIRAL_ROLLER_COASTER              */ OpenRCT2::SpiralRollerCoasterRTD,
+    /* RIDE_TYPE_STAND_UP_ROLLER_COASTER            */ OpenRCT2::StandUpRollerCoasterRTD,
+    /* RIDE_TYPE_SUSPENDED_SWINGING_COASTER         */ OpenRCT2::SuspendedSwingingCoasterRTD,
+    /* RIDE_TYPE_INVERTED_ROLLER_COASTER            */ OpenRCT2::InvertedRollerCoasterRTD,
+    /* RIDE_TYPE_JUNIOR_ROLLER_COASTER              */ OpenRCT2::JuniorRollerCoasterRTD,
+    /* RIDE_TYPE_MINIATURE_RAILWAY                  */ OpenRCT2::MiniatureRailwayRTD,
+    /* RIDE_TYPE_MONORAIL                           */ OpenRCT2::MonorailRTD,
+    /* RIDE_TYPE_MINI_SUSPENDED_COASTER             */ OpenRCT2::MiniSuspendedCoasterRTD,
+    /* RIDE_TYPE_BOAT_HIRE                          */ OpenRCT2::BoatHireRTD,
+    /* RIDE_TYPE_WOODEN_WILD_MOUSE                  */ OpenRCT2::WoodenWildMouseRTD,
+    /* RIDE_TYPE_STEEPLECHASE                       */ OpenRCT2::SteeplechaseRTD,
+    /* RIDE_TYPE_CAR_RIDE                           */ OpenRCT2::CarRideRTD,
+    /* RIDE_TYPE_LAUNCHED_FREEFALL                  */ OpenRCT2::LaunchedFreefallRTD,
+    /* RIDE_TYPE_BOBSLEIGH_COASTER                  */ OpenRCT2::BobsleighCoasterRTD,
+    /* RIDE_TYPE_OBSERVATION_TOWER                  */ OpenRCT2::ObservationTowerRTD,
+    /* RIDE_TYPE_LOOPING_ROLLER_COASTER             */ OpenRCT2::LoopingRollerCoasterRTD,
+    /* RIDE_TYPE_DINGHY_SLIDE                       */ OpenRCT2::DinghySlideRTD,
+    /* RIDE_TYPE_MINE_TRAIN_COASTER                 */ OpenRCT2::MineTrainCoasterRTD,
+    /* RIDE_TYPE_CHAIRLIFT                          */ OpenRCT2::ChairliftRTD,
+    /* RIDE_TYPE_CORKSCREW_ROLLER_COASTER           */ OpenRCT2::CorkscrewRollerCoasterRTD,
+    /* RIDE_TYPE_MAZE                               */ OpenRCT2::MazeRTD,
+    /* RIDE_TYPE_SPIRAL_SLIDE                       */ OpenRCT2::SpiralSlideRTD,
+    /* RIDE_TYPE_GO_KARTS                           */ OpenRCT2::GoKartsRTD,
+    /* RIDE_TYPE_LOG_FLUME                          */ OpenRCT2::LogFlumeRTD,
+    /* RIDE_TYPE_RIVER_RAPIDS                       */ OpenRCT2::RiverRapidsRTD,
+    /* RIDE_TYPE_DODGEMS                            */ OpenRCT2::DodgemsRTD,
+    /* RIDE_TYPE_SWINGING_SHIP                      */ OpenRCT2::SwingingShipRTD,
+    /* RIDE_TYPE_SWINGING_INVERTER_SHIP             */ OpenRCT2::SwingingInverterShipRTD,
+    /* RIDE_TYPE_FOOD_STALL                         */ OpenRCT2::FoodStallRTD,
     /* RIDE_TYPE_1D                                 */ kDummyRTD,
-    /* RIDE_TYPE_DRINK_STALL                        */ DrinkStallRTD,
+    /* RIDE_TYPE_DRINK_STALL                        */ OpenRCT2::DrinkStallRTD,
     /* RIDE_TYPE_1F                                 */ kDummyRTD,
-    /* RIDE_TYPE_SHOP                               */ ShopRTD,
-    /* RIDE_TYPE_MERRY_GO_ROUND                     */ MerryGoRoundRTD,
+    /* RIDE_TYPE_SHOP                               */ OpenRCT2::ShopRTD,
+    /* RIDE_TYPE_MERRY_GO_ROUND                     */ OpenRCT2::MerryGoRoundRTD,
     /* RIDE_TYPE_22                                 */ kDummyRTD,
-    /* RIDE_TYPE_INFORMATION_KIOSK                  */ InformationKioskRTD,
-    /* RIDE_TYPE_TOILETS                            */ ToiletsRTD,
-    /* RIDE_TYPE_FERRIS_WHEEL                       */ FerrisWheelRTD,
-    /* RIDE_TYPE_MOTION_SIMULATOR                   */ MotionSimulatorRTD,
-    /* RIDE_TYPE_3D_CINEMA                          */ CinemaRTD,
-    /* RIDE_TYPE_TOP_SPIN                           */ TopSpinRTD,
-    /* RIDE_TYPE_SPACE_RINGS                        */ SpaceRingsRTD,
-    /* RIDE_TYPE_REVERSE_FREEFALL_COASTER           */ ReverseFreefallCoasterRTD,
-    /* RIDE_TYPE_LIFT                               */ LiftRTD,
-    /* RIDE_TYPE_VERTICAL_DROP_ROLLER_COASTER       */ VerticalDropCoasterRTD,
-    /* RIDE_TYPE_CASH_MACHINE                       */ CashMachineRTD,
-    /* RIDE_TYPE_TWIST                              */ TwistRTD,
-    /* RIDE_TYPE_HAUNTED_HOUSE                      */ HauntedHouseRTD,
-    /* RIDE_TYPE_FIRST_AID                          */ FirstAidRTD,
-    /* RIDE_TYPE_CIRCUS                             */ CircusRTD,
-    /* RIDE_TYPE_GHOST_TRAIN                        */ GhostTrainRTD,
-    /* RIDE_TYPE_TWISTER_ROLLER_COASTER             */ TwisterRollerCoasterRTD,
-    /* RIDE_TYPE_WOODEN_ROLLER_COASTER              */ WoodenRollerCoasterRTD,
-    /* RIDE_TYPE_SIDE_FRICTION_ROLLER_COASTER       */ SideFrictionRollerCoasterRTD,
-    /* RIDE_TYPE_STEEL_WILD_MOUSE                   */ SteelWildMouseRTD,
-    /* RIDE_TYPE_MULTI_DIMENSION_ROLLER_COASTER     */ MultiDimensionRollerCoasterRTD,
-    /* RIDE_TYPE_MULTI_DIMENSION_ROLLER_COASTER_ALT */ MultiDimensionRollerCoasterAltRTD,
-    /* RIDE_TYPE_FLYING_ROLLER_COASTER              */ FlyingRollerCoasterRTD,
-    /* RIDE_TYPE_FLYING_ROLLER_COASTER_ALT          */ FlyingRollerCoasterAltRTD,
-    /* RIDE_TYPE_VIRGINIA_REEL                      */ VirginiaReelRTD,
-    /* RIDE_TYPE_SPLASH_BOATS                       */ SplashBoatsRTD,
-    /* RIDE_TYPE_MINI_HELICOPTERS                   */ MiniHelicoptersRTD,
-    /* RIDE_TYPE_LAY_DOWN_ROLLER_COASTER            */ LayDownRollerCoasterRTD,
-    /* RIDE_TYPE_SUSPENDED_MONORAIL                 */ SuspendedMonorailRTD,
-    /* RIDE_TYPE_LAY_DOWN_ROLLER_COASTER_ALT        */ LayDownRollerCoasterAltRTD,
-    /* RIDE_TYPE_REVERSER_ROLLER_COASTER            */ ReverserRollerCoasterRTD,
-    /* RIDE_TYPE_HEARTLINE_TWISTER_COASTER          */ HeartlineTwisterCoasterRTD,
-    /* RIDE_TYPE_MINI_GOLF                          */ MiniGolfRTD,
-    /* RIDE_TYPE_GIGA_COASTER                       */ GigaCoasterRTD,
-    /* RIDE_TYPE_ROTO_DROP                          */ RotoDropRTD,
-    /* RIDE_TYPE_FLYING_SAUCERS                     */ FlyingSaucersRTD,
-    /* RIDE_TYPE_CROOKED_HOUSE                      */ CrookedHouseRTD,
-    /* RIDE_TYPE_MONORAIL_CYCLES                    */ MonorailCyclesRTD,
-    /* RIDE_TYPE_COMPACT_INVERTED_COASTER           */ CompactInvertedCoasterRTD,
-    /* RIDE_TYPE_WATER_COASTER                      */ WaterCoasterRTD,
-    /* RIDE_TYPE_AIR_POWERED_VERTICAL_COASTER       */ AirPoweredVerticalCoasterRTD,
-    /* RIDE_TYPE_INVERTED_HAIRPIN_COASTER           */ InvertedHairpinCoasterRTD,
-    /* RIDE_TYPE_MAGIC_CARPET                       */ MagicCarpetRTD,
-    /* RIDE_TYPE_SUBMARINE_RIDE                     */ SubmarineRideRTD,
-    /* RIDE_TYPE_RIVER_RAFTS                        */ RiverRaftsRTD,
+    /* RIDE_TYPE_INFORMATION_KIOSK                  */ OpenRCT2::InformationKioskRTD,
+    /* RIDE_TYPE_TOILETS                            */ OpenRCT2::ToiletsRTD,
+    /* RIDE_TYPE_FERRIS_WHEEL                       */ OpenRCT2::FerrisWheelRTD,
+    /* RIDE_TYPE_MOTION_SIMULATOR                   */ OpenRCT2::MotionSimulatorRTD,
+    /* RIDE_TYPE_3D_CINEMA                          */ OpenRCT2::CinemaRTD,
+    /* RIDE_TYPE_TOP_SPIN                           */ OpenRCT2::TopSpinRTD,
+    /* RIDE_TYPE_SPACE_RINGS                        */ OpenRCT2::SpaceRingsRTD,
+    /* RIDE_TYPE_REVERSE_FREEFALL_COASTER           */ OpenRCT2::ReverseFreefallCoasterRTD,
+    /* RIDE_TYPE_LIFT                               */ OpenRCT2::LiftRTD,
+    /* RIDE_TYPE_VERTICAL_DROP_ROLLER_COASTER       */ OpenRCT2::VerticalDropCoasterRTD,
+    /* RIDE_TYPE_CASH_MACHINE                       */ OpenRCT2::CashMachineRTD,
+    /* RIDE_TYPE_TWIST                              */ OpenRCT2::TwistRTD,
+    /* RIDE_TYPE_HAUNTED_HOUSE                      */ OpenRCT2::HauntedHouseRTD,
+    /* RIDE_TYPE_FIRST_AID                          */ OpenRCT2::FirstAidRTD,
+    /* RIDE_TYPE_CIRCUS                             */ OpenRCT2::CircusRTD,
+    /* RIDE_TYPE_GHOST_TRAIN                        */ OpenRCT2::GhostTrainRTD,
+    /* RIDE_TYPE_TWISTER_ROLLER_COASTER             */ OpenRCT2::TwisterRollerCoasterRTD,
+    /* RIDE_TYPE_WOODEN_ROLLER_COASTER              */ OpenRCT2::WoodenRollerCoasterRTD,
+    /* RIDE_TYPE_SIDE_FRICTION_ROLLER_COASTER       */ OpenRCT2::SideFrictionRollerCoasterRTD,
+    /* RIDE_TYPE_STEEL_WILD_MOUSE                   */ OpenRCT2::SteelWildMouseRTD,
+    /* RIDE_TYPE_MULTI_DIMENSION_ROLLER_COASTER     */ OpenRCT2::MultiDimensionRollerCoasterRTD,
+    /* RIDE_TYPE_MULTI_DIMENSION_ROLLER_COASTER_ALT */ OpenRCT2::MultiDimensionRollerCoasterAltRTD,
+    /* RIDE_TYPE_FLYING_ROLLER_COASTER              */ OpenRCT2::FlyingRollerCoasterRTD,
+    /* RIDE_TYPE_FLYING_ROLLER_COASTER_ALT          */ OpenRCT2::FlyingRollerCoasterAltRTD,
+    /* RIDE_TYPE_VIRGINIA_REEL                      */ OpenRCT2::VirginiaReelRTD,
+    /* RIDE_TYPE_SPLASH_BOATS                       */ OpenRCT2::SplashBoatsRTD,
+    /* RIDE_TYPE_MINI_HELICOPTERS                   */ OpenRCT2::MiniHelicoptersRTD,
+    /* RIDE_TYPE_LAY_DOWN_ROLLER_COASTER            */ OpenRCT2::LayDownRollerCoasterRTD,
+    /* RIDE_TYPE_SUSPENDED_MONORAIL                 */ OpenRCT2::SuspendedMonorailRTD,
+    /* RIDE_TYPE_LAY_DOWN_ROLLER_COASTER_ALT        */ OpenRCT2::LayDownRollerCoasterAltRTD,
+    /* RIDE_TYPE_REVERSER_ROLLER_COASTER            */ OpenRCT2::ReverserRollerCoasterRTD,
+    /* RIDE_TYPE_HEARTLINE_TWISTER_COASTER          */ OpenRCT2::HeartlineTwisterCoasterRTD,
+    /* RIDE_TYPE_MINI_GOLF                          */ OpenRCT2::MiniGolfRTD,
+    /* RIDE_TYPE_GIGA_COASTER                       */ OpenRCT2::GigaCoasterRTD,
+    /* RIDE_TYPE_ROTO_DROP                          */ OpenRCT2::RotoDropRTD,
+    /* RIDE_TYPE_FLYING_SAUCERS                     */ OpenRCT2::FlyingSaucersRTD,
+    /* RIDE_TYPE_CROOKED_HOUSE                      */ OpenRCT2::CrookedHouseRTD,
+    /* RIDE_TYPE_MONORAIL_CYCLES                    */ OpenRCT2::MonorailCyclesRTD,
+    /* RIDE_TYPE_COMPACT_INVERTED_COASTER           */ OpenRCT2::CompactInvertedCoasterRTD,
+    /* RIDE_TYPE_WATER_COASTER                      */ OpenRCT2::WaterCoasterRTD,
+    /* RIDE_TYPE_AIR_POWERED_VERTICAL_COASTER       */ OpenRCT2::AirPoweredVerticalCoasterRTD,
+    /* RIDE_TYPE_INVERTED_HAIRPIN_COASTER           */ OpenRCT2::InvertedHairpinCoasterRTD,
+    /* RIDE_TYPE_MAGIC_CARPET                       */ OpenRCT2::MagicCarpetRTD,
+    /* RIDE_TYPE_SUBMARINE_RIDE                     */ OpenRCT2::SubmarineRideRTD,
+    /* RIDE_TYPE_RIVER_RAFTS                        */ OpenRCT2::RiverRaftsRTD,
     /* RIDE_TYPE_50                                 */ kDummyRTD,
-    /* RIDE_TYPE_ENTERPRISE                         */ EnterpriseRTD,
+    /* RIDE_TYPE_ENTERPRISE                         */ OpenRCT2::EnterpriseRTD,
     /* RIDE_TYPE_52                                 */ kDummyRTD,
     /* RIDE_TYPE_53                                 */ kDummyRTD,
     /* RIDE_TYPE_54                                 */ kDummyRTD,
     /* RIDE_TYPE_55                                 */ kDummyRTD,
-    /* RIDE_TYPE_INVERTED_IMPULSE_COASTER           */ InvertedImpulseCoasterRTD,
-    /* RIDE_TYPE_MINI_ROLLER_COASTER                */ MiniRollerCoasterRTD,
-    /* RIDE_TYPE_MINE_RIDE                          */ MineRideRTD,
+    /* RIDE_TYPE_INVERTED_IMPULSE_COASTER           */ OpenRCT2::InvertedImpulseCoasterRTD,
+    /* RIDE_TYPE_MINI_ROLLER_COASTER                */ OpenRCT2::MiniRollerCoasterRTD,
+    /* RIDE_TYPE_MINE_RIDE                          */ OpenRCT2::MineRideRTD,
     /* RIDE_TYPE_59                                 */ kDummyRTD,
-    /* RIDE_TYPE_LIM_LAUNCHED_ROLLER_COASTER        */ LIMLaunchedRollerCoasterRTD,
-    /* RIDE_TYPE_HYPERCOASTER,                      */ HypercoasterRTD,
-    /* RIDE_TYPE_HYPER_TWISTER,                     */ HyperTwisterRTD,
-    /* RIDE_TYPE_MONSTER_TRUCKS,                    */ MonsterTrucksRTD,
-    /* RIDE_TYPE_SPINNING_WILD_MOUSE,               */ SpinningWildMouseRTD,
-    /* RIDE_TYPE_CLASSIC_MINI_ROLLER_COASTER,       */ ClassicMiniRollerCoasterRTD,
-    /* RIDE_TYPE_HYBRID_COASTER                     */ HybridCoasterRTD,
-    /* RIDE_TYPE_SINGLE_RAIL_ROLLER_COASTER         */ SingleRailRollerCoasterRTD,
-    /* RIDE_TYPE_ALPINE_COASTER                     */ AlpineCoasterRTD,
-    /* RIDE_TYPE_CLASSIC_WOODEN_ROLLER_COASTER      */ ClassicWoodenRollerCoasterRTD,
-    /* RIDE_TYPE_CLASSIC_STAND_UP_ROLLER_COASTER    */ ClassicStandUpRollerCoasterRTD,
-    /* RIDE_TYPE_LSM_LAUNCHED_ROLLER_COASTER        */ LSMLaunchedRollerCoasterRTD,
+    /* RIDE_TYPE_LIM_LAUNCHED_ROLLER_COASTER        */ OpenRCT2::LIMLaunchedRollerCoasterRTD,
+    /* RIDE_TYPE_HYPERCOASTER,                      */ OpenRCT2::HypercoasterRTD,
+    /* RIDE_TYPE_HYPER_TWISTER,                     */ OpenRCT2::HyperTwisterRTD,
+    /* RIDE_TYPE_MONSTER_TRUCKS,                    */ OpenRCT2::MonsterTrucksRTD,
+    /* RIDE_TYPE_SPINNING_WILD_MOUSE,               */ OpenRCT2::SpinningWildMouseRTD,
+    /* RIDE_TYPE_CLASSIC_MINI_ROLLER_COASTER,       */ OpenRCT2::ClassicMiniRollerCoasterRTD,
+    /* RIDE_TYPE_HYBRID_COASTER                     */ OpenRCT2::HybridCoasterRTD,
+    /* RIDE_TYPE_SINGLE_RAIL_ROLLER_COASTER         */ OpenRCT2::SingleRailRollerCoasterRTD,
+    /* RIDE_TYPE_ALPINE_COASTER                     */ OpenRCT2::AlpineCoasterRTD,
+    /* RIDE_TYPE_CLASSIC_WOODEN_ROLLER_COASTER      */ OpenRCT2::ClassicWoodenRollerCoasterRTD,
+    /* RIDE_TYPE_CLASSIC_STAND_UP_ROLLER_COASTER    */ OpenRCT2::ClassicStandUpRollerCoasterRTD,
+    /* RIDE_TYPE_LSM_LAUNCHED_ROLLER_COASTER        */ OpenRCT2::LSMLaunchedRollerCoasterRTD,
     /* RIDE_TYPE_CLASSIC_WOODEN_TWISTER_ROLLER_COASTER */ ClassicWoodenTwisterRollerCoasterRTD,
 };
 
@@ -375,19 +375,19 @@ ResearchCategory RideTypeDescriptor::GetResearchCategory() const
 {
     switch (Category)
     {
-        case RIDE_CATEGORY_TRANSPORT:
+        case RideCategory::transport:
             return ResearchCategory::Transport;
-        case RIDE_CATEGORY_GENTLE:
+        case RideCategory::gentle:
             return ResearchCategory::Gentle;
-        case RIDE_CATEGORY_ROLLERCOASTER:
+        case RideCategory::rollerCoaster:
             return ResearchCategory::Rollercoaster;
-        case RIDE_CATEGORY_THRILL:
+        case RideCategory::thrill:
             return ResearchCategory::Thrill;
-        case RIDE_CATEGORY_WATER:
+        case RideCategory::water:
             return ResearchCategory::Water;
-        case RIDE_CATEGORY_SHOP:
+        case RideCategory::shop:
             return ResearchCategory::Shop;
-        case RIDE_CATEGORY_NONE:
+        case RideCategory::none:
             break;
     }
     LOG_ERROR("Cannot get Research Category of invalid RideCategory");
@@ -411,7 +411,7 @@ void UpdateEnabledRideGroups(TrackDrawerDescriptor trackDrawerDescriptor)
 {
     trackDrawerDescriptor.Regular.GetAvailableTrackGroups(_enabledRideGroups);
 
-    if (!GetGameState().Cheats.enableAllDrawableTrackPieces)
+    if (!getGameState().cheats.enableAllDrawableTrackPieces)
     {
         _enabledRideGroups &= ~_disabledRideGroups;
     }
@@ -425,14 +425,14 @@ void UpdateDisabledRideGroups(const RideTrackGroups& res)
 void TrackDrawerEntry::GetAvailableTrackGroups(RideTrackGroups& res) const
 {
     res = enabledTrackGroups;
-    if (GetGameState().Cheats.enableAllDrawableTrackPieces)
+    if (getGameState().cheats.enableAllDrawableTrackPieces)
         res |= extraTrackGroups;
 }
 
 bool TrackDrawerEntry::SupportsTrackGroup(const TrackGroup trackGroup) const
 {
     return enabledTrackGroups.get(EnumValue(trackGroup))
-        || (GetGameState().Cheats.enableAllDrawableTrackPieces && extraTrackGroups.get(EnumValue(trackGroup)));
+        || (getGameState().cheats.enableAllDrawableTrackPieces && extraTrackGroups.get(EnumValue(trackGroup)));
 }
 
 bool TrackDrawerDescriptor::HasCoveredPieces() const
