@@ -9,7 +9,6 @@
 
 #include "Climate.h"
 
-#include "../Cheats.h"
 #include "../Context.h"
 #include "../Game.h"
 #include "../GameState.h"
@@ -20,33 +19,19 @@
 #include "../audio/AudioMixer.h"
 #include "../config/Config.h"
 #include "../core/EnumUtils.hpp"
-#include "../drawing/Drawing.h"
+#include "../object/ClimateObject.h"
+#include "../object/ObjectManager.h"
 #include "../profiling/Profiling.h"
 #include "../scenario/Scenario.h"
 #include "../util/Util.h"
 #include "../windows/Intent.h"
 
-#include <iterator>
+#include <array>
 #include <memory>
 
 using namespace OpenRCT2;
 using namespace OpenRCT2::Audio;
 
-constexpr int32_t kMaxThunderInstances = 2;
-
-enum class ThunderStatus
-{
-    none,
-    playing,
-};
-
-struct WeatherPattern
-{
-    int8_t baseTemperature;
-    int8_t randomBias;
-    WeatherType distribution[24];
-};
-
 struct WeatherTrait
 {
     int8_t temperatureDelta;
@@ -56,10 +41,27 @@ struct WeatherTrait
     uint32_t spriteId;
 };
 
-// TODO: no need for these to be declared extern, just move the definitions up
-extern const WeatherPattern* kClimatePatterns[4];
-extern const WeatherTrait kClimateWeatherTraits[EnumValue(WeatherType::Count)];
-extern const FilterPaletteID kClimateWeatherGloomColours[4];
+// clang-format off
+constexpr std::array<WeatherTrait, EnumValue(WeatherType::Count)> kClimateWeatherTraits = { {
+    {  10, WeatherEffectType::None,     0, WeatherLevel::None,  SPR_WEATHER_SUN          }, // Sunny
+    {   5, WeatherEffectType::None,     0, WeatherLevel::None,  SPR_WEATHER_SUN_CLOUD    }, // Partially Cloudy
+    {   0, WeatherEffectType::None,     0, WeatherLevel::None,  SPR_WEATHER_CLOUD        }, // Cloudy
+    {  -2, WeatherEffectType::Rain,     1, WeatherLevel::Light, SPR_WEATHER_LIGHT_RAIN   }, // Rain
+    {  -4, WeatherEffectType::Rain,     2, WeatherLevel::Heavy, SPR_WEATHER_HEAVY_RAIN   }, // Heavy Rain
+    {   2, WeatherEffectType::Storm,    2, WeatherLevel::Heavy, SPR_WEATHER_STORM        }, // Thunderstorm
+    { -10, WeatherEffectType::Snow,     1, WeatherLevel::Light, SPR_G2_WEATHER_SNOW      }, // Snow
+    { -15, WeatherEffectType::Snow,     2, WeatherLevel::Heavy, SPR_G2_WEATHER_HEAVY_SNOW}, // Heavy Snow
+    { -20, WeatherEffectType::Blizzard, 2, WeatherLevel::Heavy, SPR_G2_WEATHER_BLIZZARD  }, // Blizzard
+} };
+// clang-format on
+
+constexpr int32_t kMaxThunderInstances = 2;
+
+enum class ThunderStatus
+{
+    none,
+    playing,
+};
 
 // Climate data
 uint16_t gClimateLightningFlash;
@@ -78,6 +80,13 @@ static int32_t _thunderVolume;
 static int32_t _thunderStereoEcho = 0;
 static std::shared_ptr<IAudioChannel> _weatherSoundChannel;
 
+constexpr FilterPaletteID kClimateWeatherGloomColours[4] = {
+    FilterPaletteID::PaletteNull,
+    FilterPaletteID::PaletteDarken1,
+    FilterPaletteID::PaletteDarken2,
+    FilterPaletteID::PaletteDarken3,
+};
+
 static int8_t ClimateStepWeatherLevel(int8_t currentWeatherLevel, int8_t nextWeatherLevel);
 static void ClimateDetermineFutureWeather(uint32_t randomValue);
 static void ClimateUpdateWeatherSound();
@@ -94,21 +103,25 @@ int32_t ClimateCelsiusToFahrenheit(int32_t celsius)
 /**
  * Set climate and determine start weather.
  */
-void ClimateReset(ClimateType climate)
+void ClimateReset()
 {
-    auto weather = WeatherType::PartiallyCloudy;
-    int32_t month = GetDate().GetMonth();
+    auto& objManager = GetContext()->GetObjectManager();
+    auto* climateObj = objManager.GetLoadedObject<ClimateObject>(0);
+    if (climateObj == nullptr)
+        return;
 
-    const WeatherPattern& pattern = kClimatePatterns[EnumValue(climate)][month];
+    int32_t month = GetDate().GetMonth();
+    const WeatherPattern& pattern = climateObj->getPatternForMonth(month);
+
+    auto weather = WeatherType::PartiallyCloudy;
     const WeatherTrait& trait = kClimateWeatherTraits[EnumValue(weather)];
 
-    auto& gameState = GetGameState();
-    gameState.Climate = climate;
-    gameState.WeatherCurrent.weatherType = weather;
-    gameState.WeatherCurrent.temperature = pattern.baseTemperature + trait.temperatureDelta;
-    gameState.WeatherCurrent.weatherEffect = trait.effectLevel;
-    gameState.WeatherCurrent.weatherGloom = trait.gloomLevel;
-    gameState.WeatherCurrent.level = trait.level;
+    auto& gameState = getGameState();
+    gameState.weatherCurrent.weatherType = weather;
+    gameState.weatherCurrent.temperature = pattern.baseTemperature + trait.temperatureDelta;
+    gameState.weatherCurrent.weatherEffect = trait.effectLevel;
+    gameState.weatherCurrent.weatherGloom = trait.gloomLevel;
+    gameState.weatherCurrent.level = trait.level;
 
     _lightningTimer = 0;
     _thunderTimer = 0;
@@ -129,58 +142,58 @@ void ClimateUpdate()
 {
     PROFILED_FUNCTION();
 
-    auto& gameState = GetGameState();
+    auto& gameState = getGameState();
 
     // Only do climate logic if playing (not in scenario editor or title screen)
-    if (gScreenFlags & (~SCREEN_FLAGS_PLAYING))
+    if (gLegacyScene != LegacyScene::playing)
         return;
 
-    if (!GetGameState().Cheats.freezeWeather)
+    if (!getGameState().cheats.freezeWeather)
     {
-        if (gameState.WeatherUpdateTimer)
+        if (gameState.weatherUpdateTimer)
         {
-            if (gameState.WeatherUpdateTimer == 960)
+            if (gameState.weatherUpdateTimer == 960)
             {
                 auto intent = Intent(INTENT_ACTION_UPDATE_CLIMATE);
                 ContextBroadcastIntent(&intent);
             }
-            gameState.WeatherUpdateTimer--;
+            gameState.weatherUpdateTimer--;
         }
-        else if (!(gameState.CurrentTicks & 0x7F))
+        else if (!(gameState.currentTicks & 0x7F))
         {
-            if (gameState.WeatherCurrent.temperature == gameState.WeatherNext.temperature)
+            if (gameState.weatherCurrent.temperature == gameState.weatherNext.temperature)
             {
-                if (gameState.WeatherCurrent.weatherGloom == gameState.WeatherNext.weatherGloom)
+                if (gameState.weatherCurrent.weatherGloom == gameState.weatherNext.weatherGloom)
                 {
-                    gameState.WeatherCurrent.weatherEffect = gameState.WeatherNext.weatherEffect;
+                    gameState.weatherCurrent.weatherEffect = gameState.weatherNext.weatherEffect;
                     _thunderTimer = 0;
                     _lightningTimer = 0;
 
-                    if (gameState.WeatherCurrent.level == gameState.WeatherNext.level)
+                    if (gameState.weatherCurrent.level == gameState.weatherNext.level)
                     {
-                        gameState.WeatherCurrent.weatherType = gameState.WeatherNext.weatherType;
+                        gameState.weatherCurrent.weatherType = gameState.weatherNext.weatherType;
                         ClimateDetermineFutureWeather(ScenarioRand());
                         auto intent = Intent(INTENT_ACTION_UPDATE_CLIMATE);
                         ContextBroadcastIntent(&intent);
                     }
-                    else if (gameState.WeatherNext.level <= WeatherLevel::Heavy)
+                    else if (gameState.weatherNext.level <= WeatherLevel::Heavy)
                     {
-                        gameState.WeatherCurrent.level = static_cast<WeatherLevel>(ClimateStepWeatherLevel(
-                            static_cast<int8_t>(gameState.WeatherCurrent.level),
-                            static_cast<int8_t>(gameState.WeatherNext.level)));
+                        gameState.weatherCurrent.level = static_cast<WeatherLevel>(ClimateStepWeatherLevel(
+                            static_cast<int8_t>(gameState.weatherCurrent.level),
+                            static_cast<int8_t>(gameState.weatherNext.level)));
                     }
                 }
                 else
                 {
-                    gameState.WeatherCurrent.weatherGloom = ClimateStepWeatherLevel(
-                        gameState.WeatherCurrent.weatherGloom, gameState.WeatherNext.weatherGloom);
+                    gameState.weatherCurrent.weatherGloom = ClimateStepWeatherLevel(
+                        gameState.weatherCurrent.weatherGloom, gameState.weatherNext.weatherGloom);
                     GfxInvalidateScreen();
                 }
             }
             else
             {
-                gameState.WeatherCurrent.temperature = ClimateStepWeatherLevel(
-                    gameState.WeatherCurrent.temperature, gameState.WeatherNext.temperature);
+                gameState.weatherCurrent.temperature = ClimateStepWeatherLevel(
+                    gameState.weatherCurrent.temperature, gameState.weatherNext.temperature);
                 auto intent = Intent(INTENT_ACTION_UPDATE_CLIMATE);
                 ContextBroadcastIntent(&intent);
             }
@@ -193,12 +206,12 @@ void ClimateUpdate()
         ClimateUpdateThunder();
     }
     else if (
-        gameState.WeatherCurrent.weatherEffect == WeatherEffectType::Storm
-        || gameState.WeatherCurrent.weatherEffect == WeatherEffectType::Blizzard)
+        gameState.weatherCurrent.weatherEffect == WeatherEffectType::Storm
+        || gameState.weatherCurrent.weatherEffect == WeatherEffectType::Blizzard)
     {
-        // Create new thunder and lightning
-        uint32_t randomNumber = UtilRand();
-        if ((randomNumber & 0xFFFF) <= 0x1B4)
+        // Create new thunder and lightning. Their amount is scaled inversely proportional
+        // to the game speed, otherwise they become annoying at very high speeds
+        if (uint32_t randomNumber = UtilRand(); (randomNumber & 0xFFFF) <= (0x1B4u >> gGameSpeed))
         {
             randomNumber >>= 16;
             _thunderTimer = 43 + (randomNumber % 64);
@@ -209,18 +222,23 @@ void ClimateUpdate()
 
 void ClimateForceWeather(WeatherType weather)
 {
-    auto& gameState = GetGameState();
+    auto& objManager = GetContext()->GetObjectManager();
+    auto* climateObj = objManager.GetLoadedObject<ClimateObject>(0);
+    if (climateObj == nullptr)
+        return;
+
     int32_t month = GetDate().GetMonth();
+    const WeatherPattern& pattern = climateObj->getPatternForMonth(month);
 
-    const auto& pattern = kClimatePatterns[EnumValue(gameState.Climate)][month];
     const auto& trait = kClimateWeatherTraits[EnumValue(weather)];
 
-    gameState.WeatherCurrent.weatherType = weather;
-    gameState.WeatherCurrent.weatherGloom = trait.gloomLevel;
-    gameState.WeatherCurrent.level = trait.level;
-    gameState.WeatherCurrent.weatherEffect = trait.effectLevel;
-    gameState.WeatherCurrent.temperature = pattern.baseTemperature + trait.temperatureDelta;
-    gameState.WeatherUpdateTimer = 1920;
+    auto& gameState = getGameState();
+    gameState.weatherCurrent.weatherType = weather;
+    gameState.weatherCurrent.weatherGloom = trait.gloomLevel;
+    gameState.weatherCurrent.level = trait.level;
+    gameState.weatherCurrent.weatherEffect = trait.effectLevel;
+    gameState.weatherCurrent.temperature = pattern.baseTemperature + trait.temperatureDelta;
+    gameState.weatherUpdateTimer = 1920;
 
     ClimateDetermineFutureWeather(ScenarioRand());
 
@@ -235,7 +253,7 @@ void ClimateUpdateSound()
     if (!OpenRCT2::Audio::IsAvailable())
         return;
 
-    if (gScreenFlags & SCREEN_FLAGS_TITLE_DEMO)
+    if (gLegacyScene == LegacyScene::titleSequence)
         return;
 
     ClimateUpdateWeatherSound();
@@ -244,27 +262,45 @@ void ClimateUpdateSound()
 
 bool ClimateIsRaining()
 {
-    auto& weather = GetGameState().WeatherCurrent.weatherType;
+    auto& weather = getGameState().weatherCurrent.weatherType;
     return weather == WeatherType::Rain || weather == WeatherType::HeavyRain || weather == WeatherType::Thunder;
 }
 
 bool ClimateIsSnowing()
 {
-    auto& weather = GetGameState().WeatherCurrent.weatherType;
+    auto& weather = getGameState().weatherCurrent.weatherType;
+    return weather == WeatherType::Snow || weather == WeatherType::HeavySnow || weather == WeatherType::Blizzard;
+}
+
+bool ClimateTransitioningToSnow()
+{
+    auto& weather = getGameState().weatherNext.weatherType;
     return weather == WeatherType::Snow || weather == WeatherType::HeavySnow || weather == WeatherType::Blizzard;
 }
 
 bool ClimateIsSnowingHeavily()
 {
-    auto& weather = GetGameState().WeatherCurrent.weatherType;
+    auto& weather = getGameState().weatherCurrent.weatherType;
     return weather == WeatherType::HeavySnow || weather == WeatherType::Blizzard;
 }
 
+bool ClimateIsPrecipitating()
+{
+    return ClimateIsRaining() || ClimateIsSnowingHeavily();
+}
+
 bool WeatherIsDry(WeatherType weather)
 {
     return weather == WeatherType::Sunny || weather == WeatherType::PartiallyCloudy || weather == WeatherType::Cloudy;
 }
 
+bool ClimateHasWeatherEffect()
+{
+    const auto& weatherCurrent = getGameState().weatherCurrent;
+    // The game starts drawing rain whenever this level is not none.
+    return weatherCurrent.level != WeatherLevel::None;
+}
+
 FilterPaletteID ClimateGetWeatherGloomPaletteId(const WeatherState& state)
 {
     auto paletteId = FilterPaletteID::PaletteNull;
@@ -276,14 +312,9 @@ FilterPaletteID ClimateGetWeatherGloomPaletteId(const WeatherState& state)
     return paletteId;
 }
 
-uint32_t ClimateGetWeatherSpriteId(const WeatherState& state)
+uint32_t ClimateGetWeatherSpriteId(const WeatherType weatherType)
 {
-    uint32_t spriteId = SPR_WEATHER_SUN;
-    if (EnumValue(state.weatherType) < std::size(kClimateWeatherTraits))
-    {
-        spriteId = kClimateWeatherTraits[EnumValue(state.weatherType)].spriteId;
-    }
-    return spriteId;
+    return kClimateWeatherTraits[EnumValue(weatherType)].spriteId;
 }
 
 static int8_t ClimateStepWeatherLevel(int8_t currentWeatherLevel, int8_t nextWeatherLevel)
@@ -304,29 +335,35 @@ static int8_t ClimateStepWeatherLevel(int8_t currentWeatherLevel, int8_t nextWea
  */
 static void ClimateDetermineFutureWeather(uint32_t randomValue)
 {
+    auto& objManager = GetContext()->GetObjectManager();
+    auto* climateObj = objManager.GetLoadedObject<ClimateObject>(0);
+    if (climateObj == nullptr)
+        return;
+
     int32_t month = GetDate().GetMonth();
-    auto& gameState = GetGameState();
+    const WeatherPattern& pattern = climateObj->getPatternForMonth(month);
 
     // Generate a random index with values 0 up to randomBias-1
     // and choose weather from the distribution table accordingly
-    const auto& pattern = kClimatePatterns[EnumValue(gameState.Climate)][month];
     const auto randomIndex = ((randomValue % 256) * pattern.randomBias) / 256;
     const auto nextWeather = pattern.distribution[randomIndex];
-    gameState.WeatherNext.weatherType = nextWeather;
+
+    auto& gameState = getGameState();
+    gameState.weatherNext.weatherType = nextWeather;
 
     const auto& nextWeatherTrait = kClimateWeatherTraits[EnumValue(nextWeather)];
-    gameState.WeatherNext.temperature = pattern.baseTemperature + nextWeatherTrait.temperatureDelta;
-    gameState.WeatherNext.weatherEffect = nextWeatherTrait.effectLevel;
-    gameState.WeatherNext.weatherGloom = nextWeatherTrait.gloomLevel;
-    gameState.WeatherNext.level = nextWeatherTrait.level;
+    gameState.weatherNext.temperature = pattern.baseTemperature + nextWeatherTrait.temperatureDelta;
+    gameState.weatherNext.weatherEffect = nextWeatherTrait.effectLevel;
+    gameState.weatherNext.weatherGloom = nextWeatherTrait.gloomLevel;
+    gameState.weatherNext.level = nextWeatherTrait.level;
 
-    gameState.WeatherUpdateTimer = 1920;
+    gameState.weatherUpdateTimer = 1920;
 }
 
 static void ClimateUpdateWeatherSound()
 {
-    if (GetGameState().WeatherCurrent.weatherEffect == WeatherEffectType::Rain
-        || GetGameState().WeatherCurrent.weatherEffect == WeatherEffectType::Storm)
+    if (getGameState().weatherCurrent.weatherEffect == WeatherEffectType::Rain
+        || getGameState().weatherCurrent.weatherEffect == WeatherEffectType::Storm)
     {
         // Start playing the weather sound
         if (_weatherSoundChannel == nullptr || _weatherSoundChannel->IsDone())
@@ -459,83 +496,3 @@ static void ClimatePlayThunder(int32_t instanceIndex, OpenRCT2::Audio::SoundId s
         _thunderStatus[instanceIndex] = ThunderStatus::playing;
     }
 }
-
-#pragma region Climate / Weather data tables
-
-const FilterPaletteID kClimateWeatherGloomColours[4] = {
-    FilterPaletteID::PaletteNull,
-    FilterPaletteID::PaletteDarken1,
-    FilterPaletteID::PaletteDarken2,
-    FilterPaletteID::PaletteDarken3,
-};
-
-// clang-format off
-const WeatherTrait kClimateWeatherTraits[EnumValue(WeatherType::Count)] = {
-    {  10, WeatherEffectType::None,     0, WeatherLevel::None,  SPR_WEATHER_SUN        }, // Sunny
-    {   5, WeatherEffectType::None,     0, WeatherLevel::None,  SPR_WEATHER_SUN_CLOUD  }, // Partially Cloudy
-    {   0, WeatherEffectType::None,     0, WeatherLevel::None,  SPR_WEATHER_CLOUD      }, // Cloudy
-    {  -2, WeatherEffectType::Rain,     1, WeatherLevel::Light, SPR_WEATHER_LIGHT_RAIN }, // Rain
-    {  -4, WeatherEffectType::Rain,     2, WeatherLevel::Heavy, SPR_WEATHER_HEAVY_RAIN }, // Heavy Rain
-    {   2, WeatherEffectType::Storm,    2, WeatherLevel::Heavy, SPR_WEATHER_STORM      }, // Thunderstorm
-    { -10, WeatherEffectType::Snow,     1, WeatherLevel::Light, SPR_G2_WEATHER_SNOW      }, // Snow
-    { -15, WeatherEffectType::Snow,     2, WeatherLevel::Heavy, SPR_G2_WEATHER_HEAVY_SNOW}, // Heavy Snow
-    { -20, WeatherEffectType::Blizzard, 2, WeatherLevel::Heavy, SPR_G2_WEATHER_BLIZZARD  }, // Blizzard
-};
-// clang-format on
-
-constexpr auto S = WeatherType::Sunny;
-constexpr auto P = WeatherType::PartiallyCloudy;
-constexpr auto C = WeatherType::Cloudy;
-constexpr auto R = WeatherType::Rain;
-constexpr auto H = WeatherType::HeavyRain;
-constexpr auto T = WeatherType::Thunder;
-
-static constexpr WeatherPattern kClimatePatternsCoolAndWet[] = {
-    { 8, 18, { S, P, P, P, P, P, C, C, C, C, C, C, C, R, R, R, H, H, S, S, S, S, S } },
-    { 10, 21, { P, P, P, P, P, C, C, C, C, C, C, C, C, C, R, R, R, H, H, H, T, S, S } },
-    { 14, 17, { S, S, S, P, P, P, P, P, P, C, C, C, C, R, R, R, H, S, S, S, S, S, S } },
-    { 17, 17, { S, S, S, S, P, P, P, P, P, P, P, C, C, C, C, R, R, S, S, S, S, S, S } },
-    { 19, 23, { S, S, S, S, S, S, S, S, S, S, P, P, P, P, P, P, C, C, C, C, C, R, H } },
-    { 20, 23, { S, S, S, S, S, S, P, P, P, P, P, P, P, P, C, C, C, C, R, H, H, H, T } },
-    { 16, 19, { S, S, S, P, P, P, P, P, C, C, C, C, C, C, R, R, H, H, T, S, S, S, S } },
-    { 13, 16, { S, S, P, P, P, P, C, C, C, C, C, C, R, R, H, T, S, S, S, S, S, S, S } },
-};
-static constexpr WeatherPattern kClimatePatternsWarm[] = {
-    { 12, 21, { S, S, S, S, S, P, P, P, P, P, P, P, P, C, C, C, C, C, C, C, H, S, S } },
-    { 13, 22, { S, S, S, S, S, P, P, P, P, P, P, C, C, C, C, C, C, C, C, C, R, T, S } },
-    { 16, 17, { S, S, S, S, S, S, P, P, P, P, P, P, C, C, C, C, R, S, S, S, S, S, S } },
-    { 19, 18, { S, S, S, S, S, S, P, P, P, P, P, P, P, C, C, C, C, R, S, S, S, S, S } },
-    { 21, 22, { S, S, S, S, S, S, S, S, S, S, P, P, P, P, P, P, P, P, P, C, C, C, S } },
-    { 22, 17, { S, S, S, S, S, S, S, S, S, P, P, P, P, P, C, C, T, S, S, S, S, S, S } },
-    { 19, 17, { S, S, S, S, S, P, P, P, P, P, C, C, C, C, C, C, R, S, S, S, S, S, S } },
-    { 16, 17, { S, S, P, P, P, P, P, C, C, C, C, C, C, C, C, C, H, S, S, S, S, S, S } },
-};
-static constexpr WeatherPattern kClimatePatternsHotAndDry[] = {
-    { 12, 15, { S, S, S, S, P, P, P, P, P, P, P, P, C, C, R, S, S, S, S, S, S, S, S } },
-    { 14, 12, { S, S, S, S, S, P, P, P, P, P, C, C, S, S, S, S, S, S, S, S, S, S, S } },
-    { 16, 11, { S, S, S, S, S, S, P, P, P, P, C, S, S, S, S, S, S, S, S, S, S, S, S } },
-    { 19, 9, { S, S, S, S, S, S, P, P, P, S, S, S, S, S, S, S, S, S, S, S, S, S, S } },
-    { 21, 13, { S, S, S, S, S, S, S, S, S, S, P, P, P, S, S, S, S, S, S, S, S, S, S } },
-    { 22, 11, { S, S, S, S, S, S, S, S, S, P, P, S, S, S, S, S, S, S, S, S, S, S, S } },
-    { 21, 12, { S, S, S, S, S, S, S, P, P, P, C, T, S, S, S, S, S, S, S, S, S, S, S } },
-    { 16, 13, { S, S, S, S, S, S, S, S, P, P, P, C, R, S, S, S, S, S, S, S, S, S, S } },
-};
-static constexpr WeatherPattern kClimatePatternsCold[] = {
-    { 4, 18, { S, S, S, S, P, P, P, P, P, C, C, C, C, C, C, C, R, H, S, S, S, S, S } },
-    { 5, 21, { S, S, S, S, P, P, P, P, P, C, C, C, C, C, C, C, C, C, R, H, T, S, S } },
-    { 7, 17, { S, S, S, S, P, P, P, P, P, P, P, C, C, C, C, R, H, S, S, S, S, S, S } },
-    { 9, 17, { S, S, S, S, P, P, P, P, P, P, P, C, C, C, C, R, R, S, S, S, S, S, S } },
-    { 10, 23, { S, S, S, S, S, S, S, S, S, S, P, P, P, P, P, P, C, C, C, C, C, R, H } },
-    { 11, 23, { S, S, S, S, S, S, P, P, P, P, P, P, P, P, P, P, C, C, C, C, R, H, T } },
-    { 9, 19, { S, S, S, S, S, P, P, P, P, P, C, C, C, C, C, C, R, H, T, S, S, S, S } },
-    { 6, 16, { S, S, P, P, P, P, C, C, C, C, C, C, R, R, H, T, S, S, S, S, S, S, S } },
-};
-
-const WeatherPattern* kClimatePatterns[] = {
-    kClimatePatternsCoolAndWet,
-    kClimatePatternsWarm,
-    kClimatePatternsHotAndDry,
-    kClimatePatternsCold,
-};
-
-#pragma endregion
