@@ -33,9 +33,7 @@
 #include "../object/SceneryGroupObject.h"
 #include "../object/SmallSceneryEntry.h"
 #include "../object/WallSceneryEntry.h"
-#include "../scenario/Scenario.h"
 #include "Footpath.h"
-#include "Map.h"
 #include "Park.h"
 #include "tile_element/PathElement.h"
 #include "tile_element/SmallSceneryElement.h"
@@ -178,13 +176,13 @@ void SmallSceneryElement::UpdateAge(const CoordsXY& sceneryPos)
         return;
     }
 
-    auto& gameState = GetGameState();
-    if (gameState.Cheats.disablePlantAging && sceneryEntry->HasFlag(SMALL_SCENERY_FLAG_CAN_BE_WATERED))
+    auto& gameState = getGameState();
+    if (gameState.cheats.disablePlantAging && sceneryEntry->HasFlag(SMALL_SCENERY_FLAG_CAN_BE_WATERED))
     {
         return;
     }
 
-    if (!sceneryEntry->HasFlag(SMALL_SCENERY_FLAG_CAN_BE_WATERED) || WeatherIsDry(gameState.WeatherCurrent.weatherType)
+    if (!sceneryEntry->HasFlag(SMALL_SCENERY_FLAG_CAN_BE_WATERED) || WeatherIsDry(gameState.weatherCurrent.weatherType)
         || GetAge() < 5)
     {
         IncreaseAge(sceneryPos);
@@ -239,7 +237,7 @@ void SceneryRemoveGhostToolPlacement()
     {
         gSceneryGhostType &= ~SCENERY_GHOST_FLAG_0;
 
-        auto removeSceneryAction = SmallSceneryRemoveAction(
+        auto removeSceneryAction = GameActions::SmallSceneryRemoveAction(
             gSceneryGhostPosition, gSceneryQuadrant, gSceneryPlaceObject.EntryIndex);
         removeSceneryAction.SetFlags(
             GAME_COMMAND_FLAG_ALLOW_DURING_PAUSED | GAME_COMMAND_FLAG_NO_SPEND | GAME_COMMAND_FLAG_GHOST);
@@ -262,7 +260,7 @@ void SceneryRemoveGhostToolPlacement()
             if (tileElement->GetBaseZ() != gSceneryGhostPosition.z)
                 continue;
 
-            auto footpathAdditionRemoveAction = FootpathAdditionRemoveAction(gSceneryGhostPosition);
+            auto footpathAdditionRemoveAction = GameActions::FootpathAdditionRemoveAction(gSceneryGhostPosition);
             footpathAdditionRemoveAction.SetFlags(
                 GAME_COMMAND_FLAG_ALLOW_DURING_PAUSED | GAME_COMMAND_FLAG_NO_SPEND | GAME_COMMAND_FLAG_GHOST);
             GameActions::Execute(&footpathAdditionRemoveAction);
@@ -275,7 +273,7 @@ void SceneryRemoveGhostToolPlacement()
         gSceneryGhostType &= ~SCENERY_GHOST_FLAG_2;
 
         CoordsXYZD wallLocation = { gSceneryGhostPosition, gSceneryGhostWallRotation };
-        auto wallRemoveAction = WallRemoveAction(wallLocation);
+        auto wallRemoveAction = GameActions::WallRemoveAction(wallLocation);
         wallRemoveAction.SetFlags(GAME_COMMAND_FLAG_ALLOW_DURING_PAUSED | GAME_COMMAND_FLAG_NO_SPEND | GAME_COMMAND_FLAG_GHOST);
         wallRemoveAction.Execute();
     }
@@ -284,7 +282,7 @@ void SceneryRemoveGhostToolPlacement()
     {
         gSceneryGhostType &= ~SCENERY_GHOST_FLAG_3;
 
-        auto removeSceneryAction = LargeSceneryRemoveAction({ gSceneryGhostPosition, gSceneryPlaceRotation }, 0);
+        auto removeSceneryAction = GameActions::LargeSceneryRemoveAction({ gSceneryGhostPosition, gSceneryPlaceRotation }, 0);
         removeSceneryAction.SetFlags(
             GAME_COMMAND_FLAG_ALLOW_DURING_PAUSED | GAME_COMMAND_FLAG_NO_SPEND | GAME_COMMAND_FLAG_GHOST);
         removeSceneryAction.Execute();
@@ -294,7 +292,7 @@ void SceneryRemoveGhostToolPlacement()
     {
         gSceneryGhostType &= ~SCENERY_GHOST_FLAG_4;
 
-        auto removeSceneryAction = BannerRemoveAction({ gSceneryGhostPosition, gSceneryPlaceRotation });
+        auto removeSceneryAction = GameActions::BannerRemoveAction({ gSceneryGhostPosition, gSceneryPlaceRotation });
         removeSceneryAction.SetFlags(
             GAME_COMMAND_FLAG_ALLOW_DURING_PAUSED | GAME_COMMAND_FLAG_NO_SPEND | GAME_COMMAND_FLAG_GHOST);
         GameActions::Execute(&removeSceneryAction);
@@ -304,13 +302,13 @@ void SceneryRemoveGhostToolPlacement()
 bool IsSceneryAvailableToBuild(const ScenerySelection& item)
 {
     // All scenery can be built when in the scenario editor
-    if (gScreenFlags & SCREEN_FLAGS_EDITOR)
+    if (isInEditorMode())
     {
         return true;
     }
 
-    auto& gameState = GetGameState();
-    if (!gameState.Cheats.ignoreResearchStatus)
+    auto& gameState = getGameState();
+    if (!gameState.cheats.ignoreResearchStatus)
     {
         if (!SceneryIsInvented(item))
         {
@@ -318,7 +316,7 @@ bool IsSceneryAvailableToBuild(const ScenerySelection& item)
         }
     }
 
-    if (!gameState.Cheats.sandboxMode && !(gScreenFlags & SCREEN_FLAGS_EDITOR))
+    if (!gameState.cheats.sandboxMode && !isInEditorMode())
     {
         if (IsSceneryItemRestricted(item))
         {
@@ -369,38 +367,38 @@ static bool IsSceneryEntryValid(const ScenerySelection& item)
 
 bool IsSceneryItemRestricted(const ScenerySelection& item)
 {
-    auto& gameState = GetGameState();
-    return std::find(std::begin(gameState.RestrictedScenery), std::end(gameState.RestrictedScenery), item)
-        != std::end(gameState.RestrictedScenery);
+    auto& gameState = getGameState();
+    return std::find(std::begin(gameState.restrictedScenery), std::end(gameState.restrictedScenery), item)
+        != std::end(gameState.restrictedScenery);
 }
 
 void ClearRestrictedScenery()
 {
-    GetGameState().RestrictedScenery.clear();
+    getGameState().restrictedScenery.clear();
 }
 
 std::vector<ScenerySelection>& GetRestrictedScenery()
 {
-    return GetGameState().RestrictedScenery;
+    return getGameState().restrictedScenery;
 }
 
 void SetSceneryItemRestricted(const ScenerySelection& item, bool on)
 {
-    auto& gameState = GetGameState();
-    auto existingItem = std::find(std::begin(gameState.RestrictedScenery), std::end(gameState.RestrictedScenery), item);
-    const bool existingItemIsPresent = existingItem != std::end(gameState.RestrictedScenery);
+    auto& gameState = getGameState();
+    auto existingItem = std::find(std::begin(gameState.restrictedScenery), std::end(gameState.restrictedScenery), item);
+    const bool existingItemIsPresent = existingItem != std::end(gameState.restrictedScenery);
     if (on)
     {
         if (!existingItemIsPresent)
         {
-            gameState.RestrictedScenery.push_back(item);
+            gameState.restrictedScenery.push_back(item);
         }
     }
     else
     {
         if (existingItemIsPresent)
         {
-            gameState.RestrictedScenery.erase(existingItem);
+            gameState.restrictedScenery.erase(existingItem);
         }
     }
 }
@@ -524,14 +522,14 @@ static MiscScenery GetAllMiscScenery()
 
 void RestrictAllMiscScenery()
 {
-    auto& gameState = GetGameState();
+    auto& gameState = getGameState();
     auto miscScenery = GetAllMiscScenery().miscScenery;
-    gameState.RestrictedScenery.insert(gameState.RestrictedScenery.begin(), miscScenery.begin(), miscScenery.end());
+    gameState.restrictedScenery.insert(gameState.restrictedScenery.begin(), miscScenery.begin(), miscScenery.end());
 }
 
 static void MarkAllUnrestrictedSceneryInVectorInvented(const std::vector<ScenerySelection>& vector)
 {
-    auto& restrictedScenery = GetGameState().RestrictedScenery;
+    auto& restrictedScenery = getGameState().restrictedScenery;
 
     for (const auto& sceneryItem : vector)
     {
